(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    365705,       8967]
NotebookOptionsPosition[    354376,       8624]
NotebookOutlinePosition[    354721,       8639]
CellTagsIndexPosition[    354678,       8636]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Methoden der Bioinformatik",
  FontSize->24,
  FontWeight->"Bold"],
 StyleBox[" \n\n",
  FontSize->12],
 "Eine Einf\[UDoubleDot]hrung zur Anwendung in Biologie und Medizin\n\n2. \
Auflage",
 StyleBox["\n",
  FontSize->18,
  FontWeight->"Bold"],
 StyleBox["\n",
  FontSize->12],
 "Marc-Thorsten H\[UDoubleDot]tt",
 StyleBox[" ",
  FontSize->12,
  FontWeight->"Bold"],
 "und",
 StyleBox[" ",
  FontSize->12,
  FontWeight->"Bold"],
 "Manuel Dehnert\n",
 StyleBox["\n",
  FontSize->12],
 "Springer Spektrum",
 StyleBox[" ",
  FontSize->12,
  FontWeight->"Bold"],
 "2006",
 StyleBox[", ",
  FontSize->12,
  FontWeight->"Bold"],
 "2016, ISBN 978-3-662-46149-5"
}], "Subsubtitle",
 CellChangeTimes->{{3.669868691792925*^9, 3.669868786167323*^9}, {
  3.6698688284727426`*^9, 3.669868879042635*^9}, {3.6698691142260866`*^9, 
  3.6698691148331213`*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-Exkurs: ",
 "Bereitstellung der Substitutionsmatrix"
}], "Subtitle",
 CellChangeTimes->{3.670321495640956*^9, 3.670402706588908*^9},
 Background->RGBColor[
  0.8705882352941177, 0.00392156862745098, 0.2196078431372549]],

Cell[TextData[{
 "Wie wir bereits bei der formalen Einf\[UDoubleDot]hrung des paarweisen \
Alignments gesehen haben, ist das Kernst\[UDoubleDot]ck des Verfahrens die \
Substitutionsmatrix. Wir werden hier die BLOSUM62-Matrix verwenden, die wir \
zuerst aus einer lokalen Datei einlesen und dann mit dem Befehl ",
 StyleBox["Partition[]",
  FontWeight->"Bold"],
 " in das richtige (24\[Times]24) Format bringen (vgl. Abb. 3.2)."
}], "Text",
 CellChangeTimes->{{3.6746317732864513`*^9, 3.674631792869481*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";"}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"blosum", "=", 
   RowBox[{"Partition", "[", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{"ReadList", "[", 
       RowBox[{"\"\<blosum62.txt\>\"", ",", "Number", ",", 
        RowBox[{"RecordLists", "\[Rule]", "True"}], ",", 
        RowBox[{"RecordSeparators", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"\"\<\\n\>\"", ",", "\"\< \>\""}], "}"}]}]}], "]"}], "]"}], 
     ",", "24"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.677494039964464*^9, 3.677494041446467*^9}, {
  3.6774941292650213`*^9, 3.677494129499022*^9}, {3.6775537396170807`*^9, 
  3.677553745560691*^9}}],

Cell[TextData[{
 "Mit dem Befehl ",
 StyleBox["Dimensions[]",
  FontWeight->"Bold"],
 " k\[ODoubleDot]nnen wir wie \[UDoubleDot]blich die Dimension der \
eingelesenen Matrix \[UDoubleDot]berpr\[UDoubleDot]fen."
}], "Text",
 CellChangeTimes->{{3.6746318302365365`*^9, 3.674631868587596*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Dimensions", "[", "blosum", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"24", ",", "24"}], "}"}]], "Output",
 CellChangeTimes->{3.6775716897503195`*^9}]
}, Open  ]],

Cell[TextData[{
 "An dieser Stelle ist die Substitutionsmatrix eine reine Zahlenmatrix, der \
wir im Folgenden eine Bedeutung zuweisen m\[UDoubleDot]ssen. Die universelle \
Anordnung jeder Substitutionsmatrix erlaubt uns, die Zeilen und Spalten mit \
einem Label zu versehen. Die Abfolge von Labels legen wir als Zeichenkette in \
einer Variablen ",
 StyleBox["proteinRef",
  FontWeight->"Bold"],
 " ab."
}], "Text",
 CellChangeTimes->{{3.67463191272066*^9, 3.6746319248926783`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"proteinRef", "=", 
  RowBox[{
  "Characters", "[", "\"\<ARNDCQEGHILKMFPSTWYVBZX*\>\"", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"A\"\>", ",", "\<\"R\"\>", ",", "\<\"N\"\>", ",", "\<\"D\"\>", 
   ",", "\<\"C\"\>", ",", "\<\"Q\"\>", ",", "\<\"E\"\>", ",", "\<\"G\"\>", 
   ",", "\<\"H\"\>", ",", "\<\"I\"\>", ",", "\<\"L\"\>", ",", "\<\"K\"\>", 
   ",", "\<\"M\"\>", ",", "\<\"F\"\>", ",", "\<\"P\"\>", ",", "\<\"S\"\>", 
   ",", "\<\"T\"\>", ",", "\<\"W\"\>", ",", "\<\"Y\"\>", ",", "\<\"V\"\>", 
   ",", "\<\"B\"\>", ",", "\<\"Z\"\>", ",", "\<\"X\"\>", ",", "\<\"*\"\>"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.677571689765919*^9}]
}, Open  ]],

Cell[TextData[{
 "Der Begriff ",
 StyleBox["TableForm[]",
  FontWeight->"Bold"],
 " erlaubt eine \[UDoubleDot]bersichtliche Ausgabe der mit Labels versehenen \
Substitutionsmatrix."
}], "Text",
 CellChangeTimes->{{3.6746319465567102`*^9, 3.674631977476756*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{"blosum", ",", 
   RowBox[{"TableHeadings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"proteinRef", ",", "proteinRef"}], "}"}]}], ",", 
   RowBox[{"TableSpacing", "\[Rule]", "0.4"}], ",", 
   RowBox[{"TableAlignments", "\[Rule]", "Right"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5776824217132177`*^9, 3.5776824391825266`*^9}, 
   3.577682751387882*^9, {3.623820808373982*^9, 3.623820854387879*^9}}],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      StyleBox["\[Null]",
       ShowStringCharacters->False], 
      TagBox["\<\"A\"\>",
       HoldForm], 
      TagBox["\<\"R\"\>",
       HoldForm], 
      TagBox["\<\"N\"\>",
       HoldForm], 
      TagBox["\<\"D\"\>",
       HoldForm], 
      TagBox["\<\"C\"\>",
       HoldForm], 
      TagBox["\<\"Q\"\>",
       HoldForm], 
      TagBox["\<\"E\"\>",
       HoldForm], 
      TagBox["\<\"G\"\>",
       HoldForm], 
      TagBox["\<\"H\"\>",
       HoldForm], 
      TagBox["\<\"I\"\>",
       HoldForm], 
      TagBox["\<\"L\"\>",
       HoldForm], 
      TagBox["\<\"K\"\>",
       HoldForm], 
      TagBox["\<\"M\"\>",
       HoldForm], 
      TagBox["\<\"F\"\>",
       HoldForm], 
      TagBox["\<\"P\"\>",
       HoldForm], 
      TagBox["\<\"S\"\>",
       HoldForm], 
      TagBox["\<\"T\"\>",
       HoldForm], 
      TagBox["\<\"W\"\>",
       HoldForm], 
      TagBox["\<\"Y\"\>",
       HoldForm], 
      TagBox["\<\"V\"\>",
       HoldForm], 
      TagBox["\<\"B\"\>",
       HoldForm], 
      TagBox["\<\"Z\"\>",
       HoldForm], 
      TagBox["\<\"X\"\>",
       HoldForm], 
      TagBox["\<\"*\"\>",
       HoldForm]},
     {
      TagBox["\<\"A\"\>",
       HoldForm], "4", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "2"}], "0", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "0", 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "1"}], "1", "0", 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "2"}], "0", 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "1"}], "0", 
      RowBox[{"-", "4"}]},
     {
      TagBox["\<\"R\"\>",
       HoldForm], 
      RowBox[{"-", "1"}], "5", "0", 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "3"}], "1", "0", 
      RowBox[{"-", "2"}], "0", 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "2"}], "2", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "1"}], "0", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "4"}]},
     {
      TagBox["\<\"N\"\>",
       HoldForm], 
      RowBox[{"-", "2"}], "0", "6", "1", 
      RowBox[{"-", "3"}], "0", "0", "0", "1", 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "3"}], "0", 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "2"}], "1", "0", 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "3"}], "3", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "4"}]},
     {
      TagBox["\<\"D\"\>",
       HoldForm], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "2"}], "1", "6", 
      RowBox[{"-", "3"}], "0", "2", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "1"}], "0", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "3"}], "4", "1", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "4"}]},
     {
      TagBox["\<\"C\"\>",
       HoldForm], "0", 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "3"}], "9", 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "4"}]},
     {
      TagBox["\<\"Q\"\>",
       HoldForm], 
      RowBox[{"-", "1"}], "1", "0", "0", 
      RowBox[{"-", "3"}], "5", "2", 
      RowBox[{"-", "2"}], "0", 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "2"}], "1", "0", 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "1"}], "0", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "2"}], "0", "3", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "4"}]},
     {
      TagBox["\<\"E\"\>",
       HoldForm], 
      RowBox[{"-", "1"}], "0", "0", "2", 
      RowBox[{"-", "4"}], "2", "5", 
      RowBox[{"-", "2"}], "0", 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "3"}], "1", 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "1"}], "0", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "2"}], "1", "4", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "4"}]},
     {
      TagBox["\<\"G\"\>",
       HoldForm], "0", 
      RowBox[{"-", "2"}], "0", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "2"}], "6", 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "2"}], "0", 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "4"}]},
     {
      TagBox["\<\"H\"\>",
       HoldForm], 
      RowBox[{"-", "2"}], "0", "1", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "3"}], "0", "0", 
      RowBox[{"-", "2"}], "8", 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "2"}], "2", 
      RowBox[{"-", "3"}], "0", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "4"}]},
     {
      TagBox["\<\"I\"\>",
       HoldForm], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "3"}], "4", "2", 
      RowBox[{"-", "3"}], "1", "0", 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "1"}], "3", 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "4"}]},
     {
      TagBox["\<\"L\"\>",
       HoldForm], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "3"}], "2", "4", 
      RowBox[{"-", "2"}], "2", "0", 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "4"}]},
     {
      TagBox["\<\"K\"\>",
       HoldForm], 
      RowBox[{"-", "1"}], "2", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "3"}], "1", "1", 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "2"}], "5", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "1"}], "0", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "2"}], "0", "1", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "4"}]},
     {
      TagBox["\<\"M\"\>",
       HoldForm], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "1"}], "0", 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "2"}], "1", "2", 
      RowBox[{"-", "1"}], "5", "0", 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "4"}]},
     {
      TagBox["\<\"F\"\>",
       HoldForm], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "1"}], "0", "0", 
      RowBox[{"-", "3"}], "0", "6", 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "2"}], "1", "3", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "4"}]},
     {
      TagBox["\<\"P\"\>",
       HoldForm], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "4"}], "7", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "4"}]},
     {
      TagBox["\<\"S\"\>",
       HoldForm], "1", 
      RowBox[{"-", "1"}], "1", "0", 
      RowBox[{"-", "1"}], "0", "0", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "2"}], "0", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "1"}], "4", "1", 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "2"}], "0", "0", "0", 
      RowBox[{"-", "4"}]},
     {
      TagBox["\<\"T\"\>",
       HoldForm], "0", 
      RowBox[{"-", "1"}], "0", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "1"}], "1", "5", 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "2"}], "0", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "0", 
      RowBox[{"-", "4"}]},
     {
      TagBox["\<\"W\"\>",
       HoldForm], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "2"}], "11", "2", 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "4"}]},
     {
      TagBox["\<\"Y\"\>",
       HoldForm], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "3"}], "2", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "1"}], "3", 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "2"}], "2", "7", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "4"}]},
     {
      TagBox["\<\"V\"\>",
       HoldForm], "0", 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "3"}], "3", "1", 
      RowBox[{"-", "2"}], "1", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "2"}], "0", 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "1"}], "4", 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "4"}]},
     {
      TagBox["\<\"B\"\>",
       HoldForm], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "1"}], "3", "4", 
      RowBox[{"-", "3"}], "0", "1", 
      RowBox[{"-", "1"}], "0", 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "4"}], "0", 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "2"}], "0", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "3"}], "4", "1", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "4"}]},
     {
      TagBox["\<\"Z\"\>",
       HoldForm], 
      RowBox[{"-", "1"}], "0", "0", "1", 
      RowBox[{"-", "3"}], "3", "4", 
      RowBox[{"-", "2"}], "0", 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "3"}], "1", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "1"}], "0", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "2"}], "1", "4", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "4"}]},
     {
      TagBox["\<\"X\"\>",
       HoldForm], "0", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "2"}], "0", "0", 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "4"}]},
     {
      TagBox["\<\"*\"\>",
       HoldForm], 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "4"}], "1"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Right}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.16]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {{
      "A", "R", "N", "D", "C", "Q", "E", "G", "H", "I", "L", "K", "M", "F", 
       "P", "S", "T", "W", "Y", "V", "B", "Z", "X", "*"}, {
      "A", "R", "N", "D", "C", "Q", "E", "G", "H", "I", "L", "K", "M", "F", 
       "P", "S", "T", "W", "Y", "V", "B", "Z", "X", "*"}}, TableSpacing -> 
    0.4, TableAlignments -> Right]]]], "Output",
 CellChangeTimes->{3.6775716898283195`*^9}]
}, Open  ]],

Cell[TextData[{
 "Abbildung 3.2 zeigt diese Darstellung der BLOSUM62-Substitutionsmatrix. Wir \
werden nun die beiden Beispielsequenzen diskutieren. Der Befehl ",
 StyleBox["Characters[]",
  FontWeight->"Bold"],
 " zerlegt dabei die als Zeichenkette eingetragenen Sequenzen in ihre \
Einzelsymbole."
}], "Text",
 CellChangeTimes->{{3.6746320181358204`*^9, 3.6746320358418465`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"prot1", "=", 
   RowBox[{"Characters", "[", "\"\<KEFHNGHT\>\"", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"prot2", "=", 
    RowBox[{"Characters", "[", "\"\<KYFHKAGNGHSPT\>\"", "]"}]}], ";"}], 
  " "}]}], "Input",
 CellChangeTimes->{3.676195287770979*^9}],

Cell[TextData[{
 "Als Erstes ben\[ODoubleDot]tigen wir nun eine Funktion, die zu zwei \
gegebenen Symbolen den entsprechenden Eintrag aus der Substitutionsmatrix \
extrahiert. Dies geschieht einfach mit dem Befehl ",
 StyleBox["Part[...] ",
  FontWeight->"Bold"],
 "oder seiner Kurzform ",
 StyleBox["[[]]",
  FontWeight->"Bold"],
 ". Allerdings ist der Umweg \[UDoubleDot]ber die Labels ",
 StyleBox["proteinRef",
  FontWeight->"Bold"],
 " der Substitutionsmatrix ",
 StyleBox["blosum",
  FontWeight->"Bold"],
 " zu beachten: Man hat ein Symbol aus der ersten Sequenz, s1, und ein Symbol \
aus der zweiten Sequenz, s2, gegeben und ben\[ODoubleDot]tigt nun die \
Position dieser Symbole in der Label-Liste ",
 StyleBox["proteinRef",
  FontWeight->"Bold"],
 ". Dies geschieht jeweils mit ",
 StyleBox["Position[proteinRef, si]",
  FontWeight->"Bold"],
 ", wobei allerdings der ",
 StyleBox["Part",
  FontWeight->"Bold"],
 "-Befehl noch erforderlich ist, um unn\[ODoubleDot]tige Klammern zu \
vermeiden. Mit diesen Zahlen kann man nun das Element aus der \
Substitutionsmatrix ansprechen. F\[UDoubleDot]r die folgende Untersuchung ist \
es w\[UDoubleDot]nschenswert, diesen Prozess in einer Funktion abzulegen. Wir \
werden hier eine sehr allgemeine Fassung dieser Funktion formulieren, die als \
Argumente (also als frei zu spezifizierende Parameter) nicht nur die beiden \
Symbole selbst (dies w\[ADoubleDot]re der elementarste Fall einer solchen \
Funktion) hat, sondern auch die Label-Liste und die Substitutionsmatrix. Auf \
diese Weise ist es nicht erforderlich, die Variablennamen ",
 StyleBox["proteinRef",
  FontWeight->"Bold"],
 " und ",
 StyleBox["blosum",
  FontWeight->"Bold"],
 " beizubehalten; sie werden im Inneren der Funktion nicht verwendet. Eine \
weitere Abweichung von der naheliegenden Realisierung der Funktion wird sein, \
statt die beiden Symbole direkt als Argument zuzulassen, die gesamten \
Sequenzen und die beiden Positionen der Symbole in den Sequenzen an die \
Funktion zu \[UDoubleDot]bergeben. Der Vorteil dieses scheinbar viel \
komplizierteren Konstrukts liegt darin, im Folgenden die Positionen als \
Laufindizes in einer Schleife verwenden zu k\[ODoubleDot]nnen. Die Definition \
dieser Funktion ",
 StyleBox["coordFun",
  FontWeight->"Bold"],
 " erfolgt wie gewohnt mithilfe der ",
 StyleBox["Module",
  FontWeight->"Bold"],
 "-Umgebung. Zuerst werden die beiden Symbole in tempor\[ADoubleDot]re \
Variablen geschrieben (z.B. ",
 StyleBox["tmp1 = seq1[[posA]]",
  FontWeight->"Bold"],
 "); dann wird die Position dieser Symbole in der Label-Liste abgefragt (",
 StyleBox["tmp3 = Position[ref, tmp1][[1, 1]]",
  FontWeight->"Bold"],
 "; wie zuvor eliminiert der ",
 StyleBox["Part",
  FontWeight->"Bold"],
 "-Befehl, ",
 StyleBox["...[[1, 1]]",
  FontWeight->"Bold"],
 " st\[ODoubleDot]rende Klammern); schlie\[SZ]lich k\[ODoubleDot]nnen diese \
beiden Positionen zum Zugriff auf das Matrixelement verwendet werden. \
Insgesamt hat man:"
}], "Text",
 CellChangeTimes->{{3.674632234980142*^9, 3.674632241627152*^9}, 
   3.6746323582273283`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"coordFun", "[", 
   RowBox[{
   "ref_", ",", "seq1_", ",", "seq2_", ",", "posA_", ",", "posB_", ",", 
    "mat_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"tmp1", ",", "tmp2", ",", "tmp3", ",", "tmp4"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"tmp1", "=", 
      RowBox[{"seq1", "[", 
       RowBox[{"[", "posA", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"tmp2", "=", 
      RowBox[{"seq2", "[", 
       RowBox[{"[", "posB", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"tmp3", "=", 
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{"ref", ",", "tmp1"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"tmp4", "=", 
      RowBox[{
       RowBox[{"Position", "[", 
        RowBox[{"ref", ",", "tmp2"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"mat", "[", 
      RowBox[{"[", 
       RowBox[{"tmp3", ",", "tmp4"}], "]"}], "]"}]}]}], "]"}]}]], "Input"],

Cell["\<\
Will man z.B. unter den vorliegenden Variablenbezeichnungen den Eintrag der \
Substitutionsmatrix ermitteln, der den Score f\[UDoubleDot]r eine Paarung des \
jeweils zweiten Symbols der Sequenzen angibt, so geschieht dies mit dem \
Befehl:\
\>", "Text",
 CellChangeTimes->{{3.674632423361427*^9, 3.674632438020451*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"coordFun", "[", 
  RowBox[{
  "proteinRef", ",", "prot1", ",", "prot2", ",", "2", ",", "2", ",", 
   "blosum"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"-", "2"}]], "Output",
 CellChangeTimes->{3.67757168992192*^9}]
}, Open  ]],

Cell[TextData[{
 "Die etwas aufwendige Gestaltung unserer Funktion ",
 StyleBox["coordFun",
  FontWeight->"Bold"],
 " erweist sich nun als vorteilhaft. Durch die Verwendung der \
Symbolpositionen k\[ODoubleDot]nnen wir unmittelbar eine Matrix anlegen, die \
zu jedem Symbolpaar der beiden Sequenzen den entsprechenden Score enth\
\[ADoubleDot]lt. Dies erreichen wir mit dem Befehl ",
 StyleBox["Table",
  FontWeight->"Bold"],
 " und zwei Laufindizes, die jeweils von 1 bis zur L\[ADoubleDot]nge der \
Sequenz (z.B. ",
 StyleBox["Length[prot1]",
  FontWeight->"Bold"],
 ") laufen."
}], "Text",
 CellChangeTimes->{{3.674632452533473*^9, 3.6746324576914806`*^9}, {
  3.674632496679538*^9, 3.6746325253475833`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"coordTab", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"coordFun", "[", 
      RowBox[{
      "proteinRef", ",", "prot1", ",", "prot2", ",", "i", ",", "j", ",", 
       "blosum"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "prot1", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"Length", "[", "prot2", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[TextData[{
 "Die Ausgabe erfolgt dann \[UDoubleDot]ber den Formatierungsbefehl ",
 StyleBox["TableForm",
  FontWeight->"Bold"],
 ". Dabei verwenden wir die beiden Sequenzen noch zur Bezeichnung der Zeilen \
und Spalten (mit ",
 StyleBox["TableHeadings",
  FontWeight->"Bold"],
 "), legen den Abstand der einzelnen Eintr\[ADoubleDot]ge fest (mit ",
 StyleBox["TableSpacing",
  FontWeight->"Bold"],
 ") und erzwingen zudem (mit ",
 StyleBox["TableAlignments",
  FontWeight->"Bold"],
 ") eine rechtsb\[UDoubleDot]ndige Ausgabe."
}], "Text",
 CellChangeTimes->{{3.6746325666126437`*^9, 3.6746325794816637`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{"coordTab", ",", " ", 
   RowBox[{"TableHeadings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"prot1", ",", "prot2"}], "}"}]}], ",", 
   RowBox[{"TableSpacing", "\[Rule]", "1"}], ",", 
   RowBox[{"TableAlignments", "\[Rule]", "Right"}]}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      StyleBox["\[Null]",
       ShowStringCharacters->False], 
      TagBox["\<\"K\"\>",
       HoldForm], 
      TagBox["\<\"Y\"\>",
       HoldForm], 
      TagBox["\<\"F\"\>",
       HoldForm], 
      TagBox["\<\"H\"\>",
       HoldForm], 
      TagBox["\<\"K\"\>",
       HoldForm], 
      TagBox["\<\"A\"\>",
       HoldForm], 
      TagBox["\<\"G\"\>",
       HoldForm], 
      TagBox["\<\"N\"\>",
       HoldForm], 
      TagBox["\<\"G\"\>",
       HoldForm], 
      TagBox["\<\"H\"\>",
       HoldForm], 
      TagBox["\<\"S\"\>",
       HoldForm], 
      TagBox["\<\"P\"\>",
       HoldForm], 
      TagBox["\<\"T\"\>",
       HoldForm]},
     {
      TagBox["\<\"K\"\>",
       HoldForm], "5", 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "1"}], "5", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "2"}], "0", 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "1"}], "0", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}]},
     {
      TagBox["\<\"E\"\>",
       HoldForm], "1", 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "3"}], "0", "1", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "2"}], "0", 
      RowBox[{"-", "2"}], "0", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}]},
     {
      TagBox["\<\"F\"\>",
       HoldForm], 
      RowBox[{"-", "3"}], "3", "6", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "2"}]},
     {
      TagBox["\<\"H\"\>",
       HoldForm], 
      RowBox[{"-", "1"}], "2", 
      RowBox[{"-", "1"}], "8", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "2"}], "1", 
      RowBox[{"-", "2"}], "8", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "2"}]},
     {
      TagBox["\<\"N\"\>",
       HoldForm], "0", 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "3"}], "1", "0", 
      RowBox[{"-", "2"}], "0", "6", "0", "1", "1", 
      RowBox[{"-", "2"}], "0"},
     {
      TagBox["\<\"G\"\>",
       HoldForm], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "2"}], "0", "6", "0", "6", 
      RowBox[{"-", "2"}], "0", 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "2"}]},
     {
      TagBox["\<\"H\"\>",
       HoldForm], 
      RowBox[{"-", "1"}], "2", 
      RowBox[{"-", "1"}], "8", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "2"}], "1", 
      RowBox[{"-", "2"}], "8", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "2"}]},
     {
      TagBox["\<\"T\"\>",
       HoldForm], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "1"}], "0", 
      RowBox[{"-", "2"}], "0", 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "2"}], "1", 
      RowBox[{"-", "1"}], "5"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Right}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {{"K", "E", "F", "H", "N", "G", "H", "T"}, {
      "K", "Y", "F", "H", "K", "A", "G", "N", "G", "H", "S", "P", "T"}}, 
    TableSpacing -> 1, TableAlignments -> Right]]]], "Output",
 CellChangeTimes->{3.6775716899531193`*^9}]
}, Open  ]],

Cell["\<\
Eine solche Tabelle k\[ODoubleDot]nnte eine erste Orientierung bei einer \
Nachbearbeitung eines Alignments von Hand (etwa die Auswahl von \
Teilsequenzen) liefern.
\
\>", "Text",
 CellChangeTimes->{{3.6746326055587053`*^9, 3.674632630654744*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-Exkurs: ",
 "Needleman-Wunsch-Verfahren"
}], "Subtitle",
 CellChangeTimes->{3.670321495640956*^9, 3.670402706588908*^9, 
  3.670402787620543*^9},
 Background->RGBColor[
  0.8705882352941177, 0.00392156862745098, 0.2196078431372549]],

Cell[TextData[{
 "Die Initialisierung der ",
 StyleBox["F",
  FontSlant->"Italic"],
 "-Matrix f\[UDoubleDot]r das Needleman-Wunsch-Verfahren erfolgt durch Einf\
\[UDoubleDot]gen einer nullten Zeile und Spalte, die den kumulierten \
Gap-Penalty als Eintr\[ADoubleDot]ge enthalten. Zuerst legen wir den \
Gap-Penalty fest:"
}], "Text",
 CellChangeTimes->{{3.6746326699688025`*^9, 3.6746326785558157`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"gP", "=", "5"}], ";"}], " "}]], "Input"],

Cell[TextData[{
 "Dabei ist klar, dass wir in einer sp\[ADoubleDot]teren Funktion, die das \
gesamte Needleman-Wunsch-Verfahren umfasst, diesen Parameter als Argument \
frei angeben wollen. Dazu kommen wir aber sp\[ADoubleDot]ter. Als N\
\[ADoubleDot]chstes legen wir die Initialisierungseintr\[ADoubleDot]ge der ",
 StyleBox["F",
  FontSlant->"Italic"],
 "-Matrix fest. Wir haben uns als Format dieser ",
 StyleBox["F",
  FontSlant->"Italic"],
 "-Matrix-Elemente f\[UDoubleDot]r ein Zahlenpaar entschieden: Der erste \
Eintrag gibt das tats\[ADoubleDot]chliche Matrixelement an, \
w\[ADoubleDot]hrend der zweite Eintrag den Zeiger darstellt, der codiert, aus \
welchem vorangehenden Matrixelement das vorliegende Element in der Rekursion \
seinen Wert erhalten hat. Dabei verwenden wir einen Zahlencode \
f\[UDoubleDot]r den Zeiger: 1 = \[OpenCurlyQuote]diagonal\[CloseCurlyQuote], \
2 = \[OpenCurlyQuote]oben\[CloseCurlyQuote] und 3 = \[OpenCurlyQuote]links\
\[CloseCurlyQuote]. Den Zustand 0 verwenden wir (im oberen linken \
Matrixelement) f\[UDoubleDot]r das Fehlen eines Zeigerzustands."
}], "Text",
 CellChangeTimes->{{3.6746327009008503`*^9, 3.674632705294857*^9}, {
  3.674632760019945*^9, 3.6746327808489795`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"matF", "[", 
    RowBox[{"0", ",", "0"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{3.6238210335450163`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"matF", "[", 
    RowBox[{"i_", ",", "0"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "i"}], "*", "gP"}], ",", "2"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{3.6238210344351397`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"matF", "[", 
    RowBox[{"0", ",", "j_"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "j"}], "*", "gP"}], ",", "3"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{3.6238210353570957`*^9}],

Cell[TextData[{
 "Zur Rekursion verwenden wir eine ",
 StyleBox["Do",
  FontWeight->"Bold"],
 "-Schleife. Im Inneren der Schleife steht dabei einfach die Maximumsabfrage \
zwischen den drei vorangehenden (mit Score und Gap-Penalty verrechneten) \
Matrixeintr\[ADoubleDot]gen, so wie wir es bereits kennengelernt haben. Da \
wir diese Maximumsabfrage sowohl zur Ermittlung des Matrixelements als auch \
zur Zeigerbestimmung ben\[ODoubleDot]tigen, legen wir die dreielementige \
Liste in einer Variablen ",
 StyleBox["tmp1",
  FontWeight->"Bold"],
 " ab, um dann zur Festlegung des Matrixelements darauf zuzugreifen. Zudem \
ist noch zu beachten, dass durch die zweielementige Struktur der \
F-Matrix-Eintr\[ADoubleDot]ge die Gr\[ODoubleDot]\[SZ]e ",
 StyleBox["matF[i, j][[1]]",
  FontWeight->"Bold"],
 " den tats\[ADoubleDot]chlichen Matrixeintrag liefert und ",
 StyleBox["matF[i, j][[2]]",
  FontWeight->"Bold"],
 " den zugeh\[ODoubleDot]rigen Wert der Zeigervariablen ausgibt."
}], "Text",
 CellChangeTimes->{{3.6746328582721014`*^9, 3.674632890654154*^9}}],

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"tmp1", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"matF", "[", 
           RowBox[{
            RowBox[{"i", "-", "1"}], ",", 
            RowBox[{"j", "-", "1"}]}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "+", 
         RowBox[{"coordFun", "[", 
          RowBox[{
          "proteinRef", ",", "prot1", ",", "prot2", ",", "i", ",", "j", ",", 
           "blosum"}], "]"}]}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"matF", "[", 
           RowBox[{
            RowBox[{"i", "-", "1"}], ",", "j"}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "gP"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"matF", "[", 
           RowBox[{"i", ",", 
            RowBox[{"j", "-", "1"}]}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "gP"}]}], 
       "\[IndentingNewLine]", "}"}]}], ";", " ", "\[IndentingNewLine]", " ", 
     RowBox[{
      RowBox[{"matF", "[", 
       RowBox[{"i", ",", "j"}], "]"}], "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Max", "[", "tmp1", "]"}], ",", 
        RowBox[{
         RowBox[{"Position", "[", 
          RowBox[{"tmp1", ",", 
           RowBox[{"Max", "[", "tmp1", "]"}]}], "]"}], "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "}"}]}]}], 
    "\[IndentingNewLine]", "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "1", ",", 
     RowBox[{"Length", "[", "prot1", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "1", ",", 
     RowBox[{"Length", "[", "prot2", "]"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.623821039857704*^9, 3.623821042913952*^9}}],

Cell[TextData[{
 "Wie gewohnt stehen die einzelnen Befehle der ",
 StyleBox["Do",
  FontWeight->"Bold"],
 "-Schleife als Liste in geschweiften Klammern. Deutlich zu erkennen ist \
auch, dass jedes Matrixelement ",
 StyleBox["matF[i, j]",
  FontWeight->"Bold"],
 " als zweielementige Liste definiert wird (mit dem tats\[ADoubleDot]chlichen \
Matrixeintrag als erstes Element und dem Zeiger als zweites Element). \
Interessant ist noch die Zeigergewinnung: Wir haben die dreielementige Liste \
so organisiert, dass die Elementposition dem oben eingef\[UDoubleDot]hrten \
Code des Zeigers entspricht: Liefert das erste Element das Maximum, so ist \
der Zeigerzustand gerade 1 (\[OpenCurlyQuote]diagonal\[CloseCurlyQuote]) und \
so fort. Auf diese Weise l\[ADoubleDot]sst sich der Zeigerzustand recht \
elegant durch ",
 StyleBox["Position[tmp1, Max[tmp1]] ",
  FontWeight->"Bold"],
 "ermitteln. Wir wenden uns nun der Ausgabe des Ergebnisses zu. Das Ziel ist, \
die ",
 StyleBox["F",
  FontSlant->"Italic"],
 "-Matrix abzubilden, die Zeiger als Pfeile einzutragen und schlie\[SZ]lich \
den optimalen Pfad, der sich durch Zur\[UDoubleDot]ckverfolgen (Traceback) \
vom rechten unteren Matrixelement aus ergibt, zu gewinnen. In einem zweiten \
Schritt werden wir die Ausgabe dieser Nebenrechnungen \
unterdr\[UDoubleDot]cken und nur das tats\[ADoubleDot]chliche Alignment der \
beiden Sequenzen ausgeben. Legen wir zuerst die in der ",
 StyleBox["Do",
  FontWeight->"Bold"],
 "-Schleife berechneten Matrixelemente in einer Tabelle ab:"
}], "Text",
 CellChangeTimes->{{3.6746329162501917`*^9, 3.674632921244199*^9}, {
  3.6746329994713163`*^9, 3.6746330266363583`*^9}, {3.6746330918264604`*^9, 
  3.6746330924064612`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"matFTab", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"matF", "[", 
      RowBox[{"i", ",", "j"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", 
       RowBox[{"Length", "[", "prot1", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "0", ",", 
       RowBox[{"Length", "[", "prot2", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{
  3.5687175155*^9, {3.623821044904704*^9, 3.6238210458688307`*^9}, 
   3.674633462046032*^9}],

Cell[TextData[{
 "Durch Anwenden von Substitutionsregeln, bei denen jedes Elementpaar ",
 StyleBox["{n1, n2}",
  FontWeight->"Bold"],
 " entweder durch nur das erste oder nur das zweite Element ersetzt wird, \
teilen wir die Tabelle in zwei getrennte Tabellen f\[UDoubleDot]r die \
Matrixelemente und die Zeigerzust\[ADoubleDot]nde auf."
}], "Text",
 CellChangeTimes->{{3.674633129394518*^9, 3.674633140660537*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"matFTabA", "=", 
   RowBox[{"matFTab", "/.", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n1_", ",", "n2_Integer"}], "}"}], "\[Rule]", " ", "n1"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"matFTabB", "=", 
   RowBox[{"matFTab", "/.", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n1_", ",", "n2_Integer"}], "}"}], "\[Rule]", " ", "n2"}]}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.5687175220625*^9, 3.56871752621875*^9}, {
  3.623821046974214*^9, 3.6238210493541117`*^9}, {3.674633455465021*^9, 
  3.6746334578370247`*^9}}],

Cell[TextData[{
 "Man erkennt auch hier wieder das zentrale Ordnungsprinzip der \
Substitutionsregeln in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", so wie wir es bereits in Kap. 1.5 diskutiert haben: Der Unterstrich \
(engl. ",
 StyleBox["underscore",
  FontSlant->"Italic",
  FontColor->GrayLevel[0]],
 ", _) bezeichnet ein beliebiges Element; auf der linken Seite kann man \
diesem beliebigen Element einen Namen zuweisen, falls man darauf noch einmal \
im Rahmen der Substitutionsregel zugreifen will (z.B. ",
 StyleBox["n1_",
  FontWeight->"Bold"],
 "); auf der rechten Seite kann das Element n\[ADoubleDot]her charakterisiert \
werden, so dass die Substitutionsregel nur auf Elemente mit einer bestimmten \
Eigenschaft angewendet wird (z.B. ",
 StyleBox["_Integer",
  FontWeight->"Bold"],
 ", wenn man nur ganzzahlige Elemente diskutieren m\[ODoubleDot]chte). In \
unserem Fall wurde die Spezifizierung des zweiten Eintrags in diesem Paar \
(also ",
 StyleBox["n2_Integer",
  FontWeight->"Bold"],
 ") zur Sicherheit vorgenommen, da die Ersetzungsregel sonst im Extremfall \
von Sequenzen der L\[ADoubleDot]nge 2, die zum Alignment gebracht werden \
sollen, auf der Ebene der gesamten Liste operieren w\[UDoubleDot]rde: Auch \
ein Objekt ",
 StyleBox["{liste1, liste2}",
  FontWeight->"Bold"],
 " erf\[UDoubleDot]llt das Schema ",
 StyleBox["{n1_, n2_}",
  FontWeight->"Bold"],
 " und w\[UDoubleDot]rde z.B. komplett durch ",
 StyleBox["liste1",
  FontWeight->"Bold"],
 " ersetzt; es erf\[UDoubleDot]llt aber nicht das Schema ",
 StyleBox["{n1_, n2_Integer}",
  FontWeight->"Bold"],
 ". \n\nDas Ziel einer angemessen formatierten Ausgabe dieser Matrix \
verbinden wirmit der Gew\[ODoubleDot]hnung an einige etwas fortgeschrittenere \
Grafikbefehle. Die Alternative w\[ADoubleDot]re, die Darstellung mit dem \
Befehl ",
 StyleBox["TableForm[]",
  FontWeight->"Bold"],
 " und den dort verf\[UDoubleDot]gbaren Formatierungsoptionen zu erreichen. \
Hier wollen wir den Weg gehen, die Eintr\[ADoubleDot]ge in Grafikelemente zu \
verwandeln. W\[ADoubleDot]hrend beim ",
 StyleBox["Plot",
  FontWeight->"Bold"],
 "-Befehl eine konkrete mathematische Funktion dargestellt wird, erlaubt die ",
 StyleBox["Graphics",
  FontWeight->"Bold"],
 "-Umgebung die Umsetzung sehr allgemeiner Grafikelemente. Typische Elemente \
sind Liniensegmente (mit dem Befehl ",
 StyleBox["Line[punkt1, punkt2, ...]",
  FontWeight->"Bold"],
 "), Punkte (mit ",
 StyleBox["Point[koordinate]",
  FontWeight->"Bold"],
 ") oder platzierter Text (mit ",
 StyleBox["Text[textsegment, koordinate]",
  FontWeight->"Bold"],
 "). Dargestellt werden solche Elemente dann mit der Kombination ",
 StyleBox["Show[Graphics[grafikbefehle]]",
  FontWeight->"Bold"],
 ". \n\nDie hier angestrebte Grafik besteht aus drei Segmenten: In ",
 StyleBox["p1",
  FontWeight->"Bold"],
 " wird jeder Eintrag von ",
 StyleBox["matFTabA",
  FontWeight->"Bold"],
 " als Text an einem zugeh\[ODoubleDot]rigen Punkt des Grafikfensters \
platziert. F\[UDoubleDot]r das (",
 StyleBox["i",
  FontSlant->"Italic"],
 ",",
 StyleBox[" j",
  FontSlant->"Italic"],
 ")-te Element lautet dieser Befehl ",
 StyleBox["Text[matFTabA[[i, j]], {j, dim1- (i - 1)}]",
  FontWeight->"Bold"],
 ", wobei ",
 StyleBox["dim1",
  FontWeight->"Bold"],
 " als Abk\[UDoubleDot]rzung f\[UDoubleDot]r ",
 StyleBox["Dimensions[matFTabA][[1]]",
  FontWeight->"Bold"],
 " verwendet wurde (vgl. die folgenden Befehlszeilen). Man erkennt an der \
zweiten Koordinate, dass man das unterschiedliche Koordinatensystem von \
Matrizen (der \[OpenCurlyQuote]Nullpunkt\[CloseCurlyQuote] liegt oben links) \
und Grafiken (der Nullpunkt liegt unten links) zu ber\[UDoubleDot]cksichtigen \
hat. Bemerkenswerterweise lassen sich diese Grafikbefehle ",
 StyleBox["Text[]",
  FontWeight->"Bold"],
 " zu jedem Matrixelement wiederummit ",
 StyleBox["Table[]",
  FontWeight->"Bold"],
 " als Tabelle strukturieren und durch einen ",
 StyleBox["Show[Graphics[]]",
  FontWeight->"Bold"],
 "-Befehl darstellen. Mit ",
 StyleBox["p2",
  FontWeight->"Bold"],
 " und ",
 StyleBox["p3",
  FontWeight->"Bold"],
 " werden die Achsenbeschriftungen bereitgestellt. Dazu verwenden wir erneut \
die Symbolsequenzen ",
 StyleBox["prot1",
  FontWeight->"Bold"],
 " und ",
 StyleBox["prot2",
  FontWeight->"Bold"],
 " als Zeichenketten, die in den Text-Befehl eingesetzt werden.Mit ",
 StyleBox["Prepend[]",
  FontWeight->"Bold"],
 " werden Leerzeichen vor jede Sequenz gesetzt, mit dem Befehl ",
 StyleBox["Rectangle[]",
  FontWeight->"Bold"],
 ", einer entsprechenden, von Hand getroffenen Koordinatenwahl und der \
Formatierungsanweisung ",
 StyleBox["GrayLevel[0.9]",
  FontWeight->"Bold"],
 " werden diese Achsenbeschriftungen noch grau hinterlegt. \
Zun\[ADoubleDot]chst werden die Grafikausgaben unterdr\[UDoubleDot]ckt, um \
sie dann etwas sp\[ADoubleDot]ter gemeinsam darzustellen. Zu Beginn legen wir \
noch einige Abk\[UDoubleDot]rzungen f\[UDoubleDot]r mehrfach auftretende \
Dimensionsabfragen an."
}], "Text",
 CellChangeTimes->{{3.674633441550999*^9, 3.6746334499370117`*^9}, 
   3.6746335022280936`*^9, {3.6746335482701664`*^9, 3.6746335568521786`*^9}, {
   3.6746336948263903`*^9, 3.674633714310418*^9}, {3.674633842537608*^9, 
   3.6746338430176086`*^9}, 3.677494394395488*^9, 3.677494448938184*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dim1", "=", 
   RowBox[{
    RowBox[{"Dimensions", "[", "matFTabA", "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dim2", "=", 
   RowBox[{
    RowBox[{"Dimensions", "[", "matFTabA", "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"len1", "=", 
   RowBox[{"Length", "[", "prot1", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"len2", "=", 
   RowBox[{"Length", "[", "prot2", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p1", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"Graphics", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"matFTabA", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "j"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", 
           RowBox[{"dim1", "-", 
            RowBox[{"(", 
             RowBox[{"i", "-", "1"}], ")"}]}]}], "}"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "dim1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "1", ",", "dim2"}], "}"}]}], "]"}], "]"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"p2", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"Graphics", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"GrayLevel", "[", "0.9", "]"}], ",", 
         RowBox[{"Rectangle", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "0.5"}], ",", "0.5"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0.5", ",", 
             RowBox[{"len1", "+", "2.5"}]}], "}"}]}], "]"}]}], "}"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Text", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Prepend", "[", 
             RowBox[{"prot1", ",", "\"\< \>\""}], "]"}], "[", 
            RowBox[{"[", "j", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", 
             RowBox[{"len1", "+", "1", "-", 
              RowBox[{"(", 
               RowBox[{"j", "-", "1"}], ")"}]}]}], "}"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "1", ",", 
           RowBox[{"len1", "+", "1"}]}], "}"}]}], "]"}]}], "}"}], "]"}], 
    "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"p3", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"Graphics", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"GrayLevel", "[", "0.9", "]"}], ",", 
         RowBox[{"Rectangle", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0.5", ",", 
             RowBox[{"len1", "+", "1.5"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"len2", "+", "1.5"}], ",", 
             RowBox[{"len1", "+", "2.5"}]}], "}"}]}], "]"}]}], "}"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Text", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Prepend", "[", 
             RowBox[{"prot2", ",", "\"\< \>\""}], "]"}], "[", 
            RowBox[{"[", "j", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", 
             RowBox[{"len1", "+", "2"}]}], "}"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "1", ",", 
           RowBox[{"len2", "+", "1"}]}], "}"}]}], "]"}]}], "}"}], "]"}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5687166545*^9, 3.568716669*^9}, {3.56871754475*^9, 
  3.568717611984375*^9}, {3.623821055590453*^9, 3.623821056948111*^9}, {
  3.623821302595067*^9, 3.6238213786683283`*^9}, {3.623821418632783*^9, 
  3.623821429231941*^9}, {3.623821472590311*^9, 3.623821473316827*^9}}],

Cell[TextData[{
 "Die gemeinsame Ausgabe der Bestandteile erfolgt nun wie gewohnt mithilfe \
des ",
 StyleBox["Show",
  FontWeight->"Bold"],
 "-Befehls."
}], "Text",
 CellChangeTimes->{{3.674633861474636*^9, 3.6746339009186954`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p4", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"p3", ",", "p2", ",", "p1", ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.568716618765625*^9, 3.568716619296875*^9}}],

Cell[BoxData[
 GraphicsBox[{{
    {GrayLevel[0.9], RectangleBox[{0.5, 9.5}, {14.5, 10.5}]}, {
     InsetBox["\<\" \"\>", {1, 10}], InsetBox["\<\"K\"\>", {2, 10}], 
     InsetBox["\<\"Y\"\>", {3, 10}], InsetBox["\<\"F\"\>", {4, 10}], 
     InsetBox["\<\"H\"\>", {5, 10}], InsetBox["\<\"K\"\>", {6, 10}], 
     InsetBox["\<\"A\"\>", {7, 10}], InsetBox["\<\"G\"\>", {8, 10}], 
     InsetBox["\<\"N\"\>", {9, 10}], InsetBox["\<\"G\"\>", {10, 10}], 
     InsetBox["\<\"H\"\>", {11, 10}], InsetBox["\<\"S\"\>", {12, 10}], 
     InsetBox["\<\"P\"\>", {13, 10}], InsetBox["\<\"T\"\>", {14, 10}]}}, {
    {GrayLevel[0.9], RectangleBox[{-0.5, 0.5}, {0.5, 10.5}]}, {
     InsetBox["\<\" \"\>", {0, 9}], InsetBox["\<\"K\"\>", {0, 8}], 
     InsetBox["\<\"E\"\>", {0, 7}], InsetBox["\<\"F\"\>", {0, 6}], 
     InsetBox["\<\"H\"\>", {0, 5}], InsetBox["\<\"N\"\>", {0, 4}], 
     InsetBox["\<\"G\"\>", {0, 3}], InsetBox["\<\"H\"\>", {0, 2}], 
     InsetBox["\<\"T\"\>", {0, 1}]}}, {{InsetBox["0", {1, 9}], InsetBox[
      RowBox[{"-", "5"}], {2, 9}], InsetBox[
      RowBox[{"-", "10"}], {3, 9}], InsetBox[
      RowBox[{"-", "15"}], {4, 9}], InsetBox[
      RowBox[{"-", "20"}], {5, 9}], InsetBox[
      RowBox[{"-", "25"}], {6, 9}], InsetBox[
      RowBox[{"-", "30"}], {7, 9}], InsetBox[
      RowBox[{"-", "35"}], {8, 9}], InsetBox[
      RowBox[{"-", "40"}], {9, 9}], InsetBox[
      RowBox[{"-", "45"}], {10, 9}], InsetBox[
      RowBox[{"-", "50"}], {11, 9}], InsetBox[
      RowBox[{"-", "55"}], {12, 9}], InsetBox[
      RowBox[{"-", "60"}], {13, 9}], InsetBox[
      RowBox[{"-", "65"}], {14, 9}]}, {InsetBox[
      RowBox[{"-", "5"}], {1, 8}], InsetBox["5", {2, 8}], 
     InsetBox["0", {3, 8}], InsetBox[
      RowBox[{"-", "5"}], {4, 8}], InsetBox[
      RowBox[{"-", "10"}], {5, 8}], InsetBox[
      RowBox[{"-", "15"}], {6, 8}], InsetBox[
      RowBox[{"-", "20"}], {7, 8}], InsetBox[
      RowBox[{"-", "25"}], {8, 8}], InsetBox[
      RowBox[{"-", "30"}], {9, 8}], InsetBox[
      RowBox[{"-", "35"}], {10, 8}], InsetBox[
      RowBox[{"-", "40"}], {11, 8}], InsetBox[
      RowBox[{"-", "45"}], {12, 8}], InsetBox[
      RowBox[{"-", "50"}], {13, 8}], InsetBox[
      RowBox[{"-", "55"}], {14, 8}]}, {InsetBox[
      RowBox[{"-", "10"}], {1, 7}], InsetBox["0", {2, 7}], 
     InsetBox["3", {3, 7}], InsetBox[
      RowBox[{"-", "2"}], {4, 7}], InsetBox[
      RowBox[{"-", "5"}], {5, 7}], InsetBox[
      RowBox[{"-", "9"}], {6, 7}], InsetBox[
      RowBox[{"-", "14"}], {7, 7}], InsetBox[
      RowBox[{"-", "19"}], {8, 7}], InsetBox[
      RowBox[{"-", "24"}], {9, 7}], InsetBox[
      RowBox[{"-", "29"}], {10, 7}], InsetBox[
      RowBox[{"-", "34"}], {11, 7}], InsetBox[
      RowBox[{"-", "39"}], {12, 7}], InsetBox[
      RowBox[{"-", "44"}], {13, 7}], InsetBox[
      RowBox[{"-", "49"}], {14, 7}]}, {InsetBox[
      RowBox[{"-", "15"}], {1, 6}], InsetBox[
      RowBox[{"-", "5"}], {2, 6}], InsetBox["3", {3, 6}], 
     InsetBox["9", {4, 6}], InsetBox["4", {5, 6}], InsetBox[
      RowBox[{"-", "1"}], {6, 6}], InsetBox[
      RowBox[{"-", "6"}], {7, 6}], InsetBox[
      RowBox[{"-", "11"}], {8, 6}], InsetBox[
      RowBox[{"-", "16"}], {9, 6}], InsetBox[
      RowBox[{"-", "21"}], {10, 6}], InsetBox[
      RowBox[{"-", "26"}], {11, 6}], InsetBox[
      RowBox[{"-", "31"}], {12, 6}], InsetBox[
      RowBox[{"-", "36"}], {13, 6}], InsetBox[
      RowBox[{"-", "41"}], {14, 6}]}, {InsetBox[
      RowBox[{"-", "20"}], {1, 5}], InsetBox[
      RowBox[{"-", "10"}], {2, 5}], InsetBox[
      RowBox[{"-", "2"}], {3, 5}], InsetBox["4", {4, 5}], 
     InsetBox["17", {5, 5}], InsetBox["12", {6, 5}], InsetBox["7", {7, 5}], 
     InsetBox["2", {8, 5}], InsetBox[
      RowBox[{"-", "3"}], {9, 5}], InsetBox[
      RowBox[{"-", "8"}], {10, 5}], InsetBox[
      RowBox[{"-", "13"}], {11, 5}], InsetBox[
      RowBox[{"-", "18"}], {12, 5}], InsetBox[
      RowBox[{"-", "23"}], {13, 5}], InsetBox[
      RowBox[{"-", "28"}], {14, 5}]}, {InsetBox[
      RowBox[{"-", "25"}], {1, 4}], InsetBox[
      RowBox[{"-", "15"}], {2, 4}], InsetBox[
      RowBox[{"-", "7"}], {3, 4}], InsetBox[
      RowBox[{"-", "1"}], {4, 4}], InsetBox["12", {5, 4}], 
     InsetBox["17", {6, 4}], InsetBox["12", {7, 4}], InsetBox["7", {8, 4}], 
     InsetBox["8", {9, 4}], InsetBox["3", {10, 4}], InsetBox[
      RowBox[{"-", "2"}], {11, 4}], InsetBox[
      RowBox[{"-", "7"}], {12, 4}], InsetBox[
      RowBox[{"-", "12"}], {13, 4}], InsetBox[
      RowBox[{"-", "17"}], {14, 4}]}, {InsetBox[
      RowBox[{"-", "30"}], {1, 3}], InsetBox[
      RowBox[{"-", "20"}], {2, 3}], InsetBox[
      RowBox[{"-", "12"}], {3, 3}], InsetBox[
      RowBox[{"-", "6"}], {4, 3}], InsetBox["7", {5, 3}], 
     InsetBox["12", {6, 3}], InsetBox["17", {7, 3}], InsetBox["18", {8, 3}], 
     InsetBox["13", {9, 3}], InsetBox["14", {10, 3}], InsetBox["9", {11, 3}], 
     InsetBox["4", {12, 3}], InsetBox[
      RowBox[{"-", "1"}], {13, 3}], InsetBox[
      RowBox[{"-", "6"}], {14, 3}]}, {InsetBox[
      RowBox[{"-", "35"}], {1, 2}], InsetBox[
      RowBox[{"-", "25"}], {2, 2}], InsetBox[
      RowBox[{"-", "17"}], {3, 2}], InsetBox[
      RowBox[{"-", "11"}], {4, 2}], InsetBox["2", {5, 2}], 
     InsetBox["7", {6, 2}], InsetBox["12", {7, 2}], InsetBox["15", {8, 2}], 
     InsetBox["19", {9, 2}], InsetBox["14", {10, 2}], InsetBox["22", {11, 2}],
      InsetBox["17", {12, 2}], InsetBox["12", {13, 2}], 
     InsetBox["7", {14, 2}]}, {InsetBox[
      RowBox[{"-", "40"}], {1, 1}], InsetBox[
      RowBox[{"-", "30"}], {2, 1}], InsetBox[
      RowBox[{"-", "22"}], {3, 1}], InsetBox[
      RowBox[{"-", "16"}], {4, 1}], InsetBox[
      RowBox[{"-", "3"}], {5, 1}], InsetBox["2", {6, 1}], 
     InsetBox["7", {7, 1}], InsetBox["10", {8, 1}], InsetBox["15", {9, 1}], 
     InsetBox["17", {10, 1}], InsetBox["17", {11, 1}], 
     InsetBox["23", {12, 1}], InsetBox["18", {13, 1}], 
     InsetBox["17", {14, 1}]}}},
  PlotRange->All]], "Output",
 CellChangeTimes->{3.67757169028072*^9}]
}, Open  ]],

Cell["\<\
Dieses Grafikelement stellt die Basis f\[UDoubleDot]r Abb. 3.11 dar.

Der n\[ADoubleDot]chste Schritt besteht im Eintragen der Zeiger in diese \
Ausgabegrafik.\
\>", "Text",
 CellChangeTimes->{{3.6746339708688*^9, 3.674634026815886*^9}, {
   3.6775652397955914`*^9, 3.6775652424319963`*^9}, 3.677565709591417*^9}],

Cell["\<\
Erneut gibt es verschiedene Wege, dies zu realisieren. Eine elegante Variante \
w\[ADoubleDot]re, die Parameter des entsprechenden Grafikbefehls zur \
Erzeugung der Pfeile aus den Werten der Zeiger explizit zu berechnen. Aus Gr\
\[UDoubleDot]nden der \[CapitalUDoubleDot]bersichtlichkeit werden wir hier \
stattdessen drei unterschiedliche Pfeile, die den drei \
Zeigerzust\[ADoubleDot]nden entsprechen, definieren und die Position in der \
Matrix als Argumente des Grafikbefehls verwenden. F\[UDoubleDot]r den \
Zeigerzustand 1 hat man etwa:\
\>", "Text",
 CellChangeTimes->{{3.6775652469872046`*^9, 3.677565259826027*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"arrA", "[", 
   RowBox[{"ii_", ",", "jj_"}], "]"}], ":=", " ", 
  RowBox[{"Show", "[", 
   RowBox[{"Graphics", "[", 
    RowBox[{
     StyleBox["{", "Code"], 
     RowBox[{
      RowBox[{"Arrowheads", "[", "Small", "]"}], ",", 
      RowBox[{"Arrow", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"ii", "+", "0.8"}], ",", 
           RowBox[{
            RowBox[{"Length", "[", "prot1", "]"}], "+", "1.2", "-", 
            RowBox[{"(", "jj", ")"}]}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"ii", "+", "0.2"}], ",", 
           RowBox[{
            RowBox[{"Length", "[", "prot1", "]"}], "+", "1.8", "-", 
            RowBox[{"(", "jj", ")"}]}]}], "}"}]}], "}"}], "]"}]}], "}"}], 
    "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.577708979166664*^9, 3.577708979823925*^9}, {
   3.57770902526331*^9, 3.577709025485627*^9}, {3.5777093391396637`*^9, 
   3.577709351818097*^9}, {3.577709431697268*^9, 3.5777094404789143`*^9}, {
   3.577709505598864*^9, 3.5777095085412703`*^9}, 3.623822180184856*^9},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[TextData[{
 "Wie schon zuvor bei den Koordinaten des ",
 StyleBox["Text",
  FontWeight->"Bold"],
 "-Befehls ist die genaue Wahl der Skalierungsfaktoren und Koordinatenangaben \
rein empirisch durch Trial-and-Error ermittelt worden. Man erkennt, wie sich \
diese Koordinaten mit der Position in der Matrix (den Argumenten der Funktion \
",
 StyleBox["arrA",
  FontWeight->"Bold"],
 ") \[ADoubleDot]ndern. Die entsprechenden Befehle f\[UDoubleDot]r die beiden \
anderen Zust\[ADoubleDot]nde der Zeigervariablen lauten:  "
}], "Text",
 CellChangeTimes->{{3.6746340437619133`*^9, 3.6746340532519283`*^9}, {
  3.6746342997763047`*^9, 3.674634299886305*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"arrB", "[", 
   RowBox[{"ii_", ",", "jj_"}], "]"}], ":=", " ", 
  RowBox[{"Show", "[", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Arrowheads", "[", "Small", "]"}], ",", 
      RowBox[{"Arrow", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"ii", "+", "1"}], ",", 
           RowBox[{
            RowBox[{"Length", "[", "prot1", "]"}], "+", "1.2", "-", 
            RowBox[{"(", "jj", ")"}]}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"ii", "+", "1"}], ",", 
           RowBox[{
            RowBox[{"Length", "[", "prot1", "]"}], "+", "1.8", "-", 
            RowBox[{"(", "jj", ")"}]}]}], "}"}]}], "}"}], "]"}]}], "}"}], 
    "]"}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"arrC", "[", 
   RowBox[{"ii_", ",", "jj_"}], "]"}], ":=", " ", 
  RowBox[{"Show", "[", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Arrowheads", "[", "Small", "]"}], ",", 
      RowBox[{"Arrow", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"ii", "+", "0.7"}], ",", 
           RowBox[{
            RowBox[{"Length", "[", "prot1", "]"}], "+", "1.0", "-", 
            RowBox[{"(", "jj", ")"}]}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"ii", "+", "0.3"}], ",", 
           RowBox[{
            RowBox[{"Length", "[", "prot1", "]"}], "+", "1.0", "-", 
            RowBox[{"(", "jj", ")"}]}]}], "}"}]}], "}"}], "]"}]}], "}"}], 
    "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.577708982956818*^9, 3.577708986738661*^9}, {
  3.577709028493306*^9, 3.577709032069882*^9}, {3.577709354442863*^9, 
  3.577709365291977*^9}, {3.57770944558294*^9, 3.577709457246389*^9}, {
  3.5777095136874247`*^9, 3.577709514935789*^9}, {3.57770961633705*^9, 
  3.577709619077859*^9}, {3.623822173968965*^9, 3.623822176078443*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[TextData[{
 "Mit einer Metafunktion ",
 StyleBox["arrXX",
  FontWeight->"Bold"],
 ", die neben der Matrixposition noch den Wert der Zeigervariablen als \
Argument enth\[ADoubleDot]lt, kann man nun zwischen diesen drei Befehlen ausw\
\[ADoubleDot]hlen. Dabei besteht diese Funktion ",
 StyleBox["arrXX",
  FontWeight->"Bold"],
 " nur aus einer",
 StyleBox[" If",
  FontWeight->"Bold"],
 "-Anweisung, die jedem Zeigerzustand den entsprechenden Grafikbefehl \
zuweist. "
}], "Text",
 CellChangeTimes->{{3.6746341010280027`*^9, 3.6746341293760443`*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"arrXX", "[", 
   RowBox[{"ll_", ",", "ii_", ",", "jj_"}], "]"}], " ", ":=", " ", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"ll", "\[Equal]", "1"}], ",", 
    RowBox[{"arrA", "[", 
     RowBox[{"ii", ",", "jj"}], "]"}], ",", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"ll", "\[Equal]", "2"}], ",", 
      RowBox[{"arrB", "[", 
       RowBox[{"ii", ",", "jj"}], "]"}], ",", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"ll", "\[Equal]", "3"}], ",", 
        RowBox[{"arrC", "[", 
         RowBox[{"ii", ",", "jj"}], "]"}], ",", " ", 
        RowBox[{"Show", "[", 
         RowBox[{"Graphics", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"GrayLevel", "[", "0.9", "]"}], ",", 
            RowBox[{"Point", "[", 
             RowBox[{"{", 
              RowBox[{"ii", ",", 
               RowBox[{"jj", "+", "0.6"}]}], "}"}], "]"}]}], "}"}], "]"}], 
         "]"}]}], "]"}]}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.577709038495627*^9, 3.57770903869532*^9}, 
   3.623822186111711*^9, {3.623822854002602*^9, 3.623822876816989*^9}, {
   3.623822949865346*^9, 3.6238229508218393`*^9}, 3.6238230052551203`*^9, {
   3.623823043306302*^9, 3.623823043898366*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell["\<\
Die Entscheidung f\[UDoubleDot]r die Matrixposition als Argument erlaubt es \
nun, diese Befehle zu nutzen, um einer ganzen Matrix das entsprechende \
Zeigerfeld zuzuweisen. Dies erreichen wir mit dem n\[ADoubleDot]chsten \
Befehl, der einfach auf eine Matrix angewendet wird:\
\>", "Text",
 CellChangeTimes->{{3.6746341516770782`*^9, 3.6746341705611095`*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"arrowfield", "[", "mat_", "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"dd1", ",", "dd2"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"dd1", " ", "=", " ", 
      RowBox[{
       RowBox[{"Dimensions", "[", "mat", "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"dd2", " ", "=", " ", 
      RowBox[{
       RowBox[{"Dimensions", "[", "mat", "]"}], "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"arrXX", "[", 
        RowBox[{
         RowBox[{"mat", "[", 
          RowBox[{"[", 
           RowBox[{"ii", ",", "jj"}], "]"}], "]"}], ",", 
         RowBox[{"(", 
          RowBox[{"jj", "-", "1"}], ")"}], ",", 
         RowBox[{"(", 
          RowBox[{"ii", "-", "1"}], ")"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"ii", ",", "1", ",", "dd1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"jj", ",", "1", ",", "dd2"}], "}"}]}], "]"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{3.6238221889036207`*^9},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[TextData[{
 "Innerhalb der ",
 StyleBox["Module",
  FontWeight->"Bold"],
 "-Umgebung erkennt man hier zun\[ADoubleDot]chst Abk\[UDoubleDot]rzungen f\
\[UDoubleDot]r die Matrixdimension und dann einen einfachen ",
 StyleBox["Table",
  FontWeight->"Bold"],
 "-Befehl, der auf jede Stelle der Matrix die Funktion ",
 StyleBox["arrXX",
  FontWeight->"Bold"],
 " anwendet. Mit der oben definierten Matrix ",
 StyleBox["matFTabB",
  FontWeight->"Bold"],
 ", in der gerade die Werte der Zeigervariablen stehen, haben wir die f\
\[UDoubleDot]r die Funktion ",
 StyleBox["arrowfield",
  FontWeight->"Bold"],
 " erforderliche Struktur vorliegen. Wir wenden diesen Befehl an:"
}], "Text",
 CellChangeTimes->{{3.674634208658167*^9, 3.6746342155751767`*^9}, 
   3.6746342816762753`*^9, 3.6746343142743273`*^9},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"p5", "=", 
   RowBox[{"arrowfield", "[", "matFTabB", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{3.568717218015625*^9, 3.623821064319346*^9, 
  3.6238218493454933`*^9, 3.6746342735562625`*^9},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[TextData[{
 "Das Resultat ist eine Struktur aus Grafikbefehlen, die wir nun mit Hilfe \
eines einfachen ",
 StyleBox["Show",
  FontWeight->"Bold"],
 "-Befehls darstellen k\[ODoubleDot]nnen:"
}], "Text",
 CellChangeTimes->{{3.6746343354393597`*^9, 3.674634347414377*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"p6", "=", 
   RowBox[{"Show", "[", "p5", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.568717145390625*^9, 3.56871714575*^9}, 
   3.623821854118786*^9},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p6", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"p4", ",", "p5"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.623821860970188*^9, 3.623821863248919*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 GraphicsBox[{{{
     {GrayLevel[0.9], RectangleBox[{0.5, 9.5}, {14.5, 10.5}]}, {
      InsetBox["\<\" \"\>", {1, 10}], InsetBox["\<\"K\"\>", {2, 10}], 
      InsetBox["\<\"Y\"\>", {3, 10}], InsetBox["\<\"F\"\>", {4, 10}], 
      InsetBox["\<\"H\"\>", {5, 10}], InsetBox["\<\"K\"\>", {6, 10}], 
      InsetBox["\<\"A\"\>", {7, 10}], InsetBox["\<\"G\"\>", {8, 10}], 
      InsetBox["\<\"N\"\>", {9, 10}], InsetBox["\<\"G\"\>", {10, 10}], 
      InsetBox["\<\"H\"\>", {11, 10}], InsetBox["\<\"S\"\>", {12, 10}], 
      InsetBox["\<\"P\"\>", {13, 10}], InsetBox["\<\"T\"\>", {14, 10}]}}, {
     {GrayLevel[0.9], RectangleBox[{-0.5, 0.5}, {0.5, 10.5}]}, {
      InsetBox["\<\" \"\>", {0, 9}], InsetBox["\<\"K\"\>", {0, 8}], 
      InsetBox["\<\"E\"\>", {0, 7}], InsetBox["\<\"F\"\>", {0, 6}], 
      InsetBox["\<\"H\"\>", {0, 5}], InsetBox["\<\"N\"\>", {0, 4}], 
      InsetBox["\<\"G\"\>", {0, 3}], InsetBox["\<\"H\"\>", {0, 2}], 
      InsetBox["\<\"T\"\>", {0, 1}]}}, {{InsetBox["0", {1, 9}], InsetBox[
       RowBox[{"-", "5"}], {2, 9}], InsetBox[
       RowBox[{"-", "10"}], {3, 9}], InsetBox[
       RowBox[{"-", "15"}], {4, 9}], InsetBox[
       RowBox[{"-", "20"}], {5, 9}], InsetBox[
       RowBox[{"-", "25"}], {6, 9}], InsetBox[
       RowBox[{"-", "30"}], {7, 9}], InsetBox[
       RowBox[{"-", "35"}], {8, 9}], InsetBox[
       RowBox[{"-", "40"}], {9, 9}], InsetBox[
       RowBox[{"-", "45"}], {10, 9}], InsetBox[
       RowBox[{"-", "50"}], {11, 9}], InsetBox[
       RowBox[{"-", "55"}], {12, 9}], InsetBox[
       RowBox[{"-", "60"}], {13, 9}], InsetBox[
       RowBox[{"-", "65"}], {14, 9}]}, {InsetBox[
       RowBox[{"-", "5"}], {1, 8}], InsetBox["5", {2, 8}], 
      InsetBox["0", {3, 8}], InsetBox[
       RowBox[{"-", "5"}], {4, 8}], InsetBox[
       RowBox[{"-", "10"}], {5, 8}], InsetBox[
       RowBox[{"-", "15"}], {6, 8}], InsetBox[
       RowBox[{"-", "20"}], {7, 8}], InsetBox[
       RowBox[{"-", "25"}], {8, 8}], InsetBox[
       RowBox[{"-", "30"}], {9, 8}], InsetBox[
       RowBox[{"-", "35"}], {10, 8}], InsetBox[
       RowBox[{"-", "40"}], {11, 8}], InsetBox[
       RowBox[{"-", "45"}], {12, 8}], InsetBox[
       RowBox[{"-", "50"}], {13, 8}], InsetBox[
       RowBox[{"-", "55"}], {14, 8}]}, {InsetBox[
       RowBox[{"-", "10"}], {1, 7}], InsetBox["0", {2, 7}], 
      InsetBox["3", {3, 7}], InsetBox[
       RowBox[{"-", "2"}], {4, 7}], InsetBox[
       RowBox[{"-", "5"}], {5, 7}], InsetBox[
       RowBox[{"-", "9"}], {6, 7}], InsetBox[
       RowBox[{"-", "14"}], {7, 7}], InsetBox[
       RowBox[{"-", "19"}], {8, 7}], InsetBox[
       RowBox[{"-", "24"}], {9, 7}], InsetBox[
       RowBox[{"-", "29"}], {10, 7}], InsetBox[
       RowBox[{"-", "34"}], {11, 7}], InsetBox[
       RowBox[{"-", "39"}], {12, 7}], InsetBox[
       RowBox[{"-", "44"}], {13, 7}], InsetBox[
       RowBox[{"-", "49"}], {14, 7}]}, {InsetBox[
       RowBox[{"-", "15"}], {1, 6}], InsetBox[
       RowBox[{"-", "5"}], {2, 6}], InsetBox["3", {3, 6}], 
      InsetBox["9", {4, 6}], InsetBox["4", {5, 6}], InsetBox[
       RowBox[{"-", "1"}], {6, 6}], InsetBox[
       RowBox[{"-", "6"}], {7, 6}], InsetBox[
       RowBox[{"-", "11"}], {8, 6}], InsetBox[
       RowBox[{"-", "16"}], {9, 6}], InsetBox[
       RowBox[{"-", "21"}], {10, 6}], InsetBox[
       RowBox[{"-", "26"}], {11, 6}], InsetBox[
       RowBox[{"-", "31"}], {12, 6}], InsetBox[
       RowBox[{"-", "36"}], {13, 6}], InsetBox[
       RowBox[{"-", "41"}], {14, 6}]}, {InsetBox[
       RowBox[{"-", "20"}], {1, 5}], InsetBox[
       RowBox[{"-", "10"}], {2, 5}], InsetBox[
       RowBox[{"-", "2"}], {3, 5}], InsetBox["4", {4, 5}], 
      InsetBox["17", {5, 5}], InsetBox["12", {6, 5}], InsetBox["7", {7, 5}], 
      InsetBox["2", {8, 5}], InsetBox[
       RowBox[{"-", "3"}], {9, 5}], InsetBox[
       RowBox[{"-", "8"}], {10, 5}], InsetBox[
       RowBox[{"-", "13"}], {11, 5}], InsetBox[
       RowBox[{"-", "18"}], {12, 5}], InsetBox[
       RowBox[{"-", "23"}], {13, 5}], InsetBox[
       RowBox[{"-", "28"}], {14, 5}]}, {InsetBox[
       RowBox[{"-", "25"}], {1, 4}], InsetBox[
       RowBox[{"-", "15"}], {2, 4}], InsetBox[
       RowBox[{"-", "7"}], {3, 4}], InsetBox[
       RowBox[{"-", "1"}], {4, 4}], InsetBox["12", {5, 4}], 
      InsetBox["17", {6, 4}], InsetBox["12", {7, 4}], InsetBox["7", {8, 4}], 
      InsetBox["8", {9, 4}], InsetBox["3", {10, 4}], InsetBox[
       RowBox[{"-", "2"}], {11, 4}], InsetBox[
       RowBox[{"-", "7"}], {12, 4}], InsetBox[
       RowBox[{"-", "12"}], {13, 4}], InsetBox[
       RowBox[{"-", "17"}], {14, 4}]}, {InsetBox[
       RowBox[{"-", "30"}], {1, 3}], InsetBox[
       RowBox[{"-", "20"}], {2, 3}], InsetBox[
       RowBox[{"-", "12"}], {3, 3}], InsetBox[
       RowBox[{"-", "6"}], {4, 3}], InsetBox["7", {5, 3}], 
      InsetBox["12", {6, 3}], InsetBox["17", {7, 3}], InsetBox["18", {8, 3}], 
      InsetBox["13", {9, 3}], InsetBox["14", {10, 3}], InsetBox["9", {11, 3}],
       InsetBox["4", {12, 3}], InsetBox[
       RowBox[{"-", "1"}], {13, 3}], InsetBox[
       RowBox[{"-", "6"}], {14, 3}]}, {InsetBox[
       RowBox[{"-", "35"}], {1, 2}], InsetBox[
       RowBox[{"-", "25"}], {2, 2}], InsetBox[
       RowBox[{"-", "17"}], {3, 2}], InsetBox[
       RowBox[{"-", "11"}], {4, 2}], InsetBox["2", {5, 2}], 
      InsetBox["7", {6, 2}], InsetBox["12", {7, 2}], InsetBox["15", {8, 2}], 
      InsetBox["19", {9, 2}], InsetBox["14", {10, 2}], 
      InsetBox["22", {11, 2}], InsetBox["17", {12, 2}], 
      InsetBox["12", {13, 2}], InsetBox["7", {14, 2}]}, {InsetBox[
       RowBox[{"-", "40"}], {1, 1}], InsetBox[
       RowBox[{"-", "30"}], {2, 1}], InsetBox[
       RowBox[{"-", "22"}], {3, 1}], InsetBox[
       RowBox[{"-", "16"}], {4, 1}], InsetBox[
       RowBox[{"-", "3"}], {5, 1}], InsetBox["2", {6, 1}], 
      InsetBox["7", {7, 1}], InsetBox["10", {8, 1}], InsetBox["15", {9, 1}], 
      InsetBox["17", {10, 1}], InsetBox["17", {11, 1}], 
      InsetBox["23", {12, 1}], InsetBox["18", {13, 1}], 
      InsetBox["17", {14, 1}]}}}, 
   {GrayLevel[0.9], PointBox[{0, 0.6}]}, 
   {Arrowheads[Small], ArrowBox[{{1.7, 9.}, {1.3, 9.}}]}, 
   {Arrowheads[Small], ArrowBox[{{2.7, 9.}, {2.3, 9.}}]}, 
   {Arrowheads[Small], ArrowBox[{{3.7, 9.}, {3.3, 9.}}]}, 
   {Arrowheads[Small], ArrowBox[{{4.7, 9.}, {4.3, 9.}}]}, 
   {Arrowheads[Small], ArrowBox[{{5.7, 9.}, {5.3, 9.}}]}, 
   {Arrowheads[Small], ArrowBox[{{6.7, 9.}, {6.3, 9.}}]}, 
   {Arrowheads[Small], ArrowBox[{{7.7, 9.}, {7.3, 9.}}]}, 
   {Arrowheads[Small], ArrowBox[{{8.7, 9.}, {8.3, 9.}}]}, 
   {Arrowheads[Small], ArrowBox[{{9.7, 9.}, {9.3, 9.}}]}, 
   {Arrowheads[Small], ArrowBox[{{10.7, 9.}, {10.3, 9.}}]}, 
   {Arrowheads[Small], ArrowBox[{{11.7, 9.}, {11.3, 9.}}]}, 
   {Arrowheads[Small], ArrowBox[{{12.7, 9.}, {12.3, 9.}}]}, 
   {Arrowheads[Small], ArrowBox[{{13.7, 9.}, {13.3, 9.}}]}, 
   {Arrowheads[Small], ArrowBox[{{1, 8.2}, {1, 8.8}}]}, 
   {Arrowheads[Small], ArrowBox[{{1.8, 8.2}, {1.2, 8.8}}]}, 
   {Arrowheads[Small], ArrowBox[{{2.7, 8.}, {2.3, 8.}}]}, 
   {Arrowheads[Small], ArrowBox[{{3.7, 8.}, {3.3, 8.}}]}, 
   {Arrowheads[Small], ArrowBox[{{4.7, 8.}, {4.3, 8.}}]}, 
   {Arrowheads[Small], ArrowBox[{{5.8, 8.2}, {5.2, 8.8}}]}, 
   {Arrowheads[Small], ArrowBox[{{6.7, 8.}, {6.3, 8.}}]}, 
   {Arrowheads[Small], ArrowBox[{{7.7, 8.}, {7.3, 8.}}]}, 
   {Arrowheads[Small], ArrowBox[{{8.7, 8.}, {8.3, 8.}}]}, 
   {Arrowheads[Small], ArrowBox[{{9.7, 8.}, {9.3, 8.}}]}, 
   {Arrowheads[Small], ArrowBox[{{10.7, 8.}, {10.3, 8.}}]}, 
   {Arrowheads[Small], ArrowBox[{{11.7, 8.}, {11.3, 8.}}]}, 
   {Arrowheads[Small], ArrowBox[{{12.7, 8.}, {12.3, 8.}}]}, 
   {Arrowheads[Small], ArrowBox[{{13.7, 8.}, {13.3, 8.}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{1, 7.199999999999999}, {1, 7.800000000000001}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{2, 7.199999999999999}, {2, 7.800000000000001}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{2.8, 7.199999999999999}, {2.2, 7.800000000000001}}]}, 
   {Arrowheads[Small], ArrowBox[{{3.7, 7.}, {3.3, 7.}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{4.8, 7.199999999999999}, {4.2, 7.800000000000001}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{5.8, 7.199999999999999}, {5.2, 7.800000000000001}}]}, 
   {Arrowheads[Small], ArrowBox[{{6.7, 7.}, {6.3, 7.}}]}, 
   {Arrowheads[Small], ArrowBox[{{7.7, 7.}, {7.3, 7.}}]}, 
   {Arrowheads[Small], ArrowBox[{{8.7, 7.}, {8.3, 7.}}]}, 
   {Arrowheads[Small], ArrowBox[{{9.7, 7.}, {9.3, 7.}}]}, 
   {Arrowheads[Small], ArrowBox[{{10.7, 7.}, {10.3, 7.}}]}, 
   {Arrowheads[Small], ArrowBox[{{11.7, 7.}, {11.3, 7.}}]}, 
   {Arrowheads[Small], ArrowBox[{{12.7, 7.}, {12.3, 7.}}]}, 
   {Arrowheads[Small], ArrowBox[{{13.7, 7.}, {13.3, 7.}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{1, 6.199999999999999}, {1, 6.800000000000001}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{2, 6.199999999999999}, {2, 6.800000000000001}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{2.8, 6.199999999999999}, {2.2, 6.800000000000001}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{3.8, 6.199999999999999}, {3.2, 6.800000000000001}}]}, 
   {Arrowheads[Small], ArrowBox[{{4.7, 6.}, {4.3, 6.}}]}, 
   {Arrowheads[Small], ArrowBox[{{5.7, 6.}, {5.3, 6.}}]}, 
   {Arrowheads[Small], ArrowBox[{{6.7, 6.}, {6.3, 6.}}]}, 
   {Arrowheads[Small], ArrowBox[{{7.7, 6.}, {7.3, 6.}}]}, 
   {Arrowheads[Small], ArrowBox[{{8.7, 6.}, {8.3, 6.}}]}, 
   {Arrowheads[Small], ArrowBox[{{9.7, 6.}, {9.3, 6.}}]}, 
   {Arrowheads[Small], ArrowBox[{{10.7, 6.}, {10.3, 6.}}]}, 
   {Arrowheads[Small], ArrowBox[{{11.7, 6.}, {11.3, 6.}}]}, 
   {Arrowheads[Small], ArrowBox[{{12.7, 6.}, {12.3, 6.}}]}, 
   {Arrowheads[Small], ArrowBox[{{13.7, 6.}, {13.3, 6.}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{1, 5.199999999999999}, {1, 5.800000000000001}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{2, 5.199999999999999}, {2, 5.800000000000001}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{3, 5.199999999999999}, {3, 5.800000000000001}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{4, 5.199999999999999}, {4, 5.800000000000001}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{4.8, 5.199999999999999}, {4.2, 5.800000000000001}}]}, 
   {Arrowheads[Small], ArrowBox[{{5.7, 5.}, {5.3, 5.}}]}, 
   {Arrowheads[Small], ArrowBox[{{6.7, 5.}, {6.3, 5.}}]}, 
   {Arrowheads[Small], ArrowBox[{{7.7, 5.}, {7.3, 5.}}]}, 
   {Arrowheads[Small], ArrowBox[{{8.7, 5.}, {8.3, 5.}}]}, 
   {Arrowheads[Small], ArrowBox[{{9.7, 5.}, {9.3, 5.}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{10.8, 5.199999999999999}, {10.2, 5.800000000000001}}]}, 
   {Arrowheads[Small], ArrowBox[{{11.7, 5.}, {11.3, 5.}}]}, 
   {Arrowheads[Small], ArrowBox[{{12.7, 5.}, {12.3, 5.}}]}, 
   {Arrowheads[Small], ArrowBox[{{13.7, 5.}, {13.3, 5.}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{1, 4.199999999999999}, {1, 4.800000000000001}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{2, 4.199999999999999}, {2, 4.800000000000001}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{3, 4.199999999999999}, {3, 4.800000000000001}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{4, 4.199999999999999}, {4, 4.800000000000001}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{5, 4.199999999999999}, {5, 4.800000000000001}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{5.8, 4.199999999999999}, {5.2, 4.800000000000001}}]}, 
   {Arrowheads[Small], ArrowBox[{{6.7, 4.}, {6.3, 4.}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{7.8, 4.199999999999999}, {7.2, 4.800000000000001}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{8.8, 4.199999999999999}, {8.2, 4.800000000000001}}]}, 
   {Arrowheads[Small], ArrowBox[{{9.7, 4.}, {9.3, 4.}}]}, 
   {Arrowheads[Small], ArrowBox[{{10.7, 4.}, {10.3, 4.}}]}, 
   {Arrowheads[Small], ArrowBox[{{11.7, 4.}, {11.3, 4.}}]}, 
   {Arrowheads[Small], ArrowBox[{{12.7, 4.}, {12.3, 4.}}]}, 
   {Arrowheads[Small], ArrowBox[{{13.7, 4.}, {13.3, 4.}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{1, 3.1999999999999993`}, {1, 3.8000000000000007`}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{2, 3.1999999999999993`}, {2, 3.8000000000000007`}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{3, 3.1999999999999993`}, {3, 3.8000000000000007`}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{4, 3.1999999999999993`}, {4, 3.8000000000000007`}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{5, 3.1999999999999993`}, {5, 3.8000000000000007`}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{6, 3.1999999999999993`}, {6, 3.8000000000000007`}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{6.8, 3.1999999999999993`}, {6.2, 3.8000000000000007`}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{7.8, 3.1999999999999993`}, {7.2, 3.8000000000000007`}}]}, 
   {Arrowheads[Small], ArrowBox[{{8.7, 3.}, {8.3, 3.}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{9.8, 3.1999999999999993`}, {9.2, 3.8000000000000007`}}]}, 
   {Arrowheads[Small], ArrowBox[{{10.7, 3.}, {10.3, 3.}}]}, 
   {Arrowheads[Small], ArrowBox[{{11.7, 3.}, {11.3, 3.}}]}, 
   {Arrowheads[Small], ArrowBox[{{12.7, 3.}, {12.3, 3.}}]}, 
   {Arrowheads[Small], ArrowBox[{{13.7, 3.}, {13.3, 3.}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{1, 2.1999999999999993`}, {1, 2.8000000000000007`}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{2, 2.1999999999999993`}, {2, 2.8000000000000007`}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{3, 2.1999999999999993`}, {3, 2.8000000000000007`}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{4, 2.1999999999999993`}, {4, 2.8000000000000007`}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{4.8, 2.1999999999999993`}, {4.2, 2.8000000000000007`}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{6, 2.1999999999999993`}, {6, 2.8000000000000007`}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{7, 2.1999999999999993`}, {7, 2.8000000000000007`}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{7.8, 2.1999999999999993`}, {7.2, 2.8000000000000007`}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{8.8, 2.1999999999999993`}, {8.2, 2.8000000000000007`}}]}, 
   {Arrowheads[Small], ArrowBox[{{9.7, 2.}, {9.3, 2.}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{10.8, 2.1999999999999993`}, {10.2, 2.8000000000000007`}}]}, 
   {Arrowheads[Small], ArrowBox[{{11.7, 2.}, {11.3, 2.}}]}, 
   {Arrowheads[Small], ArrowBox[{{12.7, 2.}, {12.3, 2.}}]}, 
   {Arrowheads[Small], ArrowBox[{{13.7, 2.}, {13.3, 2.}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{1, 1.1999999999999993`}, {1, 1.8000000000000007`}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{2, 1.1999999999999993`}, {2, 1.8000000000000007`}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{3, 1.1999999999999993`}, {3, 1.8000000000000007`}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{4, 1.1999999999999993`}, {4, 1.8000000000000007`}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{5, 1.1999999999999993`}, {5, 1.8000000000000007`}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{6, 1.1999999999999993`}, {6, 1.8000000000000007`}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{6.8, 1.1999999999999993`}, {6.2, 1.8000000000000007`}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{7.8, 1.1999999999999993`}, {7.2, 1.8000000000000007`}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{8.8, 1.1999999999999993`}, {8.2, 1.8000000000000007`}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{9.8, 1.1999999999999993`}, {9.2, 1.8000000000000007`}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{11, 1.1999999999999993`}, {11, 1.8000000000000007`}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{11.8, 1.1999999999999993`}, {11.2, 1.8000000000000007`}}]}, 
   {Arrowheads[Small], ArrowBox[{{12.7, 1.}, {12.3, 1.}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{13.8, 1.1999999999999993`}, {13.2, 1.8000000000000007`}}]}},
  PlotRange->All]], "Output",
 CellChangeTimes->{3.677571690577121*^9}]
}, Open  ]],

Cell[TextData[{
 "Die bisherigen Befehle und Auswertungen stellen die Infrastruktur bereit, \
um nun das Kernst\[UDoubleDot]ck des Needleman-Wunsch-Algorithmus in die \
Betrachtungen einbeziehen zu k\[ODoubleDot]nnen, n\[ADoubleDot]mlich die \
Ermittlung des Pfads durch dieseMatrix, der dem h\[ODoubleDot]chsten \
Alignment-Score der beiden Sequenzen entspricht. F\[UDoubleDot]hren wir zun\
\[ADoubleDot]chst eine Abk\[UDoubleDot]rzung f\[UDoubleDot]r die \
Matrixdimension ein und extrahieren das rechte untere Element, das beim \
Needleman-Wunsch-Algorithmus den Startpunkt f\[UDoubleDot]r den optimalen \
Pfad darstellt. Die Koordinaten des optimalen Pfads schreiben wir in die \
Variable ",
 StyleBox["traX",
  FontWeight->"Bold"],
 ", die wir als Funktion mit einem Laufindex ",
 StyleBox["i",
  FontSlant->"Italic"],
 " als Argument darstellen."
}], "Text",
 CellChangeTimes->{{3.6746343803044252`*^9, 3.67463438934344*^9}, {
  3.674634430775502*^9, 3.6746344464535255`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dX", "=", 
   RowBox[{"Dimensions", "[", "matFTabB", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{3.623821065539482*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"traX", "[", "1", "]"}], "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"dX", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{"dX", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"9", ",", "14"}], "}"}]], "Output",
 CellChangeTimes->{3.677571690623921*^9}]
}, Open  ]],

Cell[TextData[{
 "Mit einer ",
 StyleBox["While",
  FontWeight->"Bold"],
 "-Schleife, die \[UDoubleDot]berpr\[UDoubleDot]ft, ob das Ende (genauer: der \
Anfang) der beiden Sequenzen erreicht ist, kann nun der Pfad rekursiv \
konstruiert werden. Wann immer der Zeigerzustand 1 (\[OpenCurlyQuote]diagonal\
\[CloseCurlyQuote]) an der aktuellen Matrixposition vorliegt, werden beide \
Indizes um Eins vermindert, ansonsten jeweils nur ein Index. Eine \
Laufvariable ",
 StyleBox["j",
  FontWeight->"Bold"],
 " wird in jedem Schleifendurchlauf erh\[ODoubleDot]ht."
}], "Text",
 CellChangeTimes->{{3.67463450933762*^9, 3.6746345168956304`*^9}, {
  3.674634553234685*^9, 3.674634564932702*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"j", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"While", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"matFTabB", "[", 
     RowBox[{"[", 
      RowBox[{"Sequence", "@@", 
       RowBox[{"traX", "[", "j", "]"}]}], "]"}], "]"}], "=!=", "0"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"traX", "[", 
       RowBox[{"j", "+", "1"}], "]"}], "=", 
      RowBox[{
       RowBox[{"traX", "[", "j", "]"}], "-", 
       RowBox[{"Switch", "[", 
        RowBox[{
         RowBox[{"matFTabB", "[", 
          RowBox[{"[", 
           RowBox[{"Sequence", "@@", 
            RowBox[{"traX", "[", "j", "]"}]}], "]"}], "]"}], ",", "1", ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "1"}], "}"}], ",", "2", ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "0"}], "}"}], ",", "3", ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "1"}], "}"}]}], "]"}]}]}], ",", 
     RowBox[{"j", "=", 
      RowBox[{"j", "+", "1"}]}]}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.6238210662936573`*^9, 3.623821068255362*^9}}],

Cell[TextData[{
 "Bei n\[ADoubleDot]herem Hinsehen erkennt man einige Besonderheiten. So \
wurde z.B. als Abbruchbedingung der ",
 StyleBox["While",
  FontWeight->"Bold"],
 "-Schleife das Erreichen eines Zeigerzustands von Null verwendet. Wir nutzen \
also aus, dass dieser Zeigerzustand f\[UDoubleDot]r die obere linke Ecke der \
Matrix reserviert ist. Weiterhin muss man eine ung\[UDoubleDot]nstige \
Klammerung in Mathematica hier umgehen: Ein Zahlenpaar kann nicht ohne \
Vorbereitung als Matrixposition an den ",
 StyleBox["Part",
  FontWeight->"Bold"],
 "-Befehl (also ",
 StyleBox["[[]]",
  FontWeight->"Bold"],
 ") \[UDoubleDot]bergeben werden. Man muss (wie wir es vom Prinzip her auch \
schon im vorangegangenen ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-Exkurs gesehen haben) den Kopf dieser Liste durch den einer ungeklammerten \
Zahlenfolge ersetzen. Dies geschieht mit dem Befehl ",
 StyleBox["Sequence",
  FontWeight->"Bold"],
 ", zusammen mit ",
 StyleBox["Apply",
  FontWeight->"Bold"],
 " (also ",
 StyleBox["@@",
  FontWeight->"Bold"],
 "). Eine letzte Besonderheit stellt die konkrete Rekursion dar. Hier sieht \
man recht klar, dass sich in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " solche formalen Zuweisungen sehr elegant gestalten lassen. Der ",
 StyleBox["Switch",
  FontWeight->"Bold"],
 "-Befehl steht explizit als ein Term in der Gleichung f\[UDoubleDot]r die n\
\[ADoubleDot]chsten Pfadkoordinaten. Auf diese Weise wird der Term in Abh\
\[ADoubleDot]ngigkeit des Zeigerzustands hinzugef\[UDoubleDot]gt: entweder ",
 StyleBox["{1, 1}",
  FontWeight->"Bold"],
 " oder ",
 StyleBox["{1, 0}",
  FontWeight->"Bold"],
 " oder ",
 StyleBox["{0, 1}",
  FontWeight->"Bold"],
 ". Die Ausgabe des Pfads erfolgt nun einfach \[UDoubleDot]ber den ",
 StyleBox["Table",
  FontWeight->"Bold"],
 "-Befehl. Dabei verwenden wir den Wert der Laufvariablen ",
 StyleBox["j",
  FontWeight->"Bold"],
 " am Ende der Schleifendurchl\[ADoubleDot]ufe als obere Grenze. Der letzte \
Eintrag (n\[ADoubleDot]mlich stets die Position ",
 StyleBox["{1, 1}",
  FontWeight->"Bold"],
 ") wird weggelassen, da sie nicht mehr zum eigentlichen Pfad beitr\
\[ADoubleDot]gt."
}], "Text",
 CellChangeTimes->{{3.674634647199833*^9, 3.67463465158184*^9}, 
   3.6746347434499793`*^9, 3.6746348224490995`*^9, {3.6774945197965083`*^9, 
   3.677494520186509*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"path1", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"traX", "[", "k", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "1", ",", 
      RowBox[{"j", "-", "1"}]}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"9", ",", "14"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", "13"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", "11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7", ",", "10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", "9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "2"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6775716907799215`*^9}]
}, Open  ]],

Cell[TextData[{
 "Ein geeignetes Format f\[UDoubleDot]r die weitere Verarbeitung erreichen \
wir durch erneutes Auslesen der Zeigerzust\[ADoubleDot]nde aus der Tabelle ",
 StyleBox["matFTabB",
  FontWeight->"Bold"],
 " und durch Zusammenf\[UDoubleDot]gen mit der Pfadvariablen ",
 StyleBox["path1",
  FontWeight->"Bold"],
 ":"
}], "Text",
 CellChangeTimes->{{3.674634865282163*^9, 3.674634869328169*^9}, {
  3.674634913201235*^9, 3.674634929718259*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"path2", "=", 
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"matFTabB", "[", 
      RowBox[{"[", 
       RowBox[{"Sequence", "@@", "#"}], "]"}], "]"}], "&"}], ",", "path1"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{3.623821070067316*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "3", ",", "3", ",", "1", ",", "1", ",", "1", ",", "3", ",", "3", 
   ",", "3", ",", "1", ",", "1", ",", "1", ",", "1"}], "}"}]], "Output",
 CellChangeTimes->{3.6775716907955213`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"path3", "=", 
  RowBox[{"Map", "[", 
   RowBox[{"Flatten", ",", 
    RowBox[{"Thread", "[", 
     RowBox[{"{", 
      RowBox[{"path2", ",", "path1"}], "}"}], "]"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "9", ",", "14"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "8", ",", "13"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "8", ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "8", ",", "11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "7", ",", "10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "6", ",", "9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "5", ",", "8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "5", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "5", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "5", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "4", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "2"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.677571690826721*^9}]
}, Open  ]],

Cell["\<\
Man hat dann Wertetripletts: (Zeigerzustand, Koordinate 1, Koordinate 2).\
\>", "Text",
 CellChangeTimes->{{3.6746349459702835`*^9, 3.6746349852593455`*^9}, {
  3.677565361382205*^9, 3.6775653632542086`*^9}, {3.6775656984217973`*^9, 
  3.677565699014598*^9}}],

Cell[TextData[{
 "Wir kommen nun zur Visualisierung dieses Pfades. Dabei verwenden wir \
dieselben Graphikbefehle f\[UDoubleDot]r die Pfeile, die wir bereits zu \
Beginn dieses Notebooks eingesetzt haben, nun allerdings mit einer anderen \
Pfeilfarbe und Linienst\[ADoubleDot]rke. Man hat dann eine Farbvariante ",
 StyleBox["arrXXc",
  FontWeight->"Bold"],
 " als Befehl zur Verf\[UDoubleDot]gung, die dem urspr\[UDoubleDot]nglichen \
Metakommando ",
 StyleBox["arrXX",
  FontWeight->"Bold"],
 " zur Auswahl des richtigen Pfeils zu einem Zeiger entspricht."
}], "Text",
 CellChangeTimes->{{3.6775653680122166`*^9, 3.6775653806794395`*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"arrAc", "[", 
    RowBox[{"ii_", ",", "jj_"}], "]"}], ":=", " ", 
   RowBox[{"Show", "[", 
    RowBox[{"Graphics", "[", 
     RowBox[{
      StyleBox["{", "Code"], 
      RowBox[{
       RowBox[{"Arrowheads", "[", "Small", "]"}], ",", "Red", ",", 
       RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
       RowBox[{"Arrow", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"ii", "+", "0.8"}], ",", 
            RowBox[{
             RowBox[{"Length", "[", "prot1", "]"}], "+", "1.2", "-", 
             RowBox[{"(", "jj", ")"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"ii", "+", "0.2"}], ",", 
            RowBox[{
             RowBox[{"Length", "[", "prot1", "]"}], "+", "1.8", "-", 
             RowBox[{"(", "jj", ")"}]}]}], "}"}]}], "}"}], "]"}]}], "}"}], 
     "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"arrBc", "[", 
    RowBox[{"ii_", ",", "jj_"}], "]"}], ":=", " ", 
   RowBox[{"Show", "[", 
    RowBox[{"Graphics", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Arrowheads", "[", "Small", "]"}], ",", "Red", ",", 
       RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
       RowBox[{"Arrow", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"ii", "+", "1"}], ",", 
            RowBox[{
             RowBox[{"Length", "[", "prot1", "]"}], "+", "1.2", "-", 
             RowBox[{"(", "jj", ")"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"ii", "+", "1"}], ",", 
            RowBox[{
             RowBox[{"Length", "[", "prot1", "]"}], "+", "1.8", "-", 
             RowBox[{"(", "jj", ")"}]}]}], "}"}]}], "}"}], "]"}]}], "}"}], 
     "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"arrCc", "[", 
    RowBox[{"ii_", ",", "jj_"}], "]"}], ":=", " ", 
   RowBox[{"Show", "[", 
    RowBox[{"Graphics", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Arrowheads", "[", "Small", "]"}], ",", "Red", ",", 
       RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
       RowBox[{"Arrow", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"ii", "+", "0.7"}], ",", 
            RowBox[{
             RowBox[{"Length", "[", "prot1", "]"}], "+", "1.0", "-", 
             RowBox[{"(", "jj", ")"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"ii", "+", "0.3"}], ",", 
            RowBox[{
             RowBox[{"Length", "[", "prot1", "]"}], "+", "1.0", "-", 
             RowBox[{"(", "jj", ")"}]}]}], "}"}]}], "}"}], "]"}]}], "}"}], 
     "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"arrXXc", "[", 
   RowBox[{"ll_", ",", "ii_", ",", "jj_"}], "]"}], " ", ":=", " ", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"ll", "\[Equal]", "1"}], ",", 
    RowBox[{"arrAc", "[", 
     RowBox[{"ii", ",", "jj"}], "]"}], ",", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"ll", "\[Equal]", "2"}], ",", 
      RowBox[{"arrBc", "[", 
       RowBox[{"ii", ",", "jj"}], "]"}], ",", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"ll", "\[Equal]", "3"}], ",", 
        RowBox[{"arrCc", "[", 
         RowBox[{"ii", ",", "jj"}], "]"}]}], "]"}]}], "]"}]}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.577708979166664*^9, 3.577708979823925*^9}, {
   3.57770902526331*^9, 3.577709025485627*^9}, {3.5777093391396637`*^9, 
   3.577709351818097*^9}, {3.577709431697268*^9, 3.5777094404789143`*^9}, {
   3.577709505598864*^9, 3.5777095085412703`*^9}, 3.577710290271607*^9, {
   3.5777103393188343`*^9, 3.577710350784239*^9}, {3.623821994838057*^9, 
   3.623822024753076*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[TextData[{
 "Die Daten ",
 StyleBox["path3",
  FontWeight->"Bold"],
 " kann nun mit dem ",
 StyleBox["Map",
  FontWeight->"Bold"],
 "-Befehl direkt in ",
 StyleBox["arrXXc",
  FontWeight->"Bold"],
 " zur Erzeugung der Grafikbefehle eingef\[UDoubleDot]gt werden.",
 StyleBox[" ",
  FontColor->GrayLevel[0.5]]
}], "Text",
 CellChangeTimes->{{3.674635065464466*^9, 3.674635080646488*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"gr2", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"arrXXc", "[", 
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "3", "]"}], "]"}], "-", "1"}], ",", 
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "-", "1"}]}], "]"}], "&"}], ",", 
     "path3"}], "]"}]}], ";"}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p7", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"p6", ",", "gr2"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.623822034366399*^9, 3.623822036444879*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 GraphicsBox[{{{{
      {GrayLevel[0.9], RectangleBox[{0.5, 9.5}, {14.5, 10.5}]}, {
       InsetBox["\<\" \"\>", {1, 10}], InsetBox["\<\"K\"\>", {2, 10}], 
       InsetBox["\<\"Y\"\>", {3, 10}], InsetBox["\<\"F\"\>", {4, 10}], 
       InsetBox["\<\"H\"\>", {5, 10}], InsetBox["\<\"K\"\>", {6, 10}], 
       InsetBox["\<\"A\"\>", {7, 10}], InsetBox["\<\"G\"\>", {8, 10}], 
       InsetBox["\<\"N\"\>", {9, 10}], InsetBox["\<\"G\"\>", {10, 10}], 
       InsetBox["\<\"H\"\>", {11, 10}], InsetBox["\<\"S\"\>", {12, 10}], 
       InsetBox["\<\"P\"\>", {13, 10}], InsetBox["\<\"T\"\>", {14, 10}]}}, {
      {GrayLevel[0.9], RectangleBox[{-0.5, 0.5}, {0.5, 10.5}]}, {
       InsetBox["\<\" \"\>", {0, 9}], InsetBox["\<\"K\"\>", {0, 8}], 
       InsetBox["\<\"E\"\>", {0, 7}], InsetBox["\<\"F\"\>", {0, 6}], 
       InsetBox["\<\"H\"\>", {0, 5}], InsetBox["\<\"N\"\>", {0, 4}], 
       InsetBox["\<\"G\"\>", {0, 3}], InsetBox["\<\"H\"\>", {0, 2}], 
       InsetBox["\<\"T\"\>", {0, 1}]}}, {{InsetBox["0", {1, 9}], InsetBox[
        RowBox[{"-", "5"}], {2, 9}], InsetBox[
        RowBox[{"-", "10"}], {3, 9}], InsetBox[
        RowBox[{"-", "15"}], {4, 9}], InsetBox[
        RowBox[{"-", "20"}], {5, 9}], InsetBox[
        RowBox[{"-", "25"}], {6, 9}], InsetBox[
        RowBox[{"-", "30"}], {7, 9}], InsetBox[
        RowBox[{"-", "35"}], {8, 9}], InsetBox[
        RowBox[{"-", "40"}], {9, 9}], InsetBox[
        RowBox[{"-", "45"}], {10, 9}], InsetBox[
        RowBox[{"-", "50"}], {11, 9}], InsetBox[
        RowBox[{"-", "55"}], {12, 9}], InsetBox[
        RowBox[{"-", "60"}], {13, 9}], InsetBox[
        RowBox[{"-", "65"}], {14, 9}]}, {InsetBox[
        RowBox[{"-", "5"}], {1, 8}], InsetBox["5", {2, 8}], 
       InsetBox["0", {3, 8}], InsetBox[
        RowBox[{"-", "5"}], {4, 8}], InsetBox[
        RowBox[{"-", "10"}], {5, 8}], InsetBox[
        RowBox[{"-", "15"}], {6, 8}], InsetBox[
        RowBox[{"-", "20"}], {7, 8}], InsetBox[
        RowBox[{"-", "25"}], {8, 8}], InsetBox[
        RowBox[{"-", "30"}], {9, 8}], InsetBox[
        RowBox[{"-", "35"}], {10, 8}], InsetBox[
        RowBox[{"-", "40"}], {11, 8}], InsetBox[
        RowBox[{"-", "45"}], {12, 8}], InsetBox[
        RowBox[{"-", "50"}], {13, 8}], InsetBox[
        RowBox[{"-", "55"}], {14, 8}]}, {InsetBox[
        RowBox[{"-", "10"}], {1, 7}], InsetBox["0", {2, 7}], 
       InsetBox["3", {3, 7}], InsetBox[
        RowBox[{"-", "2"}], {4, 7}], InsetBox[
        RowBox[{"-", "5"}], {5, 7}], InsetBox[
        RowBox[{"-", "9"}], {6, 7}], InsetBox[
        RowBox[{"-", "14"}], {7, 7}], InsetBox[
        RowBox[{"-", "19"}], {8, 7}], InsetBox[
        RowBox[{"-", "24"}], {9, 7}], InsetBox[
        RowBox[{"-", "29"}], {10, 7}], InsetBox[
        RowBox[{"-", "34"}], {11, 7}], InsetBox[
        RowBox[{"-", "39"}], {12, 7}], InsetBox[
        RowBox[{"-", "44"}], {13, 7}], InsetBox[
        RowBox[{"-", "49"}], {14, 7}]}, {InsetBox[
        RowBox[{"-", "15"}], {1, 6}], InsetBox[
        RowBox[{"-", "5"}], {2, 6}], InsetBox["3", {3, 6}], 
       InsetBox["9", {4, 6}], InsetBox["4", {5, 6}], InsetBox[
        RowBox[{"-", "1"}], {6, 6}], InsetBox[
        RowBox[{"-", "6"}], {7, 6}], InsetBox[
        RowBox[{"-", "11"}], {8, 6}], InsetBox[
        RowBox[{"-", "16"}], {9, 6}], InsetBox[
        RowBox[{"-", "21"}], {10, 6}], InsetBox[
        RowBox[{"-", "26"}], {11, 6}], InsetBox[
        RowBox[{"-", "31"}], {12, 6}], InsetBox[
        RowBox[{"-", "36"}], {13, 6}], InsetBox[
        RowBox[{"-", "41"}], {14, 6}]}, {InsetBox[
        RowBox[{"-", "20"}], {1, 5}], InsetBox[
        RowBox[{"-", "10"}], {2, 5}], InsetBox[
        RowBox[{"-", "2"}], {3, 5}], InsetBox["4", {4, 5}], 
       InsetBox["17", {5, 5}], InsetBox["12", {6, 5}], InsetBox["7", {7, 5}], 
       InsetBox["2", {8, 5}], InsetBox[
        RowBox[{"-", "3"}], {9, 5}], InsetBox[
        RowBox[{"-", "8"}], {10, 5}], InsetBox[
        RowBox[{"-", "13"}], {11, 5}], InsetBox[
        RowBox[{"-", "18"}], {12, 5}], InsetBox[
        RowBox[{"-", "23"}], {13, 5}], InsetBox[
        RowBox[{"-", "28"}], {14, 5}]}, {InsetBox[
        RowBox[{"-", "25"}], {1, 4}], InsetBox[
        RowBox[{"-", "15"}], {2, 4}], InsetBox[
        RowBox[{"-", "7"}], {3, 4}], InsetBox[
        RowBox[{"-", "1"}], {4, 4}], InsetBox["12", {5, 4}], 
       InsetBox["17", {6, 4}], InsetBox["12", {7, 4}], InsetBox["7", {8, 4}], 
       InsetBox["8", {9, 4}], InsetBox["3", {10, 4}], InsetBox[
        RowBox[{"-", "2"}], {11, 4}], InsetBox[
        RowBox[{"-", "7"}], {12, 4}], InsetBox[
        RowBox[{"-", "12"}], {13, 4}], InsetBox[
        RowBox[{"-", "17"}], {14, 4}]}, {InsetBox[
        RowBox[{"-", "30"}], {1, 3}], InsetBox[
        RowBox[{"-", "20"}], {2, 3}], InsetBox[
        RowBox[{"-", "12"}], {3, 3}], InsetBox[
        RowBox[{"-", "6"}], {4, 3}], InsetBox["7", {5, 3}], 
       InsetBox["12", {6, 3}], InsetBox["17", {7, 3}], InsetBox["18", {8, 3}],
        InsetBox["13", {9, 3}], InsetBox["14", {10, 3}], 
       InsetBox["9", {11, 3}], InsetBox["4", {12, 3}], InsetBox[
        RowBox[{"-", "1"}], {13, 3}], InsetBox[
        RowBox[{"-", "6"}], {14, 3}]}, {InsetBox[
        RowBox[{"-", "35"}], {1, 2}], InsetBox[
        RowBox[{"-", "25"}], {2, 2}], InsetBox[
        RowBox[{"-", "17"}], {3, 2}], InsetBox[
        RowBox[{"-", "11"}], {4, 2}], InsetBox["2", {5, 2}], 
       InsetBox["7", {6, 2}], InsetBox["12", {7, 2}], InsetBox["15", {8, 2}], 
       InsetBox["19", {9, 2}], InsetBox["14", {10, 2}], 
       InsetBox["22", {11, 2}], InsetBox["17", {12, 2}], 
       InsetBox["12", {13, 2}], InsetBox["7", {14, 2}]}, {InsetBox[
        RowBox[{"-", "40"}], {1, 1}], InsetBox[
        RowBox[{"-", "30"}], {2, 1}], InsetBox[
        RowBox[{"-", "22"}], {3, 1}], InsetBox[
        RowBox[{"-", "16"}], {4, 1}], InsetBox[
        RowBox[{"-", "3"}], {5, 1}], InsetBox["2", {6, 1}], 
       InsetBox["7", {7, 1}], InsetBox["10", {8, 1}], InsetBox["15", {9, 1}], 
       InsetBox["17", {10, 1}], InsetBox["17", {11, 1}], 
       InsetBox["23", {12, 1}], InsetBox["18", {13, 1}], 
       InsetBox["17", {14, 1}]}}}, 
    {GrayLevel[0.9], PointBox[{0, 0.6}]}, 
    {Arrowheads[Small], ArrowBox[{{1.7, 9.}, {1.3, 9.}}]}, 
    {Arrowheads[Small], ArrowBox[{{2.7, 9.}, {2.3, 9.}}]}, 
    {Arrowheads[Small], ArrowBox[{{3.7, 9.}, {3.3, 9.}}]}, 
    {Arrowheads[Small], ArrowBox[{{4.7, 9.}, {4.3, 9.}}]}, 
    {Arrowheads[Small], ArrowBox[{{5.7, 9.}, {5.3, 9.}}]}, 
    {Arrowheads[Small], ArrowBox[{{6.7, 9.}, {6.3, 9.}}]}, 
    {Arrowheads[Small], ArrowBox[{{7.7, 9.}, {7.3, 9.}}]}, 
    {Arrowheads[Small], ArrowBox[{{8.7, 9.}, {8.3, 9.}}]}, 
    {Arrowheads[Small], ArrowBox[{{9.7, 9.}, {9.3, 9.}}]}, 
    {Arrowheads[Small], ArrowBox[{{10.7, 9.}, {10.3, 9.}}]}, 
    {Arrowheads[Small], ArrowBox[{{11.7, 9.}, {11.3, 9.}}]}, 
    {Arrowheads[Small], ArrowBox[{{12.7, 9.}, {12.3, 9.}}]}, 
    {Arrowheads[Small], ArrowBox[{{13.7, 9.}, {13.3, 9.}}]}, 
    {Arrowheads[Small], ArrowBox[{{1, 8.2}, {1, 8.8}}]}, 
    {Arrowheads[Small], ArrowBox[{{1.8, 8.2}, {1.2, 8.8}}]}, 
    {Arrowheads[Small], ArrowBox[{{2.7, 8.}, {2.3, 8.}}]}, 
    {Arrowheads[Small], ArrowBox[{{3.7, 8.}, {3.3, 8.}}]}, 
    {Arrowheads[Small], ArrowBox[{{4.7, 8.}, {4.3, 8.}}]}, 
    {Arrowheads[Small], ArrowBox[{{5.8, 8.2}, {5.2, 8.8}}]}, 
    {Arrowheads[Small], ArrowBox[{{6.7, 8.}, {6.3, 8.}}]}, 
    {Arrowheads[Small], ArrowBox[{{7.7, 8.}, {7.3, 8.}}]}, 
    {Arrowheads[Small], ArrowBox[{{8.7, 8.}, {8.3, 8.}}]}, 
    {Arrowheads[Small], ArrowBox[{{9.7, 8.}, {9.3, 8.}}]}, 
    {Arrowheads[Small], ArrowBox[{{10.7, 8.}, {10.3, 8.}}]}, 
    {Arrowheads[Small], ArrowBox[{{11.7, 8.}, {11.3, 8.}}]}, 
    {Arrowheads[Small], ArrowBox[{{12.7, 8.}, {12.3, 8.}}]}, 
    {Arrowheads[Small], ArrowBox[{{13.7, 8.}, {13.3, 8.}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{1, 7.199999999999999}, {1, 7.800000000000001}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{2, 7.199999999999999}, {2, 7.800000000000001}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{2.8, 7.199999999999999}, {2.2, 7.800000000000001}}]}, 
    {Arrowheads[Small], ArrowBox[{{3.7, 7.}, {3.3, 7.}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{4.8, 7.199999999999999}, {4.2, 7.800000000000001}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{5.8, 7.199999999999999}, {5.2, 7.800000000000001}}]}, 
    {Arrowheads[Small], ArrowBox[{{6.7, 7.}, {6.3, 7.}}]}, 
    {Arrowheads[Small], ArrowBox[{{7.7, 7.}, {7.3, 7.}}]}, 
    {Arrowheads[Small], ArrowBox[{{8.7, 7.}, {8.3, 7.}}]}, 
    {Arrowheads[Small], ArrowBox[{{9.7, 7.}, {9.3, 7.}}]}, 
    {Arrowheads[Small], ArrowBox[{{10.7, 7.}, {10.3, 7.}}]}, 
    {Arrowheads[Small], ArrowBox[{{11.7, 7.}, {11.3, 7.}}]}, 
    {Arrowheads[Small], ArrowBox[{{12.7, 7.}, {12.3, 7.}}]}, 
    {Arrowheads[Small], ArrowBox[{{13.7, 7.}, {13.3, 7.}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{1, 6.199999999999999}, {1, 6.800000000000001}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{2, 6.199999999999999}, {2, 6.800000000000001}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{2.8, 6.199999999999999}, {2.2, 6.800000000000001}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{3.8, 6.199999999999999}, {3.2, 6.800000000000001}}]}, 
    {Arrowheads[Small], ArrowBox[{{4.7, 6.}, {4.3, 6.}}]}, 
    {Arrowheads[Small], ArrowBox[{{5.7, 6.}, {5.3, 6.}}]}, 
    {Arrowheads[Small], ArrowBox[{{6.7, 6.}, {6.3, 6.}}]}, 
    {Arrowheads[Small], ArrowBox[{{7.7, 6.}, {7.3, 6.}}]}, 
    {Arrowheads[Small], ArrowBox[{{8.7, 6.}, {8.3, 6.}}]}, 
    {Arrowheads[Small], ArrowBox[{{9.7, 6.}, {9.3, 6.}}]}, 
    {Arrowheads[Small], ArrowBox[{{10.7, 6.}, {10.3, 6.}}]}, 
    {Arrowheads[Small], ArrowBox[{{11.7, 6.}, {11.3, 6.}}]}, 
    {Arrowheads[Small], ArrowBox[{{12.7, 6.}, {12.3, 6.}}]}, 
    {Arrowheads[Small], ArrowBox[{{13.7, 6.}, {13.3, 6.}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{1, 5.199999999999999}, {1, 5.800000000000001}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{2, 5.199999999999999}, {2, 5.800000000000001}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{3, 5.199999999999999}, {3, 5.800000000000001}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{4, 5.199999999999999}, {4, 5.800000000000001}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{4.8, 5.199999999999999}, {4.2, 5.800000000000001}}]}, 
    {Arrowheads[Small], ArrowBox[{{5.7, 5.}, {5.3, 5.}}]}, 
    {Arrowheads[Small], ArrowBox[{{6.7, 5.}, {6.3, 5.}}]}, 
    {Arrowheads[Small], ArrowBox[{{7.7, 5.}, {7.3, 5.}}]}, 
    {Arrowheads[Small], ArrowBox[{{8.7, 5.}, {8.3, 5.}}]}, 
    {Arrowheads[Small], ArrowBox[{{9.7, 5.}, {9.3, 5.}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{10.8, 5.199999999999999}, {10.2, 5.800000000000001}}]}, 
    {Arrowheads[Small], ArrowBox[{{11.7, 5.}, {11.3, 5.}}]}, 
    {Arrowheads[Small], ArrowBox[{{12.7, 5.}, {12.3, 5.}}]}, 
    {Arrowheads[Small], ArrowBox[{{13.7, 5.}, {13.3, 5.}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{1, 4.199999999999999}, {1, 4.800000000000001}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{2, 4.199999999999999}, {2, 4.800000000000001}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{3, 4.199999999999999}, {3, 4.800000000000001}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{4, 4.199999999999999}, {4, 4.800000000000001}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{5, 4.199999999999999}, {5, 4.800000000000001}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{5.8, 4.199999999999999}, {5.2, 4.800000000000001}}]}, 
    {Arrowheads[Small], ArrowBox[{{6.7, 4.}, {6.3, 4.}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{7.8, 4.199999999999999}, {7.2, 4.800000000000001}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{8.8, 4.199999999999999}, {8.2, 4.800000000000001}}]}, 
    {Arrowheads[Small], ArrowBox[{{9.7, 4.}, {9.3, 4.}}]}, 
    {Arrowheads[Small], ArrowBox[{{10.7, 4.}, {10.3, 4.}}]}, 
    {Arrowheads[Small], ArrowBox[{{11.7, 4.}, {11.3, 4.}}]}, 
    {Arrowheads[Small], ArrowBox[{{12.7, 4.}, {12.3, 4.}}]}, 
    {Arrowheads[Small], ArrowBox[{{13.7, 4.}, {13.3, 4.}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{1, 3.1999999999999993`}, {1, 3.8000000000000007`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{2, 3.1999999999999993`}, {2, 3.8000000000000007`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{3, 3.1999999999999993`}, {3, 3.8000000000000007`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{4, 3.1999999999999993`}, {4, 3.8000000000000007`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{5, 3.1999999999999993`}, {5, 3.8000000000000007`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{6, 3.1999999999999993`}, {6, 3.8000000000000007`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{6.8, 3.1999999999999993`}, {6.2, 3.8000000000000007`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{7.8, 3.1999999999999993`}, {7.2, 3.8000000000000007`}}]}, 
    {Arrowheads[Small], ArrowBox[{{8.7, 3.}, {8.3, 3.}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{9.8, 3.1999999999999993`}, {9.2, 3.8000000000000007`}}]}, 
    {Arrowheads[Small], ArrowBox[{{10.7, 3.}, {10.3, 3.}}]}, 
    {Arrowheads[Small], ArrowBox[{{11.7, 3.}, {11.3, 3.}}]}, 
    {Arrowheads[Small], ArrowBox[{{12.7, 3.}, {12.3, 3.}}]}, 
    {Arrowheads[Small], ArrowBox[{{13.7, 3.}, {13.3, 3.}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{1, 2.1999999999999993`}, {1, 2.8000000000000007`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{2, 2.1999999999999993`}, {2, 2.8000000000000007`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{3, 2.1999999999999993`}, {3, 2.8000000000000007`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{4, 2.1999999999999993`}, {4, 2.8000000000000007`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{4.8, 2.1999999999999993`}, {4.2, 2.8000000000000007`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{6, 2.1999999999999993`}, {6, 2.8000000000000007`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{7, 2.1999999999999993`}, {7, 2.8000000000000007`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{7.8, 2.1999999999999993`}, {7.2, 2.8000000000000007`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{8.8, 2.1999999999999993`}, {8.2, 2.8000000000000007`}}]}, 
    {Arrowheads[Small], ArrowBox[{{9.7, 2.}, {9.3, 2.}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{10.8, 2.1999999999999993`}, {10.2, 2.8000000000000007`}}]}, 
    {Arrowheads[Small], ArrowBox[{{11.7, 2.}, {11.3, 2.}}]}, 
    {Arrowheads[Small], ArrowBox[{{12.7, 2.}, {12.3, 2.}}]}, 
    {Arrowheads[Small], ArrowBox[{{13.7, 2.}, {13.3, 2.}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{1, 1.1999999999999993`}, {1, 1.8000000000000007`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{2, 1.1999999999999993`}, {2, 1.8000000000000007`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{3, 1.1999999999999993`}, {3, 1.8000000000000007`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{4, 1.1999999999999993`}, {4, 1.8000000000000007`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{5, 1.1999999999999993`}, {5, 1.8000000000000007`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{6, 1.1999999999999993`}, {6, 1.8000000000000007`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{6.8, 1.1999999999999993`}, {6.2, 1.8000000000000007`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{7.8, 1.1999999999999993`}, {7.2, 1.8000000000000007`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{8.8, 1.1999999999999993`}, {8.2, 1.8000000000000007`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{9.8, 1.1999999999999993`}, {9.2, 1.8000000000000007`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{11, 1.1999999999999993`}, {11, 1.8000000000000007`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{11.8, 1.1999999999999993`}, {11.2, 1.8000000000000007`}}]}, 
    {Arrowheads[Small], ArrowBox[{{12.7, 1.}, {12.3, 1.}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{13.8, 1.1999999999999993`}, {13.2, 1.8000000000000007`}}]}}, 
   {RGBColor[1, 0, 0], AbsoluteThickness[2], Arrowheads[Small], 
    ArrowBox[{{13.8, 1.1999999999999993`}, {13.2, 1.8000000000000007`}}]}, 
   {RGBColor[1, 0, 0], AbsoluteThickness[2], Arrowheads[Small], 
    ArrowBox[{{12.7, 2.}, {12.3, 2.}}]}, 
   {RGBColor[1, 0, 0], AbsoluteThickness[2], Arrowheads[Small], 
    ArrowBox[{{11.7, 2.}, {11.3, 2.}}]}, 
   {RGBColor[1, 0, 0], AbsoluteThickness[2], Arrowheads[Small], 
    ArrowBox[{{10.8, 2.1999999999999993`}, {10.2, 2.8000000000000007`}}]}, 
   {RGBColor[1, 0, 0], AbsoluteThickness[2], Arrowheads[Small], 
    ArrowBox[{{9.8, 3.1999999999999993`}, {9.2, 3.8000000000000007`}}]}, 
   {RGBColor[1, 0, 0], AbsoluteThickness[2], Arrowheads[Small], 
    ArrowBox[{{8.8, 4.199999999999999}, {8.2, 4.800000000000001}}]}, 
   {RGBColor[1, 0, 0], AbsoluteThickness[2], Arrowheads[Small], 
    ArrowBox[{{7.7, 5.}, {7.3, 5.}}]}, 
   {RGBColor[1, 0, 0], AbsoluteThickness[2], Arrowheads[Small], 
    ArrowBox[{{6.7, 5.}, {6.3, 5.}}]}, 
   {RGBColor[1, 0, 0], AbsoluteThickness[2], Arrowheads[Small], 
    ArrowBox[{{5.7, 5.}, {5.3, 5.}}]}, 
   {RGBColor[1, 0, 0], AbsoluteThickness[2], Arrowheads[Small], 
    ArrowBox[{{4.8, 5.199999999999999}, {4.2, 5.800000000000001}}]}, 
   {RGBColor[1, 0, 0], AbsoluteThickness[2], Arrowheads[Small], 
    ArrowBox[{{3.8, 6.199999999999999}, {3.2, 6.800000000000001}}]}, 
   {RGBColor[1, 0, 0], AbsoluteThickness[2], Arrowheads[Small], 
    ArrowBox[{{2.8, 7.199999999999999}, {2.2, 7.800000000000001}}]}, 
   {RGBColor[1, 0, 0], AbsoluteThickness[2], Arrowheads[Small], 
    ArrowBox[{{1.8, 8.2}, {1.2, 8.8}}]}},
  PlotRange->All]], "Output",
 CellChangeTimes->{3.6775716910607214`*^9}]
}, Open  ]],

Cell["\<\
Das Resultat ist in Abb. 3.11 gezeigt.
\
\>", "Text",
 CellChangeTimes->{{3.674635123514552*^9, 3.674635141461581*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-Exkurs: ",
 "Ausgabe des Alignments und weitere Tests"
}], "Subtitle",
 CellChangeTimes->{3.670321495640956*^9, 3.670402706588908*^9, 
  3.670402787620543*^9, 3.670403164706111*^9},
 Background->RGBColor[
  0.8705882352941177, 0.00392156862745098, 0.2196078431372549]],

Cell[TextData[{
 "Wie wir gesehen haben, \[UDoubleDot]bersetzen sich die Zeigerzust\
\[ADoubleDot]nde entlang des wahrscheinlichsten Pfads direkt in \
Handlungsanweisungen zur Konstruktion des Alignments. So bedeutet ein \
Zeigerzustand von 1 etwa, dass die zwei n\[ADoubleDot]chsten Symbole \
kombiniert werden, die anderen beiden Zust\[ADoubleDot]nde erfordern die \
Kombination eines Symbols mit einem Gap. Wir implementieren diese \
Vorschriften mithilfe einer ",
 StyleBox["While",
  FontWeight->"Bold"],
 "-Schleife. Zwei Z\[ADoubleDot]hlvariablen, ",
 StyleBox["count1",
  FontWeight->"Bold"],
 " und ",
 StyleBox["count2",
  FontWeight->"Bold"],
 ", geben die aktuelle Position in den beiden Sequenzen an. Die Konstruktion \
erfolgt von hinten nach vorne in den Sequenzen. Dabei werden die Spalten in \
der folgenden Weise aufgebaut: Symbol aus Sequenz 1, Verbindungssymbol (also \
Leerzeichen oder Strich), Symbol aus Sequenz 2. Diese Spalten werden bei \
jedem Schleifendurchlauf in die Funktion ",
 StyleBox["alig ",
  FontWeight->"Bold"],
 "geschrieben, die als Argument die dritte Z\[ADoubleDot]hlvariable ",
 StyleBox["j",
  FontWeight->"Bold"],
 " besitzt."
}], "Text",
 CellChangeTimes->{{3.674635175271635*^9, 3.674635179836642*^9}, 
   3.674635230424716*^9, {3.674635264545765*^9, 3.674635276203783*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"count1", "=", "0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"count2", "=", "0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"j", "=", "0"}], ";"}], "\n", 
 RowBox[{"While", "[", 
  RowBox[{
   RowBox[{"j", "<", 
    RowBox[{"Length", "[", "path2", "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"j", "=", 
      RowBox[{"j", "+", "1"}]}], ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"path2", "[", 
         RowBox[{"[", "j", "]"}], "]"}], "\[Equal]", "1"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"count1", "=", 
          RowBox[{"count1", "+", "1"}]}], ",", 
         RowBox[{"count2", "=", 
          RowBox[{"count2", "+", "1"}]}], ",", 
         RowBox[{
          RowBox[{"alig", "[", "j", "]"}], "=", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"prot1", "[", 
             RowBox[{"[", 
              RowBox[{"-", "count1"}], "]"}], "]"}], ",", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"prot1", "[", 
                RowBox[{"[", 
                 RowBox[{"-", "count1"}], "]"}], "]"}], "==", 
               RowBox[{"prot2", "[", 
                RowBox[{"[", 
                 RowBox[{"-", "count2"}], "]"}], "]"}]}], ",", "\"\<|\>\"", 
              ",", "\"\< \>\""}], "]"}], ",", 
            RowBox[{"prot2", "[", 
             RowBox[{"[", 
              RowBox[{"-", "count2"}], "]"}], "]"}]}], "}"}]}]}], "}"}], ",", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"path2", "[", 
           RowBox[{"[", "j", "]"}], "]"}], "\[Equal]", "2"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"count1", "=", 
            RowBox[{"count1", "+", "1"}]}], ",", 
           RowBox[{
            RowBox[{"alig", "[", "j", "]"}], "=", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"prot1", "[", 
               RowBox[{"[", 
                RowBox[{"-", "count1"}], "]"}], "]"}], ",", "\"\< \>\"", ",", 
              "\"\<-\>\""}], "}"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"path2", "[", 
             RowBox[{"[", "j", "]"}], "]"}], "\[Equal]", "3"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"count2", "=", 
              RowBox[{"count2", "+", "1"}]}], ",", 
             RowBox[{
              RowBox[{"alig", "[", "j", "]"}], "=", 
              RowBox[{"{", 
               RowBox[{"\"\<-\>\"", ",", "\"\< \>\"", ",", 
                RowBox[{"prot2", "[", 
                 RowBox[{"[", 
                  RowBox[{"-", "count2"}], "]"}], "]"}]}], "}"}]}]}], "}"}]}],
           "]"}]}], "]"}]}], "]"}]}], "\[IndentingNewLine]", "}"}]}], 
  "]"}]}], "Input"],

Cell[TextData[{
 "Die Ausgabe erfolgt \[UDoubleDot]ber einen entsprechenden ",
 StyleBox["Table",
  FontWeight->"Bold"],
 "-Befehl, zusammen mit einer Formatierung \[UDoubleDot]ber den Befehl ",
 StyleBox["TableForm",
  FontWeight->"Bold"],
 ", den wir im ersten ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-Exkurs dieses Kapitels bereits kennengelernt haben:"
}], "Text",
 CellChangeTimes->{{3.674635292484807*^9, 3.674635331705866*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"alFull", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"alig", "[", "i", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "j", ",", "1", ",", 
      RowBox[{"-", "1"}]}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"K\"\>", ",", "\<\"|\"\>", ",", "\<\"K\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"E\"\>", ",", "\<\" \"\>", ",", "\<\"Y\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"F\"\>", ",", "\<\"|\"\>", ",", "\<\"F\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"H\"\>", ",", "\<\"|\"\>", ",", "\<\"H\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"-\"\>", ",", "\<\" \"\>", ",", "\<\"K\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"-\"\>", ",", "\<\" \"\>", ",", "\<\"A\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"-\"\>", ",", "\<\" \"\>", ",", "\<\"G\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"N\"\>", ",", "\<\"|\"\>", ",", "\<\"N\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"G\"\>", ",", "\<\"|\"\>", ",", "\<\"G\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"H\"\>", ",", "\<\"|\"\>", ",", "\<\"H\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"-\"\>", ",", "\<\" \"\>", ",", "\<\"S\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"-\"\>", ",", "\<\" \"\>", ",", "\<\"P\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"T\"\>", ",", "\<\"|\"\>", ",", "\<\"T\"\>"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.6775716911231213`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Transpose", "[", "alFull", "]"}], "//", "TableForm"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"K\"\>", "\<\"E\"\>", "\<\"F\"\>", "\<\"H\"\>", "\<\"-\"\>", \
"\<\"-\"\>", "\<\"-\"\>", "\<\"N\"\>", "\<\"G\"\>", "\<\"H\"\>", "\<\"-\"\>", \
"\<\"-\"\>", "\<\"T\"\>"},
    {"\<\"|\"\>", "\<\" \"\>", "\<\"|\"\>", "\<\"|\"\>", "\<\" \"\>", "\<\" \
\"\>", "\<\" \"\>", "\<\"|\"\>", "\<\"|\"\>", "\<\"|\"\>", "\<\" \"\>", "\<\" \
\"\>", "\<\"|\"\>"},
    {"\<\"K\"\>", "\<\"Y\"\>", "\<\"F\"\>", "\<\"H\"\>", "\<\"K\"\>", \
"\<\"A\"\>", "\<\"G\"\>", "\<\"N\"\>", "\<\"G\"\>", "\<\"H\"\>", "\<\"S\"\>", \
"\<\"P\"\>", "\<\"T\"\>"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.6775716911387215`*^9}]
}, Open  ]],

Cell[TextData[{
 "Die Zusammenfassung aller Befehle in einer ",
 StyleBox["Module",
  FontWeight->"Bold"],
 "-Umgebung ist im Folgenden angegeben."
}], "Text",
 CellChangeTimes->{{3.6746354665200734`*^9, 3.674635474571086*^9}, {
  3.674635525661167*^9, 3.67463552749317*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"xxcoordFun", "[", 
    RowBox[{
    "ref_", ",", "seq1_", ",", "seq2_", ",", "posA_", ",", "posB_", ",", 
     "mat_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"tmp1", ",", "tmp2", ",", "tmp3", ",", "tmp4"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"tmp1", "=", 
       RowBox[{"seq1", "[", 
        RowBox[{"[", "posA", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"tmp2", "=", 
       RowBox[{"seq2", "[", 
        RowBox[{"[", "posB", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"tmp3", "=", 
       RowBox[{
        RowBox[{"Position", "[", 
         RowBox[{"ref", ",", "tmp1"}], "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"tmp4", "=", 
       RowBox[{
        RowBox[{"Position", "[", 
         RowBox[{"ref", ",", "tmp2"}], "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"mat", "[", 
       RowBox[{"[", 
        RowBox[{"tmp3", ",", "tmp4"}], "]"}], "]"}]}]}], "]"}]}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"alignment", "[", 
    RowBox[{"seq1_", ",", "seq2_", ",", "mat_", ",", "del_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "xxproteinRef", ",", "xxmatF", ",", "xxmatFTab", ",", "xxtmp1", ",", 
       "j", ",", "xxmatFTabA", ",", "xxmatFTabB", ",", "xxdX", ",", "xxtraX", 
       ",", "xxpath1", ",", "xxpath2", ",", "xxcount1", ",", "xxcount2", ",", 
       "xxalig", ",", "xxalFull"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"xxproteinRef", "=", 
       RowBox[{"Characters", "[", "\"\<ARNDCQEGHILKMFPSTWYVBZX*\>\"", "]"}]}],
       ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"xxmatF", "[", 
        RowBox[{"0", ",", "0"}], "]"}], "=", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"xxmatF", "[", 
        RowBox[{"i_", ",", "0"}], "]"}], "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "i"}], "*", "del"}], ",", "2"}], "}"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"xxmatF", "[", 
        RowBox[{"0", ",", "j_"}], "]"}], "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "j"}], "*", "del"}], ",", "3"}], "}"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"xxtmp1", "=", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"xxmatF", "[", 
                RowBox[{
                 RowBox[{"i", "-", "1"}], ",", 
                 RowBox[{"j", "-", "1"}]}], "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}], "+", 
              RowBox[{"xxcoordFun", "[", 
               RowBox[{
               "xxproteinRef", ",", "seq1", ",", "seq2", ",", "i", ",", "j", 
                ",", "mat"}], "]"}]}], ",", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{
               RowBox[{"xxmatF", "[", 
                RowBox[{
                 RowBox[{"i", "-", "1"}], ",", "j"}], "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}], "-", "del"}], ",", 
             RowBox[{
              RowBox[{
               RowBox[{"xxmatF", "[", 
                RowBox[{"i", ",", 
                 RowBox[{"j", "-", "1"}]}], "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}], "-", "del"}]}], "}"}]}], ";", 
          RowBox[{
           RowBox[{"xxmatF", "[", 
            RowBox[{"i", ",", "j"}], "]"}], "=", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Max", "[", "xxtmp1", "]"}], ",", 
             RowBox[{
              RowBox[{"Position", "[", 
               RowBox[{"xxtmp1", ",", 
                RowBox[{"Max", "[", "xxtmp1", "]"}]}], "]"}], "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "}"}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"Length", "[", "seq1", "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "1", ",", 
          RowBox[{"Length", "[", "seq2", "]"}]}], "}"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"xxmatFTab", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"xxmatF", "[", 
          RowBox[{"i", ",", "j"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "0", ",", 
           RowBox[{"Length", "[", "seq1", "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "0", ",", 
           RowBox[{"Length", "[", "seq2", "]"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"xxmatFTabA", "=", 
       RowBox[{"xxmatFTab", "/.", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"n1_", ",", "n2_Integer"}], "}"}], "\[Rule]", "n1"}]}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"xxmatFTabB", "=", 
       RowBox[{"xxmatFTab", "/.", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"n1_", ",", "n2_Integer"}], "}"}], "\[Rule]", "n2"}]}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"xxdX", "=", 
       RowBox[{"Dimensions", "[", "xxmatFTabB", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"xxtraX", "[", "1", "]"}], "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"xxdX", "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", 
         RowBox[{"xxdX", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "}"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"j", "=", "1"}], ";", "\[IndentingNewLine]", 
      RowBox[{"While", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"xxmatFTabB", "[", 
          RowBox[{"[", 
           RowBox[{"Sequence", "@@", 
            RowBox[{"xxtraX", "[", "j", "]"}]}], "]"}], "]"}], "=!=", "0"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"xxtraX", "[", 
            RowBox[{"j", "+", "1"}], "]"}], "=", 
           RowBox[{
            RowBox[{"xxtraX", "[", "j", "]"}], "-", 
            RowBox[{"Switch", "[", 
             RowBox[{
              RowBox[{"xxmatFTabB", "[", 
               RowBox[{"[", 
                RowBox[{"Sequence", "@@", 
                 RowBox[{"xxtraX", "[", "j", "]"}]}], "]"}], "]"}], ",", "1", 
              ",", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], ",", "2", ",", 
              RowBox[{"{", 
               RowBox[{"1", ",", "0"}], "}"}], ",", "3", ",", 
              RowBox[{"{", 
               RowBox[{"0", ",", "1"}], "}"}]}], "]"}]}]}], ",", 
          RowBox[{"j", "=", 
           RowBox[{"j", "+", "1"}]}]}], "}"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"xxpath1", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"xxtraX", "[", "k", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"k", ",", "1", ",", 
           RowBox[{"j", "-", "1"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"xxpath2", "=", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"xxmatFTabB", "[", 
           RowBox[{"[", 
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "1", "]"}], "]"}], ",", 
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}], "&"}], ",", 
         "xxpath1"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"xxcount1", "=", "0"}], ";", "\[IndentingNewLine]", 
      RowBox[{"xxcount2", "=", "0"}], ";", "\[IndentingNewLine]", 
      RowBox[{"j", "=", "0"}], ";", "\[IndentingNewLine]", 
      RowBox[{"While", "[", 
       RowBox[{
        RowBox[{"j", "<", 
         RowBox[{"Length", "[", "xxpath2", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"j", "=", 
           RowBox[{"j", "+", "1"}]}], ",", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"xxpath2", "[", 
              RowBox[{"[", "j", "]"}], "]"}], "\[Equal]", "1"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"xxcount1", "=", 
               RowBox[{"xxcount1", "+", "1"}]}], ",", 
              RowBox[{"xxcount2", "=", 
               RowBox[{"xxcount2", "+", "1"}]}], ",", 
              RowBox[{
               RowBox[{"xxalig", "[", "j", "]"}], "=", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"seq1", "[", 
                  RowBox[{"[", 
                   RowBox[{"-", "xxcount1"}], "]"}], "]"}], ",", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"seq1", "[", 
                    RowBox[{"[", 
                    RowBox[{"-", "xxcount1"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"seq2", "[", 
                    RowBox[{"[", 
                    RowBox[{"-", "xxcount2"}], "]"}], "]"}]}], ",", 
                   "\"\<|\>\"", ",", "\"\< \>\""}], "]"}], ",", 
                 RowBox[{"seq2", "[", 
                  RowBox[{"[", 
                   RowBox[{"-", "xxcount2"}], "]"}], "]"}]}], "}"}]}]}], 
             "}"}], ",", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"xxpath2", "[", 
                RowBox[{"[", "j", "]"}], "]"}], "\[Equal]", "2"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"xxcount1", "=", 
                 RowBox[{"xxcount1", "+", "1"}]}], ",", 
                RowBox[{
                 RowBox[{"xxalig", "[", "j", "]"}], "=", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"seq1", "[", 
                    RowBox[{"[", 
                    RowBox[{"-", "xxcount1"}], "]"}], "]"}], ",", "\"\< \>\"",
                    ",", "\"\<-\>\""}], "}"}]}]}], "}"}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"xxpath2", "[", 
                  RowBox[{"[", "j", "]"}], "]"}], "\[Equal]", "3"}], ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"xxcount2", "=", 
                   RowBox[{"xxcount2", "+", "1"}]}], ",", 
                  RowBox[{
                   RowBox[{"xxalig", "[", "j", "]"}], "=", 
                   RowBox[{"{", 
                    RowBox[{"\"\<-\>\"", ",", "\"\< \>\"", ",", 
                    RowBox[{"seq2", "[", 
                    RowBox[{"[", 
                    RowBox[{"-", "xxcount2"}], "]"}], "]"}]}], "}"}]}]}], 
                 "}"}]}], "]"}]}], "]"}]}], "]"}]}], "}"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"xxalFull", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"xxalig", "[", "i", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "j", ",", "1", ",", 
           RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Transpose", "[", "xxalFull", "]"}], "//", "TableForm"}]}]}], 
    "]"}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"alignmentScore", "[", 
     RowBox[{"seq1_", ",", "seq2_", ",", "mat_", ",", "del_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "xxproteinRef", ",", "xxFF", ",", "xxFFTab", ",", "xxtmp1", ",", "j", 
        ",", "xxFFTabA", ",", "xxFFTabB", ",", "xxdX", ",", "xxtraX", ",", 
        "xxpath1", ",", "xxpath2", ",", "xxcount1", ",", "xxcount2", ",", 
        "xxalig", ",", "xxalFull"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"xxproteinRef", "=", 
        RowBox[{
        "Characters", "[", "\"\<ARNDCQEGHILKMFPSTWYVBZX*\>\"", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"xxFF", "[", 
         RowBox[{"0", ",", "0"}], "]"}], "=", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"xxFF", "[", 
         RowBox[{"i_", ",", "0"}], "]"}], "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "i"}], "*", "del"}], ",", "2"}], "}"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"xxFF", "[", 
         RowBox[{"0", ",", "j_"}], "]"}], "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "j"}], "*", "del"}], ",", "3"}], "}"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"xxtmp1", "=", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"xxFF", "[", 
                 RowBox[{
                  RowBox[{"i", "-", "1"}], ",", 
                  RowBox[{"j", "-", "1"}]}], "]"}], "[", 
                RowBox[{"[", "1", "]"}], "]"}], "+", 
               RowBox[{"xxcoordFun", "[", 
                RowBox[{
                "xxproteinRef", ",", "seq1", ",", "seq2", ",", "i", ",", "j", 
                 ",", "mat"}], "]"}]}], ",", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{
                RowBox[{"xxFF", "[", 
                 RowBox[{
                  RowBox[{"i", "-", "1"}], ",", "j"}], "]"}], "[", 
                RowBox[{"[", "1", "]"}], "]"}], "-", "del"}], ",", 
              RowBox[{
               RowBox[{
                RowBox[{"xxFF", "[", 
                 RowBox[{"i", ",", 
                  RowBox[{"j", "-", "1"}]}], "]"}], "[", 
                RowBox[{"[", "1", "]"}], "]"}], "-", "del"}]}], "}"}]}], ";", 
           RowBox[{
            RowBox[{"xxFF", "[", 
             RowBox[{"i", ",", "j"}], "]"}], "=", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Max", "[", "xxtmp1", "]"}], ",", 
              RowBox[{
               RowBox[{"Position", "[", 
                RowBox[{"xxtmp1", ",", 
                 RowBox[{"Max", "[", "xxtmp1", "]"}]}], "]"}], "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "}"}]}]}], "}"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", "seq1", "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "1", ",", 
           RowBox[{"Length", "[", "seq2", "]"}]}], "}"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"xxFFTab", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"xxFF", "[", 
           RowBox[{"i", ",", "j"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "0", ",", 
            RowBox[{"Length", "[", "seq1", "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "0", ",", 
            RowBox[{"Length", "[", "seq2", "]"}]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"xxFFTabA", "=", 
        RowBox[{"xxFFTab", "/.", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"n1_", ",", "n2_Integer"}], "}"}], "\[Rule]", "n1"}]}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"xxFFTabB", "=", 
        RowBox[{"xxFFTab", "/.", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"n1_", ",", "n2_Integer"}], "}"}], "\[Rule]", "n2"}]}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"xxdX", "=", 
        RowBox[{"Dimensions", "[", "xxFFTabB", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"xxtraX", "[", "1", "]"}], "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"xxdX", "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", 
          RowBox[{"xxdX", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], "}"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"j", "=", "1"}], ";", "\[IndentingNewLine]", 
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"xxFFTabB", "[", 
           RowBox[{"[", 
            RowBox[{"Sequence", "@@", 
             RowBox[{"xxtraX", "[", "j", "]"}]}], "]"}], "]"}], "=!=", "0"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"xxtraX", "[", 
             RowBox[{"j", "+", "1"}], "]"}], "=", 
            RowBox[{
             RowBox[{"xxtraX", "[", "j", "]"}], "-", 
             RowBox[{"Switch", "[", 
              RowBox[{
               RowBox[{"xxFFTabB", "[", 
                RowBox[{"[", 
                 RowBox[{"Sequence", "@@", 
                  RowBox[{"xxtraX", "[", "j", "]"}]}], "]"}], "]"}], ",", "1",
                ",", 
               RowBox[{"{", 
                RowBox[{"1", ",", "1"}], "}"}], ",", "2", ",", 
               RowBox[{"{", 
                RowBox[{"1", ",", "0"}], "}"}], ",", "3", ",", 
               RowBox[{"{", 
                RowBox[{"0", ",", "1"}], "}"}]}], "]"}]}]}], ",", 
           RowBox[{"j", "=", 
            RowBox[{"j", "+", "1"}]}]}], "}"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"xxpath1", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"xxtraX", "[", "k", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", "1", ",", 
            RowBox[{"j", "-", "1"}]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"xxpath2", "=", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"xxFFTabB", "[", 
            RowBox[{"[", 
             RowBox[{
              RowBox[{"#", "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", 
              RowBox[{"#", "[", 
               RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}], "&"}], ",", 
          "xxpath1"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"xxcount1", "=", "0"}], ";", "\[IndentingNewLine]", 
       RowBox[{"xxcount2", "=", "0"}], ";", "\[IndentingNewLine]", 
       RowBox[{"j", "=", "0"}], ";", "\[IndentingNewLine]", 
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{"j", "<", 
          RowBox[{"Length", "[", "xxpath2", "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"j", "=", 
            RowBox[{"j", "+", "1"}]}], ",", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"xxpath2", "[", 
               RowBox[{"[", "j", "]"}], "]"}], "\[Equal]", "1"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"xxcount1", "=", 
                RowBox[{"xxcount1", "+", "1"}]}], ",", 
               RowBox[{"xxcount2", "=", 
                RowBox[{"xxcount2", "+", "1"}]}], ",", 
               RowBox[{
                RowBox[{"xxalig", "[", "j", "]"}], "=", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"seq1", "[", 
                   RowBox[{"[", 
                    RowBox[{"-", "xxcount1"}], "]"}], "]"}], ",", 
                  RowBox[{"If", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"seq1", "[", 
                    RowBox[{"[", 
                    RowBox[{"-", "xxcount1"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"seq2", "[", 
                    RowBox[{"[", 
                    RowBox[{"-", "xxcount2"}], "]"}], "]"}]}], ",", 
                    "\"\<|\>\"", ",", "\"\< \>\""}], "]"}], ",", 
                  RowBox[{"seq2", "[", 
                   RowBox[{"[", 
                    RowBox[{"-", "xxcount2"}], "]"}], "]"}]}], "}"}]}]}], 
              "}"}], ",", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"xxpath2", "[", 
                 RowBox[{"[", "j", "]"}], "]"}], "\[Equal]", "2"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"xxcount1", "=", 
                  RowBox[{"xxcount1", "+", "1"}]}], ",", 
                 RowBox[{
                  RowBox[{"xxalig", "[", "j", "]"}], "=", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"seq1", "[", 
                    RowBox[{"[", 
                    RowBox[{"-", "xxcount1"}], "]"}], "]"}], ",", "\"\< \>\"",
                     ",", "\"\<-\>\""}], "}"}]}]}], "}"}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"xxpath2", "[", 
                   RowBox[{"[", "j", "]"}], "]"}], "\[Equal]", "3"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"xxcount2", "=", 
                    RowBox[{"xxcount2", "+", "1"}]}], ",", 
                   RowBox[{
                    RowBox[{"xxalig", "[", "j", "]"}], "=", 
                    RowBox[{"{", 
                    RowBox[{"\"\<-\>\"", ",", "\"\< \>\"", ",", 
                    RowBox[{"seq2", "[", 
                    RowBox[{"[", 
                    RowBox[{"-", "xxcount2"}], "]"}], "]"}]}], "}"}]}]}], 
                  "}"}]}], "]"}]}], "]"}]}], "]"}]}], "}"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"xxalFull", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"xxalig", "[", "i", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "j", ",", "1", ",", 
            RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"xxFFTabA", "[", 
        RowBox[{"[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", 
          RowBox[{"-", "1"}]}], "]"}], "]"}]}]}], "]"}]}], ";"}], 
  " "}]}], "Input",
 CellChangeTimes->{{3.623821076035956*^9, 3.623821092318678*^9}, {
  3.6704041842534256`*^9, 3.6704041854444942`*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[TextData[{
 "Man hat dann einen Befehl ",
 StyleBox["alignment",
  FontWeight->"Bold"],
 " zur Verf\[UDoubleDot]gung, der vier Argumente besitzt: die beiden \
Sequenzen, die Substitutionsmatrix und den Wert des Gap-Penalty.\n\n",
 "Wir \[UDoubleDot]berpr\[UDoubleDot]fen zuerst, ob sich mit dieser neuen \
Routine das vorangegangene Alignment reproduzieren l\[ADoubleDot]sst:"
}], "Text",
 CellChangeTimes->{{3.6746355351181817`*^9, 3.674635597408276*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"alignment", "[", 
  RowBox[{"prot1", ",", "prot2", ",", "blosum", ",", "5"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"K\"\>", "\<\"E\"\>", "\<\"F\"\>", "\<\"H\"\>", "\<\"-\"\>", \
"\<\"-\"\>", "\<\"-\"\>", "\<\"N\"\>", "\<\"G\"\>", "\<\"H\"\>", "\<\"-\"\>", \
"\<\"-\"\>", "\<\"T\"\>"},
    {"\<\"|\"\>", "\<\" \"\>", "\<\"|\"\>", "\<\"|\"\>", "\<\" \"\>", "\<\" \
\"\>", "\<\" \"\>", "\<\"|\"\>", "\<\"|\"\>", "\<\"|\"\>", "\<\" \"\>", "\<\" \
\"\>", "\<\"|\"\>"},
    {"\<\"K\"\>", "\<\"Y\"\>", "\<\"F\"\>", "\<\"H\"\>", "\<\"K\"\>", \
"\<\"A\"\>", "\<\"G\"\>", "\<\"N\"\>", "\<\"G\"\>", "\<\"H\"\>", "\<\"S\"\>", \
"\<\"P\"\>", "\<\"T\"\>"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.677571691294722*^9}]
}, Open  ]],

Cell["\<\
Als erste Anwendung dieser neuen Routine wollen wir die \
Abh\[ADoubleDot]ngigkeit dieses Ergebnisses vom Gap-Penalty n\[ADoubleDot]her \
untersuchen.\
\>", "Text",
 CellChangeTimes->{{3.674635608630293*^9, 3.674635632023329*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"alignment", "[", 
  RowBox[{"prot1", ",", "prot2", ",", "blosum", ",", "0"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"K\"\>", "\<\"-\"\>", "\<\"E\"\>", "\<\"F\"\>", "\<\"H\"\>", \
"\<\"-\"\>", "\<\"-\"\>", "\<\"-\"\>", "\<\"N\"\>", "\<\"G\"\>", "\<\"H\"\>", \
"\<\"-\"\>", "\<\"-\"\>", "\<\"T\"\>"},
    {"\<\"|\"\>", "\<\" \"\>", "\<\" \"\>", "\<\"|\"\>", "\<\"|\"\>", "\<\" \
\"\>", "\<\" \"\>", "\<\" \"\>", "\<\"|\"\>", "\<\"|\"\>", "\<\"|\"\>", "\<\" \
\"\>", "\<\" \"\>", "\<\"|\"\>"},
    {"\<\"K\"\>", "\<\"Y\"\>", "\<\"-\"\>", "\<\"F\"\>", "\<\"H\"\>", \
"\<\"K\"\>", "\<\"A\"\>", "\<\"G\"\>", "\<\"N\"\>", "\<\"G\"\>", "\<\"H\"\>", \
"\<\"S\"\>", "\<\"P\"\>", "\<\"T\"\>"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.677571691325922*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"alignment", "[", 
  RowBox[{"prot1", ",", "prot2", ",", "blosum", ",", "1"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"K\"\>", "\<\"E\"\>", "\<\"F\"\>", "\<\"H\"\>", "\<\"-\"\>", \
"\<\"-\"\>", "\<\"-\"\>", "\<\"N\"\>", "\<\"G\"\>", "\<\"H\"\>", "\<\"-\"\>", \
"\<\"-\"\>", "\<\"T\"\>"},
    {"\<\"|\"\>", "\<\" \"\>", "\<\"|\"\>", "\<\"|\"\>", "\<\" \"\>", "\<\" \
\"\>", "\<\" \"\>", "\<\"|\"\>", "\<\"|\"\>", "\<\"|\"\>", "\<\" \"\>", "\<\" \
\"\>", "\<\"|\"\>"},
    {"\<\"K\"\>", "\<\"Y\"\>", "\<\"F\"\>", "\<\"H\"\>", "\<\"K\"\>", \
"\<\"A\"\>", "\<\"G\"\>", "\<\"N\"\>", "\<\"G\"\>", "\<\"H\"\>", "\<\"S\"\>", \
"\<\"P\"\>", "\<\"T\"\>"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.6775716913727217`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"alignment", "[", 
  RowBox[{"prot1", ",", "prot2", ",", "blosum", ",", "15"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"K\"\>", "\<\"E\"\>", "\<\"F\"\>", "\<\"H\"\>", "\<\"-\"\>", \
"\<\"-\"\>", "\<\"-\"\>", "\<\"N\"\>", "\<\"G\"\>", "\<\"H\"\>", "\<\"-\"\>", \
"\<\"-\"\>", "\<\"T\"\>"},
    {"\<\"|\"\>", "\<\" \"\>", "\<\"|\"\>", "\<\"|\"\>", "\<\" \"\>", "\<\" \
\"\>", "\<\" \"\>", "\<\"|\"\>", "\<\"|\"\>", "\<\"|\"\>", "\<\" \"\>", "\<\" \
\"\>", "\<\"|\"\>"},
    {"\<\"K\"\>", "\<\"Y\"\>", "\<\"F\"\>", "\<\"H\"\>", "\<\"K\"\>", \
"\<\"A\"\>", "\<\"G\"\>", "\<\"N\"\>", "\<\"G\"\>", "\<\"H\"\>", "\<\"S\"\>", \
"\<\"P\"\>", "\<\"T\"\>"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.677571691403922*^9}]
}, Open  ]],

Cell[TextData[{
 "Dieses Verhalten in Abh\[ADoubleDot]ngigkeit des Gap-Penalty ist nach \
unserer Diskussion des Needleman-Wunsch-Verfahrens in Kap. 3.1.2 sicherlich \
zu erwarten. Dennoch illustriert es den wichtigen Befund, dass ein scheinbar \
automatisiertes, algorithmisch gefasstes Verfahren der Bioinformatik je nach \
Parameterwahl ein ganzes Spektrum von Ergebnissen produzieren kann. Es gibt \
also kein eindeutiges bestes Alignment zweier Sequenzen gem\[ADoubleDot]\[SZ] \
diesem Algorithmus, sondern das Resultat ist selbst unter demselben Verfahren \
stets eine Funktion der gew\[ADoubleDot]hlten Parameter. Die Strategie, eine \
solche Parameterabh\[ADoubleDot]ngigkeit in einer bioinformatischen Analyse \
zu kontrollieren, liegt bei Betrachtung dieser Ergebnisse jedoch auf der \
Hand: Offensichtlich \[ADoubleDot]ndert sich in diesem Fall das Alignment \
\[UDoubleDot]ber einen recht gro\[SZ]en Bereich des Gap-Penalty nicht. Wir \
haben also f\[UDoubleDot]r diese beiden Sequenzen ein gegen\[UDoubleDot]ber \
einer Parametervariation relativ robustes Ergebnis vorliegen. \n\nDie \
vorangegangene Implementierung hat uns einen Einblick in das Funktionieren \
und die algorithmischen Feinheiten des Needleman-Wunsch-Algorithmus gegeben. \
Dieser Algorithmus, ebenso wie weitere wichtige Alignmentwerkzeuge, sind auch \
in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " direkt verf\[UDoubleDot]gbar. Das Ergebnis unserer Alignmentroutine l\
\[ADoubleDot]sst sich mit den Befehlen ",
 StyleBox["NeedlemanWunschSimilarity",
  FontWeight->"Bold"],
 " und ",
 StyleBox["SequenceAlignment",
  FontWeight->"Bold"],
 " reproduzieren."
}], "Text",
 CellChangeTimes->{{3.6746356556173654`*^9, 3.6746356607613726`*^9}, {
   3.674635741030499*^9, 3.674635780133561*^9}, 3.6774946816849933`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NeedlemanWunschSimilarity", "[", 
  RowBox[{
   RowBox[{"StringJoin", "[", "prot1", "]"}], ",", 
   RowBox[{"StringJoin", "[", "prot2", "]"}], ",", 
   RowBox[{"SimilarityRules", "->", "\"\<BLOSUM62\>\""}], ",", 
   RowBox[{"GapPenalty", "\[Rule]", "5"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.61638305036666*^9, 3.616383052347568*^9}, {
   3.616383086947509*^9, 3.6163830929386272`*^9}, {3.616383140884535*^9, 
   3.6163831443560057`*^9}, 3.6163834134165277`*^9, {3.616383459461278*^9, 
   3.616383524295854*^9}, {3.61638357079156*^9, 3.616383578563875*^9}, {
   3.616383623574201*^9, 3.6163836475315332`*^9}, {3.616553411221416*^9, 
   3.616553419387673*^9}}],

Cell[BoxData["12.`"], "Output",
 CellChangeTimes->{3.677571691450722*^9}]
}, Open  ]],

Cell[TextData[{
 "Die Unterschiede im Score erkl\[ADoubleDot]ren sich aus einem etwas anderen \
Bewertungsschema von Gaps. ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " bewertet statt einzelner Gaps ganze Gap-Regionen. Bei einem genauen \
Vergleich zeigen sich zudem daraus resultierende Unterschiede in den so \
ermittelten optimalen Alignments. Selbst ein relativ einfaches Werkzeug wie \
das globale Sequenzalignment weist bei genauem Hinsehen eine recht hohe \
Diversit\[ADoubleDot]t auf, die durch kleine Unterschiede in der \
Implementierung entsteht.\n\nDas Alignment selbst erhalten wir nun \
\[UDoubleDot]ber den Befehl ",
 StyleBox["SequenceAlignment",
  FontWeight->"Bold"],
 "."
}], "Text",
 CellChangeTimes->{{3.6746358429946556`*^9, 3.674635870574699*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"s1", " ", "=", " ", 
  RowBox[{"SequenceAlignment", "[", 
   RowBox[{
    RowBox[{"StringJoin", "[", "prot1", "]"}], ",", 
    RowBox[{"StringJoin", "[", "prot2", "]"}], ",", 
    RowBox[{"SimilarityRules", "\[Rule]", "\"\<BLOSUM62\>\""}], ",", 
    RowBox[{"GapPenalty", "\[Rule]", "5"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.61638305036666*^9, 3.616383052347568*^9}, {
   3.616383086947509*^9, 3.6163830929386272`*^9}, {3.616383140884535*^9, 
   3.6163831443560057`*^9}, 3.6163834134165277`*^9, {3.616383459461278*^9, 
   3.616383524295854*^9}, {3.616383990794642*^9, 3.616383995738268*^9}, {
   3.6163884125327253`*^9, 3.6163884145152063`*^9}, {3.616553447666547*^9, 
   3.616553447870151*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"K\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"\<\"E\"\>", ",", "\<\"Y\"\>"}], "}"}], ",", "\<\"FH\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"\<\"\"\>", ",", "\<\"KAG\"\>"}], "}"}], ",", "\<\"NGH\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"\<\"\"\>", ",", "\<\"SP\"\>"}], "}"}], ",", "\<\"T\"\>"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.6775716915131226`*^9}]
}, Open  ]],

Cell["\<\
Allerdings ist der Output nicht in einer f\[UDoubleDot]r bioinformatische \
Gewohnheiten \[UDoubleDot]blichen Form angegeben.

Mit der folgenden \[CapitalUDoubleDot]bersetzungsroutine \[UDoubleDot]berf\
\[UDoubleDot]hren wir den Output in die vorangegangene Struktur. Dabei gehen \
wir der Reihe nach durch die vier m\[ODoubleDot]glichen Segmente: (1) \
einzelne Strings (was im Alignment gleiche Buchstaben in beiden Sequenzen \
bedeutet), (2) Paare mit einen leeren ersten Eintrag (Gaps im ersten String), \
(3) Paare mit einem leeren zweiten Eintrag (Gaps im zweiten String), (4) \
nichtleere Paare (ungleiche Symbole werden gepaart).\
\>", "Text",
 CellChangeTimes->{{3.6746358907297287`*^9, 3.6746358995367413`*^9}, {
  3.6746359348897943`*^9, 3.674635948780815*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"makeAlignment", "[", "out_", "]"}], ":=", " ", 
  RowBox[{"Transpose", "[", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"xx", " ", "=", " ", 
         RowBox[{"out", "[", 
          RowBox[{"[", "k", "]"}], "]"}]}], ";", 
        RowBox[{"Transpose", "[", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "[", "xx", "]"}], "\[Equal]", "0"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Characters", "[", "xx", "]"}], ",", 
             RowBox[{"Table", "[", 
              RowBox[{"\"\<|\>\"", ",", 
               RowBox[{"{", 
                RowBox[{"StringLength", "[", "xx", "]"}], "}"}]}], "]"}], ",", 
             RowBox[{"Characters", "[", "xx", "]"}]}], "}"}], ",", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Length", "[", "xx", "]"}], "\[Equal]", "2"}], ",", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"xx", "[", 
                 RowBox[{"[", "1", "]"}], "]"}], "==", "\"\<\>\""}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Table", "[", 
                  RowBox[{"\"\<-\>\"", ",", 
                   RowBox[{"{", 
                    RowBox[{"StringLength", "[", 
                    RowBox[{"xx", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "]"}], "}"}]}], "]"}], 
                 ",", 
                 RowBox[{"Table", "[", 
                  RowBox[{"\"\< \>\"", ",", 
                   RowBox[{"{", 
                    RowBox[{"StringLength", "[", 
                    RowBox[{"xx", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "]"}], "}"}]}], "]"}], 
                 ",", 
                 RowBox[{"Characters", "[", 
                  RowBox[{"xx", "[", 
                   RowBox[{"[", "2", "]"}], "]"}], "]"}]}], "}"}], ",", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"xx", "[", 
                   RowBox[{"[", "2", "]"}], "]"}], "==", "\"\<\>\""}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"Characters", "[", 
                    RowBox[{"xx", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "]"}], ",", 
                   RowBox[{"Table", "[", 
                    RowBox[{"\"\< \>\"", ",", 
                    RowBox[{"{", 
                    RowBox[{"StringLength", "[", 
                    RowBox[{"xx", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "]"}], "}"}]}], "]"}], 
                   ",", 
                   RowBox[{"Table", "[", 
                    RowBox[{"\"\<-\>\"", ",", 
                    RowBox[{"{", 
                    RowBox[{"StringLength", "[", 
                    RowBox[{"xx", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "]"}], "}"}]}], "]"}]}], 
                  "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"Characters", "[", 
                    RowBox[{"xx", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "]"}], ",", 
                   RowBox[{"Table", "[", 
                    RowBox[{"\"\< \>\"", ",", 
                    RowBox[{"{", 
                    RowBox[{"StringLength", "[", 
                    RowBox[{"xx", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "]"}], "}"}]}], "]"}], 
                   ",", 
                   RowBox[{"Characters", "[", 
                    RowBox[{"xx", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "]"}]}], "}"}]}], "]"}]}],
               "]"}]}], "]"}]}], "]"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", 
         RowBox[{"Length", "[", "out", "]"}]}], "}"}]}], "]"}], ",", "1"}], 
    "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6163890209673567`*^9, 3.616389406518412*^9}, 
   3.6164714021794558`*^9, {3.616471443907179*^9, 3.61647144540627*^9}, {
   3.616471475725041*^9, 3.616471479914627*^9}, {3.616471550345716*^9, 
   3.616471597399706*^9}, {3.616472087943713*^9, 3.61647209462253*^9}, {
   3.6164721584270687`*^9, 3.6164721703542557`*^9}}],

Cell[TextData[{
 "Anwendung dieser \[CapitalUDoubleDot]bersetzungsroutine auf den Output des ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-internen Alignmentbefehls f\[UDoubleDot]hrt dann auf das gleiche Resultat \
wie unser eigener, oben entwickelter Alignmentbefehl."
}], "Text",
 CellChangeTimes->{{3.674635962949836*^9, 3.6746359989608917`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"makeAlignment", "[", "s1", "]"}], " ", "//", " ", 
  "TableForm"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"K\"\>", "\<\"E\"\>", "\<\"F\"\>", "\<\"H\"\>", "\<\"-\"\>", \
"\<\"-\"\>", "\<\"-\"\>", "\<\"N\"\>", "\<\"G\"\>", "\<\"H\"\>", "\<\"-\"\>", \
"\<\"-\"\>", "\<\"T\"\>"},
    {"\<\"|\"\>", "\<\" \"\>", "\<\"|\"\>", "\<\"|\"\>", "\<\" \"\>", "\<\" \
\"\>", "\<\" \"\>", "\<\"|\"\>", "\<\"|\"\>", "\<\"|\"\>", "\<\" \"\>", "\<\" \
\"\>", "\<\"|\"\>"},
    {"\<\"K\"\>", "\<\"Y\"\>", "\<\"F\"\>", "\<\"H\"\>", "\<\"K\"\>", \
"\<\"A\"\>", "\<\"G\"\>", "\<\"N\"\>", "\<\"G\"\>", "\<\"H\"\>", "\<\"S\"\>", \
"\<\"P\"\>", "\<\"T\"\>"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.6775716915443225`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"alignment", "[", 
  RowBox[{"prot1", ",", "prot2", ",", "blosum", ",", "5"}], "]"}]], "Input",
 CellChangeTimes->{{3.616553352856701*^9, 3.61655336605623*^9}, {
  3.616553472217718*^9, 3.616553472888167*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"K\"\>", "\<\"E\"\>", "\<\"F\"\>", "\<\"H\"\>", "\<\"-\"\>", \
"\<\"-\"\>", "\<\"-\"\>", "\<\"N\"\>", "\<\"G\"\>", "\<\"H\"\>", "\<\"-\"\>", \
"\<\"-\"\>", "\<\"T\"\>"},
    {"\<\"|\"\>", "\<\" \"\>", "\<\"|\"\>", "\<\"|\"\>", "\<\" \"\>", "\<\" \
\"\>", "\<\" \"\>", "\<\"|\"\>", "\<\"|\"\>", "\<\"|\"\>", "\<\" \"\>", "\<\" \
\"\>", "\<\"|\"\>"},
    {"\<\"K\"\>", "\<\"Y\"\>", "\<\"F\"\>", "\<\"H\"\>", "\<\"K\"\>", \
"\<\"A\"\>", "\<\"G\"\>", "\<\"N\"\>", "\<\"G\"\>", "\<\"H\"\>", "\<\"S\"\>", \
"\<\"P\"\>", "\<\"T\"\>"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.6775716915911226`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-Exkurs: ",
 "Alignment von Zufallssequenzen"
}], "Subtitle",
 CellChangeTimes->{3.670321495640956*^9, 3.670402706588908*^9, 
  3.670404040206187*^9},
 Background->RGBColor[
  0.8705882352941177, 0.00392156862745098, 0.2196078431372549]],

Cell["\<\
Auf der Grundlage unserer Implementierung des Needleman-Wunsch-Algorithmus \
lassen sich nun weitere numerische Experimente durchf\[UDoubleDot]hren. Wir \
werden hier die Score-Verteilung beim Alignment kurzer Zufallssequenzen \
analysieren. Dazu beschr\[ADoubleDot]nken wir uns auf ein Alphabet aus \
wenigen Aminos\[ADoubleDot]uren:\
\>", "Text",
 CellChangeTimes->{{3.6746360154869165`*^9, 3.674636046856962*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"alX", "=", 
  RowBox[{"Characters", "[", "\"\<CHPWY\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.577686863883887*^9, 3.577686922649285*^9}, {
  3.577760110558146*^9, 3.577760111835709*^9}, {3.577760164465807*^9, 
  3.5777601650569696`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"C\"\>", ",", "\<\"H\"\>", ",", "\<\"P\"\>", ",", "\<\"W\"\>", 
   ",", "\<\"Y\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.6775716916067224`*^9}]
}, Open  ]],

Cell["\<\
In \[UDoubleDot]blicher Weise k\[ODoubleDot]nnen wir nun die Untermatrix aus \
BLOSUM62 f\[UDoubleDot]r dieses Alphabet extrahieren:\
\>", "Text",
 CellChangeTimes->{{3.6746360624359856`*^9, 3.674636092791031*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"coordTab2", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"xxcoordFun", "[", 
      RowBox[{
      "proteinRef", ",", "alX", ",", "alX", ",", "ii", ",", "jj", ",", 
       "blosum"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"ii", ",", "1", ",", 
       RowBox[{"Length", "[", "alX", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"jj", ",", "1", ",", 
       RowBox[{"Length", "[", "alX", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.577760196299798*^9, 3.577760208912928*^9}, {
  3.616553061960496*^9, 3.616553062172349*^9}, {3.61655309302114*^9, 
  3.616553105771036*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{"coordTab2", ",", " ", 
   RowBox[{"TableHeadings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"alX", ",", "alX"}], "}"}]}], ",", 
   RowBox[{"TableSpacing", "\[Rule]", "1"}], ",", " ", 
   RowBox[{"TableAlignments", "\[Rule]", " ", "Right"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.559401255674562*^9, 3.5594012625889063`*^9}, {
  3.577760197801735*^9, 3.57776022231244*^9}}],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      StyleBox["\[Null]",
       ShowStringCharacters->False], 
      TagBox["\<\"C\"\>",
       HoldForm], 
      TagBox["\<\"H\"\>",
       HoldForm], 
      TagBox["\<\"P\"\>",
       HoldForm], 
      TagBox["\<\"W\"\>",
       HoldForm], 
      TagBox["\<\"Y\"\>",
       HoldForm]},
     {
      TagBox["\<\"C\"\>",
       HoldForm], "9", 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "2"}]},
     {
      TagBox["\<\"H\"\>",
       HoldForm], 
      RowBox[{"-", "3"}], "8", 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "2"}], "2"},
     {
      TagBox["\<\"P\"\>",
       HoldForm], 
      RowBox[{"-", "3"}], 
      RowBox[{"-", "2"}], "7", 
      RowBox[{"-", "4"}], 
      RowBox[{"-", "3"}]},
     {
      TagBox["\<\"W\"\>",
       HoldForm], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "4"}], "11", "2"},
     {
      TagBox["\<\"Y\"\>",
       HoldForm], 
      RowBox[{"-", "2"}], "2", 
      RowBox[{"-", "3"}], "2", "7"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Right}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {{"C", "H", "P", "W", "Y"}, {"C", "H", "P", "W", "Y"}}, 
    TableSpacing -> 1, TableAlignments -> Right]]]], "Output",
 CellChangeTimes->{3.6775716916379223`*^9}]
}, Open  ]],

Cell[TextData[{
 "Unser bisheriges Befehlsinventar erlaubt uns nun, sehr elegant das \
Alignment von zwei Zufallssequenzen auf dem Alphabet ",
 StyleBox["alX",
  FontWeight->"Bold"],
 " zu erzeugen:"
}], "Text",
 CellChangeTimes->{{3.6746361210100746`*^9, 3.6746361357810993`*^9}, 
   3.6774949625512877`*^9}],

Cell[BoxData[
 RowBox[{"SeedRandom", "[", "50", "]"}]], "Input",
 FontColor->GrayLevel[0.5]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"prot1", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"RandomChoice", "[", "alX", "]"}], ",", 
    RowBox[{"{", "12", "}"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"prot2", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"RandomChoice", "[", "alX", "]"}], ",", 
    RowBox[{"{", "12", "}"}]}], "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"W\"\>", ",", "\<\"W\"\>", ",", "\<\"H\"\>", ",", "\<\"Y\"\>", 
   ",", "\<\"W\"\>", ",", "\<\"W\"\>", ",", "\<\"H\"\>", ",", "\<\"C\"\>", 
   ",", "\<\"Y\"\>", ",", "\<\"P\"\>", ",", "\<\"C\"\>", ",", "\<\"C\"\>"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.6775716917315226`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"P\"\>", ",", "\<\"Y\"\>", ",", "\<\"P\"\>", ",", "\<\"H\"\>", 
   ",", "\<\"P\"\>", ",", "\<\"W\"\>", ",", "\<\"Y\"\>", ",", "\<\"P\"\>", 
   ",", "\<\"C\"\>", ",", "\<\"C\"\>", ",", "\<\"W\"\>", ",", "\<\"P\"\>"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.6775716917315226`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"alignment", "[", 
  RowBox[{"prot1", ",", "prot2", ",", "blosum", ",", "5"}], "]"}]], "Input",
 CellChangeTimes->{{3.577759890443873*^9, 3.5777598905425453`*^9}, {
  3.577761237033432*^9, 3.5777612372251368`*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"W\"\>", "\<\"W\"\>", "\<\"H\"\>", "\<\"Y\"\>", "\<\"W\"\>", \
"\<\"W\"\>", "\<\"H\"\>", "\<\"C\"\>", "\<\"Y\"\>", "\<\"P\"\>", "\<\"C\"\>", \
"\<\"C\"\>", "\<\"-\"\>", "\<\"-\"\>"},
    {"\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", \
"\<\"|\"\>", "\<\" \"\>", "\<\" \"\>", "\<\"|\"\>", "\<\"|\"\>", "\<\"|\"\>", \
"\<\"|\"\>", "\<\" \"\>", "\<\" \"\>"},
    {"\<\"P\"\>", "\<\"Y\"\>", "\<\"P\"\>", "\<\"H\"\>", "\<\"P\"\>", \
"\<\"W\"\>", "\<\"-\"\>", "\<\"-\"\>", "\<\"Y\"\>", "\<\"P\"\>", "\<\"C\"\>", \
"\<\"C\"\>", "\<\"W\"\>", "\<\"P\"\>"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.6775716917783227`*^9}]
}, Open  ]],

Cell["Den Alignment-Score", "Text",
 CellChangeTimes->{{3.674636154857127*^9, 3.674636173557155*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"alignmentScore", "[", 
  RowBox[{"prot1", ",", "prot2", ",", "blosum", ",", "5"}], "]"}]], "Input",
 CellChangeTimes->{{3.577687501911631*^9, 3.577687508052335*^9}, {
  3.5777599790464277`*^9, 3.577759979157536*^9}, {3.57776124271839*^9, 
  3.577761242918439*^9}}],

Cell[BoxData["17"], "Output",
 CellChangeTimes->{3.677571691825123*^9}]
}, Open  ]],

Cell["\<\
k\[ODoubleDot]nnen wir nun \[Dash] wie zuvor \[Dash] als Funktion des \
Gap-Penalty betrachten:\
\>", "Text",
 CellChangeTimes->{{3.67463618315617*^9, 3.6746361993521943`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tab1", " ", "=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{"alignmentScore", "[", 
       RowBox[{"prot1", ",", "prot2", ",", "blosum", ",", "i"}], "]"}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "0", ",", "10"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.577687518833723*^9, 3.577687537302709*^9}, {
  3.577759856861611*^9, 3.5777598611452436`*^9}, {3.577761276263777*^9, 
  3.577761277405504*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "53"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "43"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "34"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "28"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "22"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "17"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", "13"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7", ",", "9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"9", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10", ",", 
     RowBox[{"-", "3"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6775716920435233`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"tab1", ",", " ", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"\"\<Gap-Penalty\>\"", ",", "\"\<Score\>\""}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.577761269587592*^9, 3.577761293628314*^9}, {
  3.616383263297758*^9, 3.616383291118641*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.012833333333333334`],
      AbsoluteThickness[1.6], 
     LineBox[{{0., 53.}, {1., 43.}, {2., 34.}, {3., 28.}, {4., 22.}, {5., 
      17.}, {6., 13.}, {7., 9.}, {8., 5.}, {9., 1.}, {10., -3.}}]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox["\"Score\"", TraditionalForm], None}, {
     FormBox["\"Gap-Penalty\"", TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 10.}, {-3., 53.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6775716923711243`*^9}]
}, Open  ]],

Cell["\<\
Erwartungsgem\[ADoubleDot]\[SZ] f\[ADoubleDot]llt der Score mit wachsendem \
Gap-Penalty ab. Qualitativ erwarten wir f\[UDoubleDot]r den (auf die Sequenzl\
\[ADoubleDot]nge normierten) Alignment-Score einen linearen Abfall mit dem \
Gap-Penalty. Abweichungen von dieser Erwartung werden durch die konkrete \
Sequenzzusammensetzung erzeugt (Wie effizient lassen sich Gaps zur Erh\
\[ODoubleDot]hung des Scores einsetzen?). Das folgende numerische Experiment \
mit einer gr\[ODoubleDot]\[SZ]eren Zahl von Sequenzen best\[ADoubleDot]tigt \
diese Erwartung:\
\>", "Text",
 CellChangeTimes->{{3.6746362127532144`*^9, 3.6746362179172215`*^9}, {
  3.6746362503962693`*^9, 3.6746362573652797`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"seqNum", " ", "=", " ", "100"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seqLength", " ", "=", " ", "14"}], ";"}]}], "Input",
 CellChangeTimes->{{3.5777614817776527`*^9, 3.5777614872836943`*^9}, {
   3.577761599707365*^9, 3.5777616054081907`*^9}, {3.577761662475919*^9, 
   3.577761662556801*^9}, 3.577761767231305*^9, {3.5777618870440903`*^9, 
   3.577761887122686*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"sequenceTab1", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"RandomChoice", "[", "alX", "]"}], ",", 
       RowBox[{"{", "seqLength", "}"}]}], "]"}], ",", 
     RowBox[{"{", "seqNum", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sequenceTab2", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"RandomChoice", "[", "alX", "]"}], ",", 
       RowBox[{"{", "seqLength", "}"}]}], "]"}], ",", 
     RowBox[{"{", "seqNum", "}"}]}], "]"}]}], ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tabFull0", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"N", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"alignmentScore", "[", 
             RowBox[{
              RowBox[{"sequenceTab1", "[", 
               RowBox[{"[", "j", "]"}], "]"}], ",", 
              RowBox[{"sequenceTab2", "[", 
               RowBox[{"[", "j", "]"}], "]"}], ",", "blosum", ",", "i"}], 
             "]"}], ")"}], "/", "seqLength"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "10"}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", "seqNum"}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.577761446708804*^9, 3.577761522035701*^9}, 
   3.577761556011571*^9, {3.5777616212590313`*^9, 3.577761658823065*^9}, {
   3.577761695055909*^9, 3.5777616962915792`*^9}, {3.577761733282014*^9, 
   3.577761753527424*^9}, {3.577761800048826*^9, 3.577761800248291*^9}, {
   3.577762148394362*^9, 3.577762180522876*^9}, {3.577762254751195*^9, 
   3.577762257426557*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"tabFull0", ",", " ", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"\"\<Gap-Penalty\>\"", ",", "\"\<Score\>\""}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.577761269587592*^9, 3.577761293628314*^9}, 
   3.57776156124183*^9, {3.577762262735485*^9, 3.577762264894005*^9}, {
   3.616383310086893*^9, 3.6163833103299637`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.714285714285714}, {1., 4.}, {2., 3.5714285714285716`}, {
      3., 3.142857142857143}, {4., 2.7142857142857144`}, {5., 
      2.2857142857142856`}, {6., 1.8571428571428572`}, {7., 
      1.4285714285714286`}, {8., 1.}, {9., 0.7857142857142857}, {10., 
      0.7857142857142857}}]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 3.9285714285714284`}, {1., 3.2142857142857144`}, {2., 
      3.0714285714285716`}, {3., 2.9285714285714284`}, {4., 
      2.7857142857142856`}, {5., 2.642857142857143}, {6., 2.5}, {7., 
      2.357142857142857}, {8., 2.2142857142857144`}, {9., 
      2.0714285714285716`}, {10., 1.9285714285714286`}}]}, 
    {RGBColor[0.560181, 0.691569, 0.194885], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.5}, {1., 3.7857142857142856`}, {2., 
      3.2142857142857144`}, {3., 2.642857142857143}, {4., 
      2.357142857142857}, {5., 2.0714285714285716`}, {6., 
      1.7857142857142858`}, {7., 1.5}, {8., 1.2857142857142858`}, {9., 
      1.1428571428571428`}, {10., 1.}}]}, 
    {RGBColor[0.922526, 0.385626, 0.209179], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.857142857142857}, {1., 4.142857142857143}, {2., 
      3.4285714285714284`}, {3., 2.7142857142857144`}, {4., 
      2.142857142857143}, {5., 1.6428571428571428`}, {6., 
      1.3571428571428572`}, {7., 1.2142857142857142`}, {8., 
      1.0714285714285714`}, {9., 0.9285714285714286}, {10., 
      0.7857142857142857}}]}, 
    {RGBColor[0.528488, 0.470624, 0.701351], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 5.}, {1., 4.285714285714286}, {2., 3.5714285714285716`}, {
      3., 2.857142857142857}, {4., 2.142857142857143}, {5., 
      1.4285714285714286`}, {6., 0.7857142857142857}, {7., 
      0.2857142857142857}, {8., 0.}, {9., -0.2857142857142857}, {
      10., -0.5}}]}, 
    {RGBColor[0.772079, 0.431554, 0.102387], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 5.214285714285714}, {1., 4.357142857142857}, {2., 
      3.642857142857143}, {3., 2.9285714285714284`}, {4., 
      2.2142857142857144`}, {5., 1.7857142857142858`}, {6., 
      1.3571428571428572`}, {7., 1.0714285714285714`}, {8., 
      0.7857142857142857}, {9., 0.5714285714285714}, {10., 
      0.42857142857142855`}}]}, 
    {RGBColor[0.363898, 0.618501, 0.782349], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.642857142857143}, {1., 4.071428571428571}, {2., 
      3.642857142857143}, {3., 3.2142857142857144`}, {4., 
      2.7857142857142856`}, {5., 2.357142857142857}, {6., 2.}, {7., 
      1.7142857142857142`}, {8., 1.4285714285714286`}, {9., 
      1.2142857142857142`}, {10., 1.2142857142857142`}}]}, 
    {RGBColor[1, 0.75, 0], PointSize[0.004583333333333334], AbsoluteThickness[
     1.6], LineBox[{{0., 4.5}, {1., 3.7857142857142856`}, {2., 
      3.357142857142857}, {3., 3.0714285714285716`}, {4., 
      2.7857142857142856`}, {5., 2.5}, {6., 2.2142857142857144`}, {7., 
      1.9285714285714286`}, {8., 1.7142857142857142`}, {9., 
      1.5714285714285714`}, {10., 1.5}}]}, 
    {RGBColor[0.647624, 0.37816, 0.614037], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.571428571428571}, {1., 3.9285714285714284`}, {2., 
      3.357142857142857}, {3., 2.9285714285714284`}, {4., 
      2.642857142857143}, {5., 2.357142857142857}, {6., 
      2.0714285714285716`}, {7., 1.9285714285714286`}, {8., 
      1.7857142857142858`}, {9., 1.6428571428571428`}, {10., 1.5}}]}, 
    {RGBColor[0.571589, 0.586483, 0.], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 3.7142857142857144`}, {1., 2.7142857142857144`}, {2., 
      2.0714285714285716`}, {3., 1.6428571428571428`}, {4., 
      1.2142857142857142`}, {5., 0.7857142857142857}, {6., 
      0.35714285714285715`}, {7., -0.07142857142857142}, {8., -0.5}, {
      9., -0.8571428571428571}, {10., -1.1428571428571428`}}]}, 
    {RGBColor[0.915, 0.3325, 0.2125], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.071428571428571}, {1., 3.0714285714285716`}, {2., 
      2.4285714285714284`}, {3., 1.8571428571428572`}, {4., 
      1.4285714285714286`}, {5., 1.}, {6., 0.5714285714285714}, {7., 
      0.14285714285714285`}, {8., 0.14285714285714285`}, {9., 
      0.14285714285714285`}, {10., 0.14285714285714285`}}]}, 
    {RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], PointSize[
     0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 4.785714285714286}, {1., 4.071428571428571}, {2., 
      3.5714285714285716`}, {3., 3.142857142857143}, {4., 
      2.7857142857142856`}, {5., 2.5}, {6., 2.2142857142857144`}, {7., 2.}, {
      8., 1.8571428571428572`}, {9., 1.7857142857142858`}, {10., 
      1.7857142857142858`}}]}, 
    {RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
     PointSize[0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 5.142857142857143}, {1., 4.285714285714286}, {2., 
      3.5714285714285716`}, {3., 3.}, {4., 2.5714285714285716`}, {5., 
      2.5714285714285716`}, {6., 2.5714285714285716`}, {7., 
      2.5714285714285716`}, {8., 2.5714285714285716`}, {9., 
      2.5714285714285716`}, {10., 2.5714285714285716`}}]}, 
    {RGBColor[0.736782672705901, 0.358, 0.5030266573755369], PointSize[
     0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 4.785714285714286}, {1., 4.142857142857143}, {2., 
      3.7142857142857144`}, {3., 3.2857142857142856`}, {4., 
      2.857142857142857}, {5., 2.4285714285714284`}, {6., 2.}, {7., 
      1.8571428571428572`}, {8., 1.7142857142857142`}, {9., 
      1.5714285714285714`}, {10., 1.4285714285714286`}}]}, 
    {RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], PointSize[
     0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 4.571428571428571}, {1., 3.857142857142857}, {2., 
      3.2857142857142856`}, {3., 2.7142857142857144`}, {4., 
      2.2857142857142856`}, {5., 2.}, {6., 1.7142857142857142`}, {7., 
      1.4285714285714286`}, {8., 1.1428571428571428`}, {9., 
      0.8571428571428571}, {10., 0.8571428571428571}}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.357142857142857}, {1., 3.5}, {2., 2.7857142857142856`}, {
      3., 2.4285714285714284`}, {4., 2.142857142857143}, {5., 
      1.8571428571428572`}, {6., 1.5714285714285714`}, {7., 
      1.4285714285714286`}, {8., 1.2857142857142858`}, {9., 
      1.2142857142857142`}, {10., 1.2142857142857142`}}]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 3.9285714285714284`}, {1., 3.}, {2., 2.357142857142857}, {
      3., 1.9285714285714286`}, {4., 1.5714285714285714`}, {5., 
      1.2857142857142858`}, {6., 1.}, {7., 0.7142857142857143}, {8., 
      0.42857142857142855`}, {9., 0.14285714285714285`}, {
      10., -0.14285714285714285`}}]}, 
    {RGBColor[0.560181, 0.691569, 0.194885], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.285714285714286}, {1., 3.7142857142857144`}, {2., 
      3.5714285714285716`}, {3., 3.4285714285714284`}, {4., 
      3.2857142857142856`}, {5., 3.2857142857142856`}, {6., 
      3.2857142857142856`}, {7., 3.2857142857142856`}, {8., 
      3.2857142857142856`}, {9., 3.2857142857142856`}, {10., 
      3.2857142857142856`}}]}, 
    {RGBColor[0.922526, 0.385626, 0.209179], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 5.142857142857143}, {1., 4.428571428571429}, {2., 
      3.857142857142857}, {3., 3.2857142857142856`}, {4., 
      2.7857142857142856`}, {5., 2.357142857142857}, {6., 
      1.9285714285714286`}, {7., 1.5}, {8., 1.2142857142857142`}, {9., 
      1.1428571428571428`}, {10., 1.1428571428571428`}}]}, 
    {RGBColor[0.528488, 0.470624, 0.701351], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 5.357142857142857}, {1., 4.642857142857143}, {2., 
      4.142857142857143}, {3., 3.7142857142857144`}, {4., 
      3.357142857142857}, {5., 3.2142857142857144`}, {6., 
      3.0714285714285716`}, {7., 2.9285714285714284`}, {8., 
      2.7857142857142856`}, {9., 2.642857142857143}, {10., 2.5}}]}, 
    {RGBColor[0.772079, 0.431554, 0.102387], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.714285714285714}, {1., 3.857142857142857}, {2., 
      3.0714285714285716`}, {3., 2.5714285714285716`}, {4., 
      2.4285714285714284`}, {5., 2.2857142857142856`}, {6., 
      2.142857142857143}, {7., 2.}, {8., 1.8571428571428572`}, {9., 
      1.7142857142857142`}, {10., 1.5714285714285714`}}]}, 
    {RGBColor[0.363898, 0.618501, 0.782349], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 3.5}, {1., 2.642857142857143}, {2., 1.9285714285714286`}, {
      3., 1.5}, {4., 1.2142857142857142`}, {5., 0.9285714285714286}, {6., 
      0.6428571428571429}, {7., 0.35714285714285715`}, {8., 
      0.07142857142857142}, {9., 0.}, {10., 0.}}]}, 
    {RGBColor[1, 0.75, 0], PointSize[0.004583333333333334], AbsoluteThickness[
     1.6], LineBox[{{0., 3.4285714285714284`}, {1., 2.4285714285714284`}, {2.,
       1.9285714285714286`}, {3., 1.5}, {4., 1.0714285714285714`}, {5., 
      0.6428571428571429}, {6., 0.21428571428571427`}, {
      7., -0.07142857142857142}, {8., -0.35714285714285715`}, {
      9., -0.5714285714285714}, {10., -0.5714285714285714}}]}, 
    {RGBColor[0.647624, 0.37816, 0.614037], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.714285714285714}, {1., 4.}, {2., 3.5}, {3., 
      3.0714285714285716`}, {4., 2.642857142857143}, {5., 
      2.2142857142857144`}, {6., 1.7857142857142858`}, {7., 
      1.3571428571428572`}, {8., 0.9285714285714286}, {9., 
      0.7857142857142857}, {10., 0.6428571428571429}}]}, 
    {RGBColor[0.571589, 0.586483, 0.], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 5.857142857142857}, {1., 5.}, {2., 4.142857142857143}, {3.,
       3.2857142857142856`}, {4., 2.4285714285714284`}, {5., 2.}, {6., 
      1.5714285714285714`}, {7., 1.2142857142857142`}, {8., 1.}, {9., 
      0.8571428571428571}, {10., 0.7142857142857143}}]}, 
    {RGBColor[0.915, 0.3325, 0.2125], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 3.142857142857143}, {1., 2.2857142857142856`}, {2., 
      1.8571428571428572`}, {3., 1.5714285714285714`}, {4., 
      1.2857142857142858`}, {5., 1.}, {6., 0.7142857142857143}, {7., 
      0.42857142857142855`}, {8., 0.14285714285714285`}, {
      9., -0.14285714285714285`}, {10., -0.42857142857142855`}}]}, 
    {RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], PointSize[
     0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 4.357142857142857}, {1., 3.5}, {2., 2.857142857142857}, {
      3., 2.4285714285714284`}, {4., 2.}, {5., 1.5714285714285714`}, {6., 
      1.1428571428571428`}, {7., 0.7142857142857143}, {8., 
      0.2857142857142857}, {9., 0.14285714285714285`}, {10., 
      0.14285714285714285`}}]}, 
    {RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
     PointSize[0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 4.142857142857143}, {1., 3.2857142857142856`}, {2., 
      2.7142857142857144`}, {3., 2.2857142857142856`}, {4., 2.}, {5., 
      1.7142857142857142`}, {6., 1.4285714285714286`}, {7., 
      1.1428571428571428`}, {8., 1.}, {9., 0.8571428571428571}, {10., 
      0.8571428571428571}}]}, 
    {RGBColor[0.736782672705901, 0.358, 0.5030266573755369], PointSize[
     0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 4.142857142857143}, {1., 3.142857142857143}, {2., 2.5}, {
      3., 2.0714285714285716`}, {4., 1.6428571428571428`}, {5., 
      1.3571428571428572`}, {6., 1.0714285714285714`}, {7., 
      0.7857142857142857}, {8., 0.5}, {9., 0.21428571428571427`}, {10., 
      0.07142857142857142}}]}, 
    {RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], PointSize[
     0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 5.071428571428571}, {1., 4.357142857142857}, {2., 4.}, {3.,
       3.7142857142857144`}, {4., 3.4285714285714284`}, {5., 
      3.142857142857143}, {6., 2.857142857142857}, {7., 2.642857142857143}, {
      8., 2.5}, {9., 2.357142857142857}, {10., 2.2142857142857144`}}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.428571428571429}, {1., 3.4285714285714284`}, {2., 
      2.5714285714285716`}, {3., 2.0714285714285716`}, {4., 
      1.6428571428571428`}, {5., 1.2142857142857142`}, {6., 
      0.7857142857142857}, {7., 0.5}, {8., 0.35714285714285715`}, {9., 
      0.21428571428571427`}, {10., 0.07142857142857142}}]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.357142857142857}, {1., 3.7857142857142856`}, {2., 
      3.2142857142857144`}, {3., 2.9285714285714284`}, {4., 
      2.7857142857142856`}, {5., 2.642857142857143}, {6., 2.5}, {7., 
      2.357142857142857}, {8., 2.2142857142857144`}, {9., 
      2.0714285714285716`}, {10., 2.0714285714285716`}}]}, 
    {RGBColor[0.560181, 0.691569, 0.194885], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.642857142857143}, {1., 4.071428571428571}, {2., 
      3.7142857142857144`}, {3., 3.4285714285714284`}, {4., 
      3.142857142857143}, {5., 2.857142857142857}, {6., 
      2.5714285714285716`}, {7., 2.2857142857142856`}, {8., 2.}, {9., 
      1.7142857142857142`}, {10., 1.5}}]}, 
    {RGBColor[0.922526, 0.385626, 0.209179], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 3.357142857142857}, {1., 2.357142857142857}, {2., 1.5}, {
      3., 0.9285714285714286}, {4., 0.5}, {5., 0.21428571428571427`}, {
      6., -0.07142857142857142}, {7., -0.35714285714285715`}, {
      8., -0.6428571428571429}, {9., -0.7857142857142857}, {
      10., -0.7857142857142857}}]}, 
    {RGBColor[0.528488, 0.470624, 0.701351], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.714285714285714}, {1., 3.857142857142857}, {2., 
      3.2142857142857144`}, {3., 2.7857142857142856`}, {4., 
      2.357142857142857}, {5., 1.9285714285714286`}, {6., 1.5}, {7., 
      1.4285714285714286`}, {8., 1.4285714285714286`}, {9., 
      1.4285714285714286`}, {10., 1.4285714285714286`}}]}, 
    {RGBColor[0.772079, 0.431554, 0.102387], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.142857142857143}, {1., 3.142857142857143}, {2., 
      2.2857142857142856`}, {3., 1.7857142857142858`}, {4., 
      1.3571428571428572`}, {5., 0.9285714285714286}, {6., 0.5}, {7., 
      0.21428571428571427`}, {8., -0.07142857142857142}, {
      9., -0.35714285714285715`}, {10., -0.5}}]}, 
    {RGBColor[0.363898, 0.618501, 0.782349], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.857142857142857}, {1., 4.}, {2., 3.4285714285714284`}, {
      3., 2.857142857142857}, {4., 2.357142857142857}, {5., 
      1.9285714285714286`}, {6., 1.5}, {7., 1.2142857142857142`}, {8., 
      1.0714285714285714`}, {9., 0.9285714285714286}, {10., 
      0.9285714285714286}}]}, 
    {RGBColor[1, 0.75, 0], PointSize[0.004583333333333334], AbsoluteThickness[
     1.6], LineBox[{{0., 4.714285714285714}, {1., 4.}, {2., 
      3.4285714285714284`}, {3., 3.2142857142857144`}, {4., 
      3.0714285714285716`}, {5., 2.9285714285714284`}, {6., 
      2.7857142857142856`}, {7., 2.642857142857143}, {8., 
      2.5714285714285716`}, {9., 2.5714285714285716`}, {10., 
      2.5714285714285716`}}]}, 
    {RGBColor[0.647624, 0.37816, 0.614037], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 5.5}, {1., 4.928571428571429}, {2., 4.571428571428571}, {
      3., 4.428571428571429}, {4., 4.285714285714286}, {5., 
      4.285714285714286}, {6., 4.285714285714286}, {7., 4.285714285714286}, {
      8., 4.285714285714286}, {9., 4.285714285714286}, {10., 
      4.285714285714286}}]}, 
    {RGBColor[0.571589, 0.586483, 0.], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.285714285714286}, {1., 3.4285714285714284`}, {2., 
      2.7857142857142856`}, {3., 2.2142857142857144`}, {4., 2.}, {5., 
      1.8571428571428572`}, {6., 1.7142857142857142`}, {7., 
      1.5714285714285714`}, {8., 1.4285714285714286`}, {9., 
      1.3571428571428572`}, {10., 1.3571428571428572`}}]}, 
    {RGBColor[0.915, 0.3325, 0.2125], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.071428571428571}, {1., 3.142857142857143}, {2., 2.5}, {
      3., 1.9285714285714286`}, {4., 1.5}, {5., 1.2857142857142858`}, {6., 
      1.1428571428571428`}, {7., 1.0714285714285714`}, {8., 
      1.0714285714285714`}, {9., 1.0714285714285714`}, {10., 
      1.0714285714285714`}}]}, 
    {RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], PointSize[
     0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 5.}, {1., 4.285714285714286}, {2., 3.7857142857142856`}, {
      3., 3.5}, {4., 3.2142857142857144`}, {5., 2.9285714285714284`}, {6., 
      2.7857142857142856`}, {7., 2.642857142857143}, {8., 2.5}, {9., 
      2.357142857142857}, {10., 2.2142857142857144`}}]}, 
    {RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
     PointSize[0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 3.2857142857142856`}, {1., 2.2857142857142856`}, {2., 
      1.6428571428571428`}, {3., 1.2142857142857142`}, {4., 
      0.7857142857142857}, {5., 0.5}, {6., 0.21428571428571427`}, {
      7., -0.07142857142857142}, {8., -0.21428571428571427`}, {
      9., -0.21428571428571427`}, {10., -0.21428571428571427`}}]}, 
    {RGBColor[0.736782672705901, 0.358, 0.5030266573755369], PointSize[
     0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 4.571428571428571}, {1., 4.}, {2., 3.5714285714285716`}, {
      3., 3.142857142857143}, {4., 2.7142857142857144`}, {5., 
      2.2857142857142856`}, {6., 1.8571428571428572`}, {7., 
      1.5714285714285714`}, {8., 1.2857142857142858`}, {9., 1.}, {10., 
      0.7857142857142857}}]}, 
    {RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], PointSize[
     0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 4.571428571428571}, {1., 3.7142857142857144`}, {2., 
      3.357142857142857}, {3., 3.0714285714285716`}, {4., 
      2.7857142857142856`}, {5., 2.5}, {6., 2.2142857142857144`}, {7., 
      1.9285714285714286`}, {8., 1.6428571428571428`}, {9., 
      1.3571428571428572`}, {10., 1.0714285714285714`}}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 3.7857142857142856`}, {1., 3.0714285714285716`}, {2., 
      2.5714285714285716`}, {3., 2.2857142857142856`}, {4., 2.}, {5., 
      1.7142857142857142`}, {6., 1.4285714285714286`}, {7., 
      1.2857142857142858`}, {8., 1.1428571428571428`}, {9., 1.}, {10., 1.}}]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 5.785714285714286}, {1., 5.214285714285714}, {2., 
      4.857142857142857}, {3., 4.571428571428571}, {4., 4.285714285714286}, {
      5., 4.071428571428571}, {6., 3.9285714285714284`}, {7., 
      3.7857142857142856`}, {8., 3.7857142857142856`}, {9., 
      3.7857142857142856`}, {10., 3.7857142857142856`}}]}, 
    {RGBColor[0.560181, 0.691569, 0.194885], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.857142857142857}, {1., 4.}, {2., 3.2857142857142856`}, {
      3., 2.5714285714285716`}, {4., 2.}, {5., 1.5714285714285714`}, {6., 
      1.1428571428571428`}, {7., 0.8571428571428571}, {8., 
      0.5714285714285714}, {9., 0.2857142857142857}, {10., 0.}}]}, 
    {RGBColor[0.922526, 0.385626, 0.209179], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.357142857142857}, {1., 3.642857142857143}, {2., 3.}, {3.,
       2.4285714285714284`}, {4., 1.8571428571428572`}, {5., 
      1.7142857142857142`}, {6., 1.5714285714285714`}, {7., 
      1.4285714285714286`}, {8., 1.2857142857142858`}, {9., 
      1.1428571428571428`}, {10., 1.}}]}, 
    {RGBColor[0.528488, 0.470624, 0.701351], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 5.071428571428571}, {1., 4.214285714285714}, {2., 
      3.5714285714285716`}, {3., 3.}, {4., 2.5714285714285716`}, {5., 
      2.142857142857143}, {6., 1.7142857142857142`}, {7., 
      1.2857142857142858`}, {8., 1.}, {9., 0.7142857142857143}, {10., 0.5}}]}, 
    {RGBColor[0.772079, 0.431554, 0.102387], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 3.357142857142857}, {1., 2.5}, {2., 2.}, {3., 
      1.5714285714285714`}, {4., 1.1428571428571428`}, {5., 
      0.7142857142857143}, {6., 0.2857142857142857}, {7., 
      0.14285714285714285`}, {8., 0.}, {9., -0.14285714285714285`}, {
      10., -0.2857142857142857}}]}, 
    {RGBColor[0.363898, 0.618501, 0.782349], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.428571428571429}, {1., 3.4285714285714284`}, {2., 
      2.7142857142857144`}, {3., 2.2142857142857144`}, {4., 
      2.0714285714285716`}, {5., 1.9285714285714286`}, {6., 
      1.7857142857142858`}, {7., 1.6428571428571428`}, {8., 1.5}, {9., 
      1.3571428571428572`}, {10., 1.2142857142857142`}}]}, 
    {RGBColor[1, 0.75, 0], PointSize[0.004583333333333334], AbsoluteThickness[
     1.6], LineBox[{{0., 4.357142857142857}, {1., 3.7857142857142856`}, {2., 
      3.357142857142857}, {3., 2.9285714285714284`}, {4., 2.5}, {5., 
      2.0714285714285716`}, {6., 1.6428571428571428`}, {7., 
      1.3571428571428572`}, {8., 1.2142857142857142`}, {9., 
      1.2142857142857142`}, {10., 1.2142857142857142`}}]}, 
    {RGBColor[0.647624, 0.37816, 0.614037], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.}, {1., 3.142857142857143}, {2., 2.5}, {3., 
      1.9285714285714286`}, {4., 1.7142857142857142`}, {5., 
      1.5714285714285714`}, {6., 1.4285714285714286`}, {7., 
      1.2857142857142858`}, {8., 1.1428571428571428`}, {9., 1.}, {10., 
      0.8571428571428571}}]}, 
    {RGBColor[0.571589, 0.586483, 0.], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 3.642857142857143}, {1., 2.7857142857142856`}, {2., 
      2.0714285714285716`}, {3., 1.5}, {4., 1.}, {5., 0.7142857142857143}, {
      6., 0.42857142857142855`}, {7., 0.14285714285714285`}, {
      8., -0.14285714285714285`}, {9., -0.42857142857142855`}, {
      10., -0.7142857142857143}}]}, 
    {RGBColor[0.915, 0.3325, 0.2125], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.428571428571429}, {1., 3.7142857142857144`}, {2., 
      3.142857142857143}, {3., 2.5714285714285716`}, {4., 2.}, {5., 
      1.4285714285714286`}, {6., 1.}, {7., 0.6428571428571429}, {8., 0.5}, {
      9., 0.35714285714285715`}, {10., 0.21428571428571427`}}]}, 
    {RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], PointSize[
     0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 4.}, {1., 3.142857142857143}, {2., 2.5}, {3., 
      1.9285714285714286`}, {4., 1.5}, {5., 1.3571428571428572`}, {6., 
      1.2142857142857142`}, {7., 1.1428571428571428`}, {8., 
      1.1428571428571428`}, {9., 1.1428571428571428`}, {10., 
      1.1428571428571428`}}]}, 
    {RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
     PointSize[0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 4.857142857142857}, {1., 4.}, {2., 3.4285714285714284`}, {
      3., 2.857142857142857}, {4., 2.357142857142857}, {5., 
      2.0714285714285716`}, {6., 1.7857142857142858`}, {7., 
      1.5714285714285714`}, {8., 1.4285714285714286`}, {9., 
      1.2857142857142858`}, {10., 1.1428571428571428`}}]}, 
    {RGBColor[0.736782672705901, 0.358, 0.5030266573755369], PointSize[
     0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 4.785714285714286}, {1., 3.9285714285714284`}, {2., 
      3.5714285714285716`}, {3., 3.4285714285714284`}, {4., 
      3.2857142857142856`}, {5., 3.142857142857143}, {6., 3.}, {7., 
      2.857142857142857}, {8., 2.7142857142857144`}, {9., 
      2.5714285714285716`}, {10., 2.4285714285714284`}}]}, 
    {RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], PointSize[
     0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 4.285714285714286}, {1., 3.4285714285714284`}, {2., 
      2.642857142857143}, {3., 2.2142857142857144`}, {4., 
      1.9285714285714286`}, {5., 1.7857142857142858`}, {6., 
      1.6428571428571428`}, {7., 1.5}, {8., 1.3571428571428572`}, {9., 
      1.2142857142857142`}, {10., 1.0714285714285714`}}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 3.7857142857142856`}, {1., 2.9285714285714284`}, {2., 
      2.357142857142857}, {3., 1.9285714285714286`}, {4., 1.5}, {5., 
      1.0714285714285714`}, {6., 0.6428571428571429}, {7., 
      0.21428571428571427`}, {8., 0.}, {9., 0.}, {10., 0.}}]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 3.7857142857142856`}, {1., 2.9285714285714284`}, {2., 
      2.2142857142857144`}, {3., 1.6428571428571428`}, {4., 
      1.2142857142857142`}, {5., 0.7857142857142857}, {6., 
      0.35714285714285715`}, {7., -0.07142857142857142}, {8., -0.5}, {
      9., -0.8571428571428571}, {10., -1.0714285714285714`}}]}, 
    {RGBColor[0.560181, 0.691569, 0.194885], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 5.285714285714286}, {1., 4.571428571428571}, {2., 4.}, {3.,
       3.4285714285714284`}, {4., 2.9285714285714284`}, {5., 
      2.7857142857142856`}, {6., 2.642857142857143}, {7., 2.5}, {8., 
      2.357142857142857}, {9., 2.2142857142857144`}, {10., 
      2.0714285714285716`}}]}, 
    {RGBColor[0.922526, 0.385626, 0.209179], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.357142857142857}, {1., 3.642857142857143}, {2., 
      3.2142857142857144`}, {3., 2.9285714285714284`}, {4., 
      2.642857142857143}, {5., 2.5}, {6., 2.357142857142857}, {7., 
      2.2142857142857144`}, {8., 2.2142857142857144`}, {9., 
      2.2142857142857144`}, {10., 2.2142857142857144`}}]}, 
    {RGBColor[0.528488, 0.470624, 0.701351], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 3.4285714285714284`}, {1., 2.5714285714285716`}, {2., 
      1.7857142857142858`}, {3., 1.0714285714285714`}, {4., 
      0.5714285714285714}, {5., 0.2857142857142857}, {6., 0.}, {
      7., -0.14285714285714285`}, {8., -0.2857142857142857}, {
      9., -0.42857142857142855`}, {10., -0.5}}]}, 
    {RGBColor[0.772079, 0.431554, 0.102387], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.571428571428571}, {1., 4.}, {2., 3.642857142857143}, {3.,
       3.357142857142857}, {4., 3.0714285714285716`}, {5., 
      2.7857142857142856`}, {6., 2.5}, {7., 2.357142857142857}, {8., 
      2.2142857142857144`}, {9., 2.0714285714285716`}, {10., 
      1.9285714285714286`}}]}, 
    {RGBColor[0.363898, 0.618501, 0.782349], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 3.642857142857143}, {1., 2.642857142857143}, {2., 
      1.9285714285714286`}, {3., 1.7857142857142858`}, {4., 
      1.6428571428571428`}, {5., 1.5}, {6., 1.3571428571428572`}, {7., 
      1.2142857142857142`}, {8., 1.0714285714285714`}, {9., 
      0.9285714285714286}, {10., 0.7857142857142857}}]}, 
    {RGBColor[1, 0.75, 0], PointSize[0.004583333333333334], AbsoluteThickness[
     1.6], LineBox[{{0., 3.857142857142857}, {1., 2.857142857142857}, {2., 
      2.4285714285714284`}, {3., 2.}, {4., 1.5714285714285714`}, {5., 
      1.1428571428571428`}, {6., 0.7857142857142857}, {7., 
      0.6428571428571429}, {8., 0.5}, {9., 0.35714285714285715`}, {10., 
      0.21428571428571427`}}]}, 
    {RGBColor[0.647624, 0.37816, 0.614037], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.5}, {1., 3.642857142857143}, {2., 3.}, {3., 
      2.7142857142857144`}, {4., 2.4285714285714284`}, {5., 
      2.2857142857142856`}, {6., 2.2142857142857144`}, {7., 
      2.2142857142857144`}, {8., 2.2142857142857144`}, {9., 
      2.2142857142857144`}, {10., 2.2142857142857144`}}]}, 
    {RGBColor[0.571589, 0.586483, 0.], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 2.9285714285714284`}, {1., 2.0714285714285716`}, {2., 
      1.5714285714285714`}, {3., 1.1428571428571428`}, {4., 
      0.7857142857142857}, {5., 0.5}, {6., 0.21428571428571427`}, {7., 
      0.07142857142857142}, {8., -0.07142857142857142}, {
      9., -0.21428571428571427`}, {10., -0.35714285714285715`}}]}, 
    {RGBColor[0.915, 0.3325, 0.2125], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.428571428571429}, {1., 3.857142857142857}, {2., 
      3.4285714285714284`}, {3., 3.}, {4., 2.642857142857143}, {5., 2.5}, {6.,
       2.357142857142857}, {7., 2.2142857142857144`}, {8., 
      2.0714285714285716`}, {9., 1.9285714285714286`}, {10., 
      1.7857142857142858`}}]}, 
    {RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], PointSize[
     0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 5.}, {1., 4.428571428571429}, {2., 4.}, {3., 
      3.5714285714285716`}, {4., 3.142857142857143}, {5., 
      2.7142857142857144`}, {6., 2.4285714285714284`}, {7., 
      2.142857142857143}, {8., 1.8571428571428572`}, {9., 
      1.6428571428571428`}, {10., 1.5}}]}, 
    {RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
     PointSize[0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 4.928571428571429}, {1., 4.357142857142857}, {2., 
      3.9285714285714284`}, {3., 3.5}, {4., 3.0714285714285716`}, {5., 
      2.642857142857143}, {6., 2.2857142857142856`}, {7., 2.}, {8., 
      1.7142857142857142`}, {9., 1.4285714285714286`}, {10., 
      1.1428571428571428`}}]}, 
    {RGBColor[0.736782672705901, 0.358, 0.5030266573755369], PointSize[
     0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 4.857142857142857}, {1., 4.}, {2., 3.2857142857142856`}, {
      3., 2.9285714285714284`}, {4., 2.7857142857142856`}, {5., 
      2.642857142857143}, {6., 2.5}, {7., 2.357142857142857}, {8., 
      2.2142857142857144`}, {9., 2.0714285714285716`}, {10., 
      1.9285714285714286`}}]}, 
    {RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], PointSize[
     0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 4.642857142857143}, {1., 3.9285714285714284`}, {2., 
      3.2142857142857144`}, {3., 2.5}, {4., 1.7857142857142858`}, {5., 
      1.2857142857142858`}, {6., 1.}, {7., 0.8571428571428571}, {8., 
      0.7142857142857143}, {9., 0.5714285714285714}, {10., 
      0.42857142857142855`}}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 5.071428571428571}, {1., 4.357142857142857}, {2., 
      3.642857142857143}, {3., 3.2142857142857144`}, {4., 
      2.9285714285714284`}, {5., 2.642857142857143}, {6., 
      2.357142857142857}, {7., 2.0714285714285716`}, {8., 
      1.8571428571428572`}, {9., 1.7142857142857142`}, {10., 
      1.5714285714285714`}}]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.285714285714286}, {1., 3.4285714285714284`}, {2., 
      2.7857142857142856`}, {3., 2.2142857142857144`}, {4., 
      1.6428571428571428`}, {5., 1.0714285714285714`}, {6., 
      0.9285714285714286}, {7., 0.7857142857142857}, {8., 
      0.6428571428571429}, {9., 0.5}, {10., 0.35714285714285715`}}]}, 
    {RGBColor[0.560181, 0.691569, 0.194885], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.642857142857143}, {1., 3.7142857142857144`}, {2., 
      3.142857142857143}, {3., 2.5714285714285716`}, {4., 2.}, {5., 
      1.4285714285714286`}, {6., 0.8571428571428571}, {7., 
      0.42857142857142855`}, {8., 0.21428571428571427`}, {9., 
      0.21428571428571427`}, {10., 0.21428571428571427`}}]}, 
    {RGBColor[0.922526, 0.385626, 0.209179], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.142857142857143}, {1., 3.2857142857142856`}, {2., 
      2.642857142857143}, {3., 2.2857142857142856`}, {4., 
      2.0714285714285716`}, {5., 1.9285714285714286`}, {6., 
      1.7857142857142858`}, {7., 1.6428571428571428`}, {8., 1.5}, {9., 
      1.3571428571428572`}, {10., 1.2142857142857142`}}]}, 
    {RGBColor[0.528488, 0.470624, 0.701351], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 3.5}, {1., 2.642857142857143}, {2., 2.2142857142857144`}, {
      3., 2.}, {4., 1.8571428571428572`}, {5., 1.7142857142857142`}, {6., 
      1.5714285714285714`}, {7., 1.4285714285714286`}, {8., 
      1.2857142857142858`}, {9., 1.2142857142857142`}, {10., 
      1.2142857142857142`}}]}, 
    {RGBColor[0.772079, 0.431554, 0.102387], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.857142857142857}, {1., 4.142857142857143}, {2., 3.5}, {
      3., 2.9285714285714284`}, {4., 2.357142857142857}, {5., 
      1.7857142857142858`}, {6., 1.2857142857142858`}, {7., 1.}, {8., 
      0.7142857142857143}, {9., 0.42857142857142855`}, {10., 
      0.14285714285714285`}}]}, 
    {RGBColor[0.363898, 0.618501, 0.782349], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.214285714285714}, {1., 3.357142857142857}, {2., 2.5}, {
      3., 2.}, {4., 1.5714285714285714`}, {5., 1.2857142857142858`}, {6., 
      1.2857142857142858`}, {7., 1.2857142857142858`}, {8., 
      1.2857142857142858`}, {9., 1.2857142857142858`}, {10., 
      1.2857142857142858`}}]}, 
    {RGBColor[1, 0.75, 0], PointSize[0.004583333333333334], AbsoluteThickness[
     1.6], LineBox[{{0., 5.214285714285714}, {1., 4.5}, {2., 
      3.857142857142857}, {3., 3.2857142857142856`}, {4., 
      2.7142857142857144`}, {5., 2.142857142857143}, {6., 
      1.5714285714285714`}, {7., 1.}, {8., 0.5714285714285714}, {9., 
      0.14285714285714285`}, {10., -0.07142857142857142}}]}, 
    {RGBColor[0.647624, 0.37816, 0.614037], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.285714285714286}, {1., 3.4285714285714284`}, {2., 
      2.857142857142857}, {3., 2.2857142857142856`}, {4., 
      1.7142857142857142`}, {5., 1.1428571428571428`}, {6., 
      0.6428571428571429}, {7., 0.21428571428571427`}, {
      8., -0.07142857142857142}, {9., -0.35714285714285715`}, {
      10., -0.6428571428571429}}]}, 
    {RGBColor[0.571589, 0.586483, 0.], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.714285714285714}, {1., 3.857142857142857}, {2., 
      3.2142857142857144`}, {3., 2.7857142857142856`}, {4., 
      2.357142857142857}, {5., 1.9285714285714286`}, {6., 
      1.7142857142857142`}, {7., 1.5714285714285714`}, {8., 
      1.4285714285714286`}, {9., 1.2857142857142858`}, {10., 
      1.1428571428571428`}}]}, 
    {RGBColor[0.915, 0.3325, 0.2125], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 5.285714285714286}, {1., 4.714285714285714}, {2., 
      4.285714285714286}, {3., 3.857142857142857}, {4., 
      3.4285714285714284`}, {5., 3.}, {6., 2.5714285714285716`}, {7., 
      2.142857142857143}, {8., 1.7142857142857142`}, {9., 
      1.2857142857142858`}, {10., 0.8571428571428571}}]}, 
    {RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], PointSize[
     0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 4.857142857142857}, {1., 4.}, {2., 3.2857142857142856`}, {
      3., 2.7142857142857144`}, {4., 2.142857142857143}, {5., 
      1.5714285714285714`}, {6., 1.0714285714285714`}, {7., 
      0.6428571428571429}, {8., 0.5}, {9., 0.35714285714285715`}, {10., 
      0.21428571428571427`}}]}, 
    {RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
     PointSize[0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 5.142857142857143}, {1., 4.285714285714286}, {2., 
      3.7857142857142856`}, {3., 3.5}, {4., 3.2142857142857144`}, {5., 
      2.9285714285714284`}, {6., 2.642857142857143}, {7., 
      2.357142857142857}, {8., 2.0714285714285716`}, {9., 
      1.8571428571428572`}, {10., 1.7142857142857142`}}]}, 
    {RGBColor[0.736782672705901, 0.358, 0.5030266573755369], PointSize[
     0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 4.928571428571429}, {1., 4.5}, {2., 4.071428571428571}, {
      3., 3.7142857142857144`}, {4., 3.4285714285714284`}, {5., 
      3.142857142857143}, {6., 2.9285714285714284`}, {7., 
      2.7857142857142856`}, {8., 2.7857142857142856`}, {9., 
      2.7857142857142856`}, {10., 2.7857142857142856`}}]}, 
    {RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], PointSize[
     0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 4.642857142857143}, {1., 3.7857142857142856`}, {2., 
      3.357142857142857}, {3., 3.0714285714285716`}, {4., 
      2.7857142857142856`}, {5., 2.5}, {6., 2.2142857142857144`}, {7., 
      1.9285714285714286`}, {8., 1.6428571428571428`}, {9., 
      1.4285714285714286`}, {10., 1.2857142857142858`}}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 5.428571428571429}, {1., 4.714285714285714}, {2., 
      4.285714285714286}, {3., 4.}, {4., 3.7142857142857144`}, {5., 
      3.4285714285714284`}, {6., 3.142857142857143}, {7., 
      2.857142857142857}, {8., 2.5714285714285716`}, {9., 
      2.2857142857142856`}, {10., 2.}}]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.714285714285714}, {1., 4.}, {2., 3.4285714285714284`}, {
      3., 2.9285714285714284`}, {4., 2.642857142857143}, {5., 
      2.357142857142857}, {6., 2.0714285714285716`}, {7., 
      1.7857142857142858`}, {8., 1.5}, {9., 1.2142857142857142`}, {10., 
      1.0714285714285714`}}]}, 
    {RGBColor[0.560181, 0.691569, 0.194885], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 5.5}, {1., 4.785714285714286}, {2., 4.5}, {3., 
      4.214285714285714}, {4., 3.9285714285714284`}, {5., 
      3.642857142857143}, {6., 3.357142857142857}, {7., 
      3.0714285714285716`}, {8., 2.9285714285714284`}, {9., 
      2.7857142857142856`}, {10., 2.642857142857143}}]}, 
    {RGBColor[0.922526, 0.385626, 0.209179], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.428571428571429}, {1., 3.642857142857143}, {2., 
      3.142857142857143}, {3., 2.7142857142857144`}, {4., 
      2.4285714285714284`}, {5., 2.142857142857143}, {6., 
      1.8571428571428572`}, {7., 1.5714285714285714`}, {8., 
      1.4285714285714286`}, {9., 1.2857142857142858`}, {10., 
      1.1428571428571428`}}]}, 
    {RGBColor[0.528488, 0.470624, 0.701351], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.214285714285714}, {1., 3.357142857142857}, {2., 3.}, {3.,
       2.7142857142857144`}, {4., 2.5}, {5., 2.357142857142857}, {6., 
      2.2142857142857144`}, {7., 2.0714285714285716`}, {8., 
      1.9285714285714286`}, {9., 1.7857142857142858`}, {10., 
      1.6428571428571428`}}]}, 
    {RGBColor[0.772079, 0.431554, 0.102387], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 5.571428571428571}, {1., 5.}, {2., 4.428571428571429}, {3.,
       3.857142857142857}, {4., 3.2857142857142856`}, {5., 
      2.7142857142857144`}, {6., 2.142857142857143}, {7., 
      1.6428571428571428`}, {8., 1.2142857142857142`}, {9., 
      0.9285714285714286}, {10., 0.6428571428571429}}]}, 
    {RGBColor[0.363898, 0.618501, 0.782349], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.5}, {1., 3.7857142857142856`}, {2., 3.357142857142857}, {
      3., 3.0714285714285716`}, {4., 2.7857142857142856`}, {5., 2.5}, {6., 
      2.2142857142857144`}, {7., 1.9285714285714286`}, {8., 
      1.6428571428571428`}, {9., 1.4285714285714286`}, {10., 
      1.2857142857142858`}}]}, 
    {RGBColor[1, 0.75, 0], PointSize[0.004583333333333334], AbsoluteThickness[
     1.6], 
     LineBox[{{0., 4.071428571428571}, {1., 3.2142857142857144`}, {2., 
      2.642857142857143}, {3., 2.2142857142857144`}, {4., 
      1.7857142857142858`}, {5., 1.5}, {6., 1.2142857142857142`}, {7., 
      0.9285714285714286}, {8., 0.6428571428571429}, {9., 
      0.42857142857142855`}, {10., 0.2857142857142857}}]}, 
    {RGBColor[0.647624, 0.37816, 0.614037], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.857142857142857}, {1., 4.}, {2., 3.4285714285714284`}, {
      3., 2.9285714285714284`}, {4., 2.5}, {5., 2.0714285714285716`}, {6., 
      1.6428571428571428`}, {7., 1.2142857142857142`}, {8., 
      0.7857142857142857}, {9., 0.35714285714285715`}, {10., 
      0.07142857142857142}}]}, 
    {RGBColor[0.571589, 0.586483, 0.], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 3.9285714285714284`}, {1., 3.0714285714285716`}, {2., 
      2.4285714285714284`}, {3., 1.8571428571428572`}, {4., 
      1.2857142857142858`}, {5., 1.}, {6., 1.}, {7., 1.}, {8., 1.}, {9., 
      1.}, {10., 1.}}]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox["\"Score\"", TraditionalForm], None}, {
     FormBox["\"Gap-Penalty\"", TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 10.}, {-1.1428571428571428`, 5.857142857142857}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.677571708220752*^9}]
}, Open  ]],

Cell["\<\
Um den Einfluss der individuellen Sequenz noch deutlicher zu machen, tragen \
wir nun den Score multipliziert mit dem Gap-Penalty auf.\
\>", "Text",
 CellChangeTimes->{{3.6746362759803076`*^9, 3.67463629737034*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tabFull1", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"alignmentScore", "[", 
              RowBox[{
               RowBox[{"sequenceTab1", "[", 
                RowBox[{"[", "j", "]"}], "]"}], ",", 
               RowBox[{"sequenceTab2", "[", 
                RowBox[{"[", "j", "]"}], "]"}], ",", "blosum", ",", "i"}], 
              "]"}], ")"}], "/", "seqLength"}], "]"}], "*", 
          RowBox[{"(", 
           RowBox[{"i", "+", "1"}], ")"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "10"}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", "seqNum"}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.577761446708804*^9, 3.577761522035701*^9}, 
   3.577761556011571*^9, {3.5777616212590313`*^9, 3.577761658823065*^9}, {
   3.577761695055909*^9, 3.5777616962915792`*^9}, {3.577761733282014*^9, 
   3.577761753527424*^9}, {3.577761800048826*^9, 3.577761800248291*^9}, {
   3.577762148394362*^9, 3.577762180522876*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"tabFull1", ",", " ", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"\"\<Gap-Penalty\>\"", ",", "\"\<Score * Gap-Penalty\>\""}], 
     "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.577761269587592*^9, 3.577761293628314*^9}, 
   3.57776156124183*^9, {3.616383407849289*^9, 3.6163834082940207`*^9}, {
   3.616728390075906*^9, 3.616728405346635*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.714285714285714}, {1., 8.}, {2., 10.714285714285715`}, {
      3., 12.571428571428571`}, {4., 13.571428571428573`}, {5., 
      13.714285714285714`}, {6., 13.}, {7., 11.428571428571429`}, {8., 9.}, {
      9., 7.857142857142857}, {10., 8.642857142857142}}]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 3.9285714285714284`}, {1., 6.428571428571429}, {2., 
      9.214285714285715}, {3., 11.714285714285714`}, {4., 
      13.928571428571427`}, {5., 15.857142857142858`}, {6., 17.5}, {7., 
      18.857142857142858`}, {8., 19.92857142857143}, {9., 
      20.714285714285715`}, {10., 21.214285714285715`}}]}, 
    {RGBColor[0.560181, 0.691569, 0.194885], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.5}, {1., 7.571428571428571}, {2., 9.642857142857142}, {
      3., 10.571428571428571`}, {4., 11.785714285714286`}, {5., 
      12.42857142857143}, {6., 12.5}, {7., 12.}, {8., 11.571428571428573`}, {
      9., 11.428571428571427`}, {10., 11.}}]}, 
    {RGBColor[0.922526, 0.385626, 0.209179], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.857142857142857}, {1., 8.285714285714286}, {2., 
      10.285714285714285`}, {3., 10.857142857142858`}, {4., 
      10.714285714285714`}, {5., 9.857142857142858}, {6., 9.5}, {7., 
      9.714285714285714}, {8., 9.642857142857142}, {9., 9.285714285714286}, {
      10., 8.642857142857142}}]}, 
    {RGBColor[0.528488, 0.470624, 0.701351], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 5.}, {1., 8.571428571428571}, {2., 10.714285714285715`}, {
      3., 11.428571428571429`}, {4., 10.714285714285714`}, {5., 
      8.571428571428571}, {6., 5.5}, {7., 2.2857142857142856`}, {8., 0.}, {
      9., -2.8571428571428568`}, {10., -5.5}}]}, 
    {RGBColor[0.772079, 0.431554, 0.102387], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 5.214285714285714}, {1., 8.714285714285714}, {2., 
      10.928571428571429`}, {3., 11.714285714285714`}, {4., 
      11.071428571428573`}, {5., 10.714285714285715`}, {6., 9.5}, {7., 
      8.571428571428571}, {8., 7.071428571428571}, {9., 
      5.7142857142857135`}, {10., 4.714285714285714}}]}, 
    {RGBColor[0.363898, 0.618501, 0.782349], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.642857142857143}, {1., 8.142857142857142}, {2., 
      10.928571428571429`}, {3., 12.857142857142858`}, {4., 
      13.928571428571427`}, {5., 14.142857142857142`}, {6., 14.}, {7., 
      13.714285714285714`}, {8., 12.857142857142858`}, {9., 
      12.142857142857142`}, {10., 13.357142857142856`}}]}, 
    {RGBColor[1, 0.75, 0], PointSize[0.004583333333333334], AbsoluteThickness[
     1.6], LineBox[{{0., 4.5}, {1., 7.571428571428571}, {2., 
      10.071428571428571`}, {3., 12.285714285714286`}, {4., 
      13.928571428571427`}, {5., 15.}, {6., 15.5}, {7., 
      15.428571428571429`}, {8., 15.428571428571427`}, {9., 
      15.714285714285714`}, {10., 16.5}}]}, 
    {RGBColor[0.647624, 0.37816, 0.614037], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.571428571428571}, {1., 7.857142857142857}, {2., 
      10.071428571428571`}, {3., 11.714285714285714`}, {4., 
      13.214285714285714`}, {5., 14.142857142857142`}, {6., 
      14.500000000000002`}, {7., 15.428571428571429`}, {8., 
      16.071428571428573`}, {9., 16.428571428571427`}, {10., 16.5}}]}, 
    {RGBColor[0.571589, 0.586483, 0.], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 3.7142857142857144`}, {1., 5.428571428571429}, {2., 
      6.214285714285715}, {3., 6.571428571428571}, {4., 6.071428571428571}, {
      5., 4.714285714285714}, {6., 2.5}, {7., -0.5714285714285714}, {
      8., -4.5}, {9., -8.571428571428571}, {10., -12.571428571428571`}}]}, 
    {RGBColor[0.915, 0.3325, 0.2125], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.071428571428571}, {1., 6.142857142857143}, {2., 
      7.285714285714285}, {3., 7.428571428571429}, {4., 7.142857142857143}, {
      5., 6.}, {6., 4.}, {7., 1.1428571428571428`}, {8., 
      1.2857142857142856`}, {9., 1.4285714285714284`}, {10., 
      1.5714285714285714`}}]}, 
    {RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], PointSize[
     0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 4.785714285714286}, {1., 8.142857142857142}, {2., 
      10.714285714285715`}, {3., 12.571428571428571`}, {4., 
      13.928571428571427`}, {5., 15.}, {6., 15.5}, {7., 16.}, {8., 
      16.714285714285715`}, {9., 17.857142857142858`}, {10., 
      19.642857142857142`}}]}, 
    {RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
     PointSize[0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 5.142857142857143}, {1., 8.571428571428571}, {2., 
      10.714285714285715`}, {3., 12.}, {4., 12.857142857142858`}, {5., 
      15.42857142857143}, {6., 18.}, {7., 20.571428571428573`}, {8., 
      23.142857142857146`}, {9., 25.714285714285715`}, {10., 
      28.28571428571429}}]}, 
    {RGBColor[0.736782672705901, 0.358, 0.5030266573755369], PointSize[
     0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 4.785714285714286}, {1., 8.285714285714286}, {2., 
      11.142857142857142`}, {3., 13.142857142857142`}, {4., 
      14.285714285714286`}, {5., 14.57142857142857}, {6., 14.}, {7., 
      14.857142857142858`}, {8., 15.428571428571427`}, {9., 
      15.714285714285714`}, {10., 15.714285714285715`}}]}, 
    {RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], PointSize[
     0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 4.571428571428571}, {1., 7.714285714285714}, {2., 
      9.857142857142858}, {3., 10.857142857142858`}, {4., 
      11.428571428571427`}, {5., 12.}, {6., 12.}, {7., 11.428571428571429`}, {
      8., 10.285714285714285`}, {9., 8.571428571428571}, {10., 
      9.428571428571429}}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.357142857142857}, {1., 7.}, {2., 8.357142857142858}, {3.,
       9.714285714285714}, {4., 10.714285714285714`}, {5., 
      11.142857142857142`}, {6., 11.}, {7., 11.428571428571429`}, {8., 
      11.571428571428573`}, {9., 12.142857142857142`}, {10., 
      13.357142857142856`}}]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 3.9285714285714284`}, {1., 6.}, {2., 7.071428571428571}, {
      3., 7.714285714285714}, {4., 7.857142857142857}, {5., 
      7.714285714285715}, {6., 7.}, {7., 5.714285714285714}, {8., 
      3.8571428571428568`}, {9., 1.4285714285714284`}, {
      10., -1.5714285714285714`}}]}, 
    {RGBColor[0.560181, 0.691569, 0.194885], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.285714285714286}, {1., 7.428571428571429}, {2., 
      10.714285714285715`}, {3., 13.714285714285714`}, {4., 
      16.428571428571427`}, {5., 19.714285714285715`}, {6., 23.}, {7., 
      26.285714285714285`}, {8., 29.57142857142857}, {8.619565217391306, 
      31.60714285714286}}]}, 
    {RGBColor[0.922526, 0.385626, 0.209179], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 5.142857142857143}, {1., 8.857142857142858}, {2., 
      11.571428571428571`}, {3., 13.142857142857142`}, {4., 
      13.928571428571427`}, {5., 14.142857142857142`}, {6., 13.5}, {7., 
      12.}, {8., 10.928571428571427`}, {9., 11.428571428571427`}, {10., 
      12.571428571428571`}}]}, 
    {RGBColor[0.528488, 0.470624, 0.701351], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 5.357142857142857}, {1., 9.285714285714286}, {2., 
      12.42857142857143}, {3., 14.857142857142858`}, {4., 
      16.785714285714285`}, {5., 19.285714285714285`}, {6., 21.5}, {7., 
      23.428571428571427`}, {8., 25.07142857142857}, {9., 
      26.428571428571427`}, {10., 27.5}}]}, 
    {RGBColor[0.772079, 0.431554, 0.102387], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.714285714285714}, {1., 7.714285714285714}, {2., 
      9.214285714285715}, {3., 10.285714285714286`}, {4., 
      12.142857142857142`}, {5., 13.714285714285714`}, {6., 15.}, {7., 16.}, {
      8., 16.714285714285715`}, {9., 17.142857142857142`}, {10., 
      17.285714285714285`}}]}, 
    {RGBColor[0.363898, 0.618501, 0.782349], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 3.5}, {1., 5.285714285714286}, {2., 5.785714285714286}, {
      3., 6.}, {4., 6.071428571428571}, {5., 5.571428571428571}, {6., 4.5}, {
      7., 2.857142857142857}, {8., 0.6428571428571428}, {9., 0.}, {10., 
      0.}}]}, 
    {RGBColor[1, 0.75, 0], PointSize[0.004583333333333334], AbsoluteThickness[
     1.6], LineBox[{{0., 3.4285714285714284`}, {1., 4.857142857142857}, {2., 
      5.785714285714286}, {3., 6.}, {4., 5.357142857142857}, {5., 
      3.8571428571428577`}, {6., 1.5}, {7., -0.5714285714285714}, {
      8., -3.2142857142857144`}, {9., -5.7142857142857135`}, {
      10., -6.285714285714286}}]}, 
    {RGBColor[0.647624, 0.37816, 0.614037], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.714285714285714}, {1., 8.}, {2., 10.5}, {3., 
      12.285714285714286`}, {4., 13.214285714285714`}, {5., 
      13.285714285714286`}, {6., 12.5}, {7., 10.857142857142858`}, {8., 
      8.357142857142858}, {9., 7.857142857142857}, {10., 
      7.071428571428572}}]}, 
    {RGBColor[0.571589, 0.586483, 0.], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 5.857142857142857}, {1., 10.}, {2., 12.42857142857143}, {
      3., 13.142857142857142`}, {4., 12.142857142857142`}, {5., 12.}, {6., 
      11.}, {7., 9.714285714285714}, {8., 9.}, {9., 8.571428571428571}, {10., 
      7.857142857142858}}]}, 
    {RGBColor[0.915, 0.3325, 0.2125], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 3.142857142857143}, {1., 4.571428571428571}, {2., 
      5.571428571428571}, {3., 6.285714285714286}, {4., 6.428571428571429}, {
      5., 6.}, {6., 5.}, {7., 3.4285714285714284`}, {8., 
      1.2857142857142856`}, {9., -1.4285714285714284`}, {
      10., -4.714285714285714}}]}, 
    {RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], PointSize[
     0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 4.357142857142857}, {1., 7.}, {2., 8.571428571428571}, {3.,
       9.714285714285714}, {4., 10.}, {5., 9.428571428571429}, {6., 8.}, {7., 
      5.714285714285714}, {8., 2.571428571428571}, {9., 
      1.4285714285714284`}, {10., 1.5714285714285714`}}]}, 
    {RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
     PointSize[0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 4.142857142857143}, {1., 6.571428571428571}, {2., 
      8.142857142857142}, {3., 9.142857142857142}, {4., 10.}, {5., 
      10.285714285714285`}, {6., 10.}, {7., 9.142857142857142}, {8., 9.}, {9.,
       8.571428571428571}, {10., 9.428571428571429}}]}, 
    {RGBColor[0.736782672705901, 0.358, 0.5030266573755369], PointSize[
     0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 4.142857142857143}, {1., 6.285714285714286}, {2., 7.5}, {
      3., 8.285714285714286}, {4., 8.214285714285714}, {5., 
      8.142857142857142}, {6., 7.5}, {7., 6.285714285714286}, {8., 4.5}, {9., 
      2.142857142857143}, {10., 0.7857142857142857}}]}, 
    {RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], PointSize[
     0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 5.071428571428571}, {1., 8.714285714285714}, {2., 12.}, {
      3., 14.857142857142858`}, {4., 17.142857142857142`}, {5., 
      18.857142857142858`}, {6., 20.}, {7., 21.142857142857142`}, {8., 
      22.5}, {9., 23.571428571428573`}, {10., 24.357142857142858`}}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.428571428571429}, {1., 6.857142857142857}, {2., 
      7.714285714285715}, {3., 8.285714285714286}, {4., 8.214285714285714}, {
      5., 7.285714285714285}, {6., 5.5}, {7., 4.}, {8., 
      3.2142857142857144`}, {9., 2.142857142857143}, {10., 
      0.7857142857142857}}]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.357142857142857}, {1., 7.571428571428571}, {2., 
      9.642857142857142}, {3., 11.714285714285714`}, {4., 
      13.928571428571427`}, {5., 15.857142857142858`}, {6., 17.5}, {7., 
      18.857142857142858`}, {8., 19.92857142857143}, {9., 
      20.714285714285715`}, {10., 22.78571428571429}}]}, 
    {RGBColor[0.560181, 0.691569, 0.194885], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.642857142857143}, {1., 8.142857142857142}, {2., 
      11.142857142857142`}, {3., 13.714285714285714`}, {4., 
      15.714285714285714`}, {5., 17.142857142857142`}, {6., 18.}, {7., 
      18.285714285714285`}, {8., 18.}, {9., 17.142857142857142`}, {10., 
      16.5}}]}, 
    {RGBColor[0.922526, 0.385626, 0.209179], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 3.357142857142857}, {1., 4.714285714285714}, {2., 4.5}, {
      3., 3.7142857142857144`}, {4., 2.5}, {5., 1.2857142857142856`}, {
      6., -0.5}, {7., -2.857142857142857}, {8., -5.7857142857142865`}, {
      9., -7.857142857142857}, {10., -8.642857142857142}}]}, 
    {RGBColor[0.528488, 0.470624, 0.701351], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.714285714285714}, {1., 7.714285714285714}, {2., 
      9.642857142857142}, {3., 11.142857142857142`}, {4., 
      11.785714285714286`}, {5., 11.571428571428571`}, {6., 10.5}, {7., 
      11.428571428571429`}, {8., 12.857142857142858`}, {9., 
      14.285714285714286`}, {10., 15.714285714285715`}}]}, 
    {RGBColor[0.772079, 0.431554, 0.102387], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.142857142857143}, {1., 6.285714285714286}, {2., 
      6.857142857142857}, {3., 7.142857142857143}, {4., 
      6.7857142857142865`}, {5., 5.571428571428571}, {6., 3.5}, {7., 
      1.7142857142857142`}, {8., -0.6428571428571428}, {
      9., -3.5714285714285716`}, {10., -5.5}}]}, 
    {RGBColor[0.363898, 0.618501, 0.782349], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.857142857142857}, {1., 8.}, {2., 10.285714285714285`}, {
      3., 11.428571428571429`}, {4., 11.785714285714286`}, {5., 
      11.571428571428571`}, {6., 10.5}, {7., 9.714285714285714}, {8., 
      9.642857142857142}, {9., 9.285714285714286}, {10., 
      10.214285714285715`}}]}, 
    {RGBColor[1, 0.75, 0], PointSize[0.004583333333333334], AbsoluteThickness[
     1.6], LineBox[{{0., 4.714285714285714}, {1., 8.}, {2., 
      10.285714285714285`}, {3., 12.857142857142858`}, {4., 
      15.357142857142858`}, {5., 17.57142857142857}, {6., 19.5}, {7., 
      21.142857142857142`}, {8., 23.142857142857146`}, {9., 
      25.714285714285715`}, {10., 28.28571428571429}}]}, 
    {RGBColor[0.647624, 0.37816, 0.614037], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 5.5}, {1., 9.857142857142858}, {2., 13.714285714285714`}, {
      3., 17.714285714285715`}, {4., 21.428571428571427`}, {5., 
      25.714285714285715`}, {6., 30.}, {6.375000000000001, 
      31.60714285714286}}]}, 
    {RGBColor[0.571589, 0.586483, 0.], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.285714285714286}, {1., 6.857142857142857}, {2., 
      8.357142857142858}, {3., 8.857142857142858}, {4., 10.}, {5., 
      11.142857142857142`}, {6., 12.}, {7., 12.571428571428571`}, {8., 
      12.857142857142858`}, {9., 13.571428571428573`}, {10., 
      14.928571428571429`}}]}, 
    {RGBColor[0.915, 0.3325, 0.2125], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.071428571428571}, {1., 6.285714285714286}, {2., 7.5}, {
      3., 7.714285714285714}, {4., 7.5}, {5., 7.714285714285715}, {6., 8.}, {
      7., 8.571428571428571}, {8., 9.642857142857142}, {9., 
      10.714285714285714`}, {10., 11.785714285714285`}}]}, 
    {RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], PointSize[
     0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 5.}, {1., 8.571428571428571}, {2., 11.357142857142858`}, {
      3., 14.}, {4., 16.071428571428573`}, {5., 17.57142857142857}, {6., 
      19.5}, {7., 21.142857142857142`}, {8., 22.5}, {9., 
      23.571428571428573`}, {10., 24.357142857142858`}}]}, 
    {RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
     PointSize[0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 3.2857142857142856`}, {1., 4.571428571428571}, {2., 
      4.928571428571429}, {3., 4.857142857142857}, {4., 
      3.9285714285714284`}, {5., 3.}, {6., 1.5}, {7., -0.5714285714285714}, {
      8., -1.9285714285714284`}, {9., -2.142857142857143}, {
      10., -2.357142857142857}}]}, 
    {RGBColor[0.736782672705901, 0.358, 0.5030266573755369], PointSize[
     0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 4.571428571428571}, {1., 8.}, {2., 10.714285714285715`}, {
      3., 12.571428571428571`}, {4., 13.571428571428573`}, {5., 
      13.714285714285714`}, {6., 13.}, {7., 12.571428571428571`}, {8., 
      11.571428571428573`}, {9., 10.}, {10., 8.642857142857142}}]}, 
    {RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], PointSize[
     0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 4.571428571428571}, {1., 7.428571428571429}, {2., 
      10.071428571428571`}, {3., 12.285714285714286`}, {4., 
      13.928571428571427`}, {5., 15.}, {6., 15.5}, {7., 
      15.428571428571429`}, {8., 14.785714285714285`}, {9., 
      13.571428571428573`}, {10., 11.785714285714285`}}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 3.7857142857142856`}, {1., 6.142857142857143}, {2., 
      7.714285714285715}, {3., 9.142857142857142}, {4., 10.}, {5., 
      10.285714285714285`}, {6., 10.}, {7., 10.285714285714286`}, {8., 
      10.285714285714285`}, {9., 10.}, {10., 11.}}]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 5.785714285714286}, {1., 10.428571428571429`}, {2., 
      14.57142857142857}, {3., 18.285714285714285`}, {4., 
      21.428571428571427`}, {5., 24.428571428571427`}, {6., 27.5}, {7., 
      30.285714285714285`}, {7.349056603773587, 31.60714285714286}}]}, 
    {RGBColor[0.560181, 0.691569, 0.194885], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.857142857142857}, {1., 8.}, {2., 9.857142857142858}, {3.,
       10.285714285714286`}, {4., 10.}, {5., 9.428571428571429}, {6., 8.}, {
      7., 6.857142857142857}, {8., 5.142857142857142}, {9., 
      2.8571428571428568`}, {10., 0.}}]}, 
    {RGBColor[0.922526, 0.385626, 0.209179], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.357142857142857}, {1., 7.285714285714286}, {2., 9.}, {3.,
       9.714285714285714}, {4., 9.285714285714286}, {5., 
      10.285714285714285`}, {6., 11.}, {7., 11.428571428571429`}, {8., 
      11.571428571428573`}, {9., 11.428571428571427`}, {10., 11.}}]}, 
    {RGBColor[0.528488, 0.470624, 0.701351], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 5.071428571428571}, {1., 8.428571428571429}, {2., 
      10.714285714285715`}, {3., 12.}, {4., 12.857142857142858`}, {5., 
      12.857142857142858`}, {6., 12.}, {7., 10.285714285714286`}, {8., 9.}, {
      9., 7.142857142857143}, {10., 5.5}}]}, 
    {RGBColor[0.772079, 0.431554, 0.102387], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 3.357142857142857}, {1., 5.}, {2., 6.}, {3., 
      6.285714285714286}, {4., 5.7142857142857135`}, {5., 
      4.285714285714286}, {6., 2.}, {7., 1.1428571428571428`}, {8., 0.}, {
      9., -1.4285714285714284`}, {10., -3.142857142857143}}]}, 
    {RGBColor[0.363898, 0.618501, 0.782349], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.428571428571429}, {1., 6.857142857142857}, {2., 
      8.142857142857142}, {3., 8.857142857142858}, {4., 
      10.357142857142858`}, {5., 11.571428571428571`}, {6., 12.5}, {7., 
      13.142857142857142`}, {8., 13.5}, {9., 13.571428571428573`}, {10., 
      13.357142857142856`}}]}, 
    {RGBColor[1, 0.75, 0], PointSize[0.004583333333333334], AbsoluteThickness[
     1.6], LineBox[{{0., 4.357142857142857}, {1., 7.571428571428571}, {2., 
      10.071428571428571`}, {3., 11.714285714285714`}, {4., 12.5}, {5., 
      12.42857142857143}, {6., 11.5}, {7., 10.857142857142858`}, {8., 
      10.928571428571427`}, {9., 12.142857142857142`}, {10., 
      13.357142857142856`}}]}, 
    {RGBColor[0.647624, 0.37816, 0.614037], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.}, {1., 6.285714285714286}, {2., 7.5}, {3., 
      7.714285714285714}, {4., 8.571428571428571}, {5., 9.428571428571429}, {
      6., 10.}, {7., 10.285714285714286`}, {8., 10.285714285714285`}, {9., 
      10.}, {10., 9.428571428571429}}]}, 
    {RGBColor[0.571589, 0.586483, 0.], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 3.642857142857143}, {1., 5.571428571428571}, {2., 
      6.214285714285715}, {3., 6.}, {4., 5.}, {5., 4.285714285714286}, {6., 
      3.}, {7., 1.1428571428571428`}, {8., -1.2857142857142856`}, {
      9., -4.285714285714286}, {10., -7.857142857142858}}]}, 
    {RGBColor[0.915, 0.3325, 0.2125], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.428571428571429}, {1., 7.428571428571429}, {2., 
      9.428571428571429}, {3., 10.285714285714286`}, {4., 10.}, {5., 
      8.571428571428571}, {6., 7.}, {7., 5.142857142857143}, {8., 4.5}, {9., 
      3.5714285714285716`}, {10., 2.357142857142857}}]}, 
    {RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], PointSize[
     0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 4.}, {1., 6.285714285714286}, {2., 7.5}, {3., 
      7.714285714285714}, {4., 7.5}, {5., 8.142857142857142}, {6., 8.5}, {7., 
      9.142857142857142}, {8., 10.285714285714285`}, {9., 
      11.428571428571427`}, {10., 12.571428571428571`}}]}, 
    {RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
     PointSize[0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 4.857142857142857}, {1., 8.}, {2., 10.285714285714285`}, {
      3., 11.428571428571429`}, {4., 11.785714285714286`}, {5., 
      12.42857142857143}, {6., 12.5}, {7., 12.571428571428571`}, {8., 
      12.857142857142858`}, {9., 12.857142857142858`}, {10., 
      12.571428571428571`}}]}, 
    {RGBColor[0.736782672705901, 0.358, 0.5030266573755369], PointSize[
     0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 4.785714285714286}, {1., 7.857142857142857}, {2., 
      10.714285714285715`}, {3., 13.714285714285714`}, {4., 
      16.428571428571427`}, {5., 18.857142857142858`}, {6., 21.}, {7., 
      22.857142857142858`}, {8., 24.42857142857143}, {9., 
      25.714285714285715`}, {10., 26.71428571428571}}]}, 
    {RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], PointSize[
     0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 4.285714285714286}, {1., 6.857142857142857}, {2., 
      7.928571428571429}, {3., 8.857142857142858}, {4., 9.642857142857142}, {
      5., 10.714285714285715`}, {6., 11.5}, {7., 12.}, {8., 
      12.214285714285715`}, {9., 12.142857142857142`}, {10., 
      11.785714285714285`}}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 3.7857142857142856`}, {1., 5.857142857142857}, {2., 
      7.071428571428571}, {3., 7.714285714285714}, {4., 7.5}, {5., 
      6.428571428571429}, {6., 4.5}, {7., 1.7142857142857142`}, {8., 0.}, {9.,
       0.}, {10., 0.}}]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 3.7857142857142856`}, {1., 5.857142857142857}, {2., 
      6.642857142857143}, {3., 6.571428571428571}, {4., 6.071428571428571}, {
      5., 4.714285714285714}, {6., 2.5}, {7., -0.5714285714285714}, {
      8., -4.5}, {9., -8.571428571428571}, {10., -11.785714285714285`}}]}, 
    {RGBColor[0.560181, 0.691569, 0.194885], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 5.285714285714286}, {1., 9.142857142857142}, {2., 12.}, {
      3., 13.714285714285714`}, {4., 14.642857142857142`}, {5., 
      16.714285714285715`}, {6., 18.5}, {7., 20.}, {8., 
      21.214285714285715`}, {9., 22.142857142857146`}, {10., 
      22.78571428571429}}]}, 
    {RGBColor[0.922526, 0.385626, 0.209179], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.357142857142857}, {1., 7.285714285714286}, {2., 
      9.642857142857142}, {3., 11.714285714285714`}, {4., 
      13.214285714285714`}, {5., 15.}, {6., 16.5}, {7., 
      17.714285714285715`}, {8., 19.92857142857143}, {9., 
      22.142857142857146`}, {10., 24.357142857142858`}}]}, 
    {RGBColor[0.528488, 0.470624, 0.701351], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 3.4285714285714284`}, {1., 5.142857142857143}, {2., 
      5.357142857142858}, {3., 4.285714285714286}, {4., 
      2.8571428571428568`}, {5., 1.7142857142857142`}, {6., 0.}, {
      7., -1.1428571428571428`}, {8., -2.571428571428571}, {
      9., -4.285714285714286}, {10., -5.5}}]}, 
    {RGBColor[0.772079, 0.431554, 0.102387], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.571428571428571}, {1., 8.}, {2., 10.928571428571429`}, {
      3., 13.428571428571429`}, {4., 15.357142857142858`}, {5., 
      16.714285714285715`}, {6., 17.5}, {7., 18.857142857142858`}, {8., 
      19.92857142857143}, {9., 20.714285714285715`}, {10., 
      21.214285714285715`}}]}, 
    {RGBColor[0.363898, 0.618501, 0.782349], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 3.642857142857143}, {1., 5.285714285714286}, {2., 
      5.785714285714286}, {3., 7.142857142857143}, {4., 8.214285714285714}, {
      5., 9.}, {6., 9.5}, {7., 9.714285714285714}, {8., 9.642857142857142}, {
      9., 9.285714285714286}, {10., 8.642857142857142}}]}, 
    {RGBColor[1, 0.75, 0], PointSize[0.004583333333333334], AbsoluteThickness[
     1.6], LineBox[{{0., 3.857142857142857}, {1., 5.714285714285714}, {2., 
      7.285714285714285}, {3., 8.}, {4., 7.857142857142857}, {5., 
      6.857142857142857}, {6., 5.5}, {7., 5.142857142857143}, {8., 4.5}, {9., 
      3.5714285714285716`}, {10., 2.357142857142857}}]}, 
    {RGBColor[0.647624, 0.37816, 0.614037], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.5}, {1., 7.285714285714286}, {2., 9.}, {3., 
      10.857142857142858`}, {4., 12.142857142857142`}, {5., 
      13.714285714285714`}, {6., 15.5}, {7., 17.714285714285715`}, {8., 
      19.92857142857143}, {9., 22.142857142857146`}, {10., 
      24.357142857142858`}}]}, 
    {RGBColor[0.571589, 0.586483, 0.], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 2.9285714285714284`}, {1., 4.142857142857143}, {2., 
      4.714285714285714}, {3., 4.571428571428571}, {4., 
      3.9285714285714284`}, {5., 3.}, {6., 1.5}, {7., 0.5714285714285714}, {
      8., -0.6428571428571428}, {9., -2.142857142857143}, {
      10., -3.928571428571429}}]}, 
    {RGBColor[0.915, 0.3325, 0.2125], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.428571428571429}, {1., 7.714285714285714}, {2., 
      10.285714285714285`}, {3., 12.}, {4., 13.214285714285714`}, {5., 15.}, {
      6., 16.5}, {7., 17.714285714285715`}, {8., 18.642857142857146`}, {9., 
      19.285714285714285`}, {10., 19.642857142857142`}}]}, 
    {RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], PointSize[
     0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 5.}, {1., 8.857142857142858}, {2., 12.}, {3., 
      14.285714285714286`}, {4., 15.714285714285714`}, {5., 
      16.285714285714285`}, {6., 17.}, {7., 17.142857142857142`}, {8., 
      16.714285714285715`}, {9., 16.428571428571427`}, {10., 16.5}}]}, 
    {RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
     PointSize[0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 4.928571428571429}, {1., 8.714285714285714}, {2., 
      11.785714285714285`}, {3., 14.}, {4., 15.357142857142858`}, {5., 
      15.857142857142858`}, {6., 16.}, {7., 16.}, {8., 15.428571428571427`}, {
      9., 14.285714285714286`}, {10., 12.571428571428571`}}]}, 
    {RGBColor[0.736782672705901, 0.358, 0.5030266573755369], PointSize[
     0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 4.857142857142857}, {1., 8.}, {2., 9.857142857142858}, {3.,
       11.714285714285714`}, {4., 13.928571428571427`}, {5., 
      15.857142857142858`}, {6., 17.5}, {7., 18.857142857142858`}, {8., 
      19.92857142857143}, {9., 20.714285714285715`}, {10., 
      21.214285714285715`}}]}, 
    {RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], PointSize[
     0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 4.642857142857143}, {1., 7.857142857142857}, {2., 
      9.642857142857142}, {3., 10.}, {4., 8.928571428571429}, {5., 
      7.714285714285715}, {6., 7.}, {7., 6.857142857142857}, {8., 
      6.428571428571429}, {9., 5.7142857142857135`}, {10., 
      4.714285714285714}}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 5.071428571428571}, {1., 8.714285714285714}, {2., 
      10.928571428571429`}, {3., 12.857142857142858`}, {4., 
      14.642857142857142`}, {5., 15.857142857142858`}, {6., 16.5}, {7., 
      16.571428571428573`}, {8., 16.714285714285715`}, {9., 
      17.142857142857142`}, {10., 17.285714285714285`}}]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.285714285714286}, {1., 6.857142857142857}, {2., 
      8.357142857142858}, {3., 8.857142857142858}, {4., 8.214285714285714}, {
      5., 6.428571428571429}, {6., 6.5}, {7., 6.285714285714286}, {8., 
      5.7857142857142865`}, {9., 5.}, {10., 3.928571428571429}}]}, 
    {RGBColor[0.560181, 0.691569, 0.194885], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.642857142857143}, {1., 7.428571428571429}, {2., 
      9.428571428571429}, {3., 10.285714285714286`}, {4., 10.}, {5., 
      8.571428571428571}, {6., 6.}, {7., 3.4285714285714284`}, {8., 
      1.9285714285714284`}, {9., 2.142857142857143}, {10., 
      2.357142857142857}}]}, 
    {RGBColor[0.922526, 0.385626, 0.209179], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.142857142857143}, {1., 6.571428571428571}, {2., 
      7.928571428571429}, {3., 9.142857142857142}, {4., 
      10.357142857142858`}, {5., 11.571428571428571`}, {6., 12.5}, {7., 
      13.142857142857142`}, {8., 13.5}, {9., 13.571428571428573`}, {10., 
      13.357142857142856`}}]}, 
    {RGBColor[0.528488, 0.470624, 0.701351], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 3.5}, {1., 5.285714285714286}, {2., 6.642857142857143}, {
      3., 8.}, {4., 9.285714285714286}, {5., 10.285714285714285`}, {6., 
      11.}, {7., 11.428571428571429`}, {8., 11.571428571428573`}, {9., 
      12.142857142857142`}, {10., 13.357142857142856`}}]}, 
    {RGBColor[0.772079, 0.431554, 0.102387], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.857142857142857}, {1., 8.285714285714286}, {2., 10.5}, {
      3., 11.714285714285714`}, {4., 11.785714285714286`}, {5., 
      10.714285714285715`}, {6., 9.}, {7., 8.}, {8., 6.428571428571429}, {9., 
      4.285714285714286}, {10., 1.5714285714285714`}}]}, 
    {RGBColor[0.363898, 0.618501, 0.782349], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.214285714285714}, {1., 6.714285714285714}, {2., 7.5}, {
      3., 8.}, {4., 7.857142857142857}, {5., 7.714285714285715}, {6., 9.}, {
      7., 10.285714285714286`}, {8., 11.571428571428573`}, {9., 
      12.857142857142858`}, {10., 14.142857142857144`}}]}, 
    {RGBColor[1, 0.75, 0], PointSize[0.004583333333333334], AbsoluteThickness[
     1.6], LineBox[{{0., 5.214285714285714}, {1., 9.}, {2., 
      11.571428571428571`}, {3., 13.142857142857142`}, {4., 
      13.571428571428573`}, {5., 12.857142857142858`}, {6., 11.}, {7., 8.}, {
      8., 5.142857142857142}, {9., 1.4285714285714284`}, {
      10., -0.7857142857142857}}]}, 
    {RGBColor[0.647624, 0.37816, 0.614037], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.285714285714286}, {1., 6.857142857142857}, {2., 
      8.571428571428571}, {3., 9.142857142857142}, {4., 8.571428571428571}, {
      5., 6.857142857142857}, {6., 4.5}, {7., 1.7142857142857142`}, {
      8., -0.6428571428571428}, {9., -3.5714285714285716`}, {
      10., -7.071428571428572}}]}, 
    {RGBColor[0.571589, 0.586483, 0.], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.714285714285714}, {1., 7.714285714285714}, {2., 
      9.642857142857142}, {3., 11.142857142857142`}, {4., 
      11.785714285714286`}, {5., 11.571428571428571`}, {6., 12.}, {7., 
      12.571428571428571`}, {8., 12.857142857142858`}, {9., 
      12.857142857142858`}, {10., 12.571428571428571`}}]}, 
    {RGBColor[0.915, 0.3325, 0.2125], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 5.285714285714286}, {1., 9.428571428571429}, {2., 
      12.857142857142858`}, {3., 15.428571428571429`}, {4., 
      17.142857142857142`}, {5., 18.}, {6., 18.}, {7., 17.142857142857142`}, {
      8., 15.428571428571427`}, {9., 12.857142857142858`}, {10., 
      9.428571428571429}}]}, 
    {RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], PointSize[
     0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 4.857142857142857}, {1., 8.}, {2., 9.857142857142858}, {3.,
       10.857142857142858`}, {4., 10.714285714285714`}, {5., 
      9.428571428571429}, {6., 7.5}, {7., 5.142857142857143}, {8., 4.5}, {9., 
      3.5714285714285716`}, {10., 2.357142857142857}}]}, 
    {RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
     PointSize[0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 5.142857142857143}, {1., 8.571428571428571}, {2., 
      11.357142857142858`}, {3., 14.}, {4., 16.071428571428573`}, {5., 
      17.57142857142857}, {6., 18.5}, {7., 18.857142857142858`}, {8., 
      18.642857142857146`}, {9., 18.571428571428573`}, {10., 
      18.857142857142858`}}]}, 
    {RGBColor[0.736782672705901, 0.358, 0.5030266573755369], PointSize[
     0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 4.928571428571429}, {1., 9.}, {2., 12.214285714285714`}, {
      3., 14.857142857142858`}, {4., 17.142857142857142`}, {5., 
      18.857142857142858`}, {6., 20.5}, {7., 22.285714285714285`}, {8., 
      25.07142857142857}, {9., 27.857142857142854`}, {10., 
      30.642857142857142`}}]}, 
    {RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], PointSize[
     0.004583333333333334], AbsoluteThickness[1.6], 
     LineBox[{{0., 4.642857142857143}, {1., 7.571428571428571}, {2., 
      10.071428571428571`}, {3., 12.285714285714286`}, {4., 
      13.928571428571427`}, {5., 15.}, {6., 15.5}, {7., 
      15.428571428571429`}, {8., 14.785714285714285`}, {9., 
      14.285714285714286`}, {10., 14.142857142857144`}}]}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 5.428571428571429}, {1., 9.428571428571429}, {2., 
      12.857142857142858`}, {3., 16.}, {4., 18.571428571428573`}, {5., 
      20.57142857142857}, {6., 22.}, {7., 22.857142857142858`}, {8., 
      23.142857142857146`}, {9., 22.857142857142854`}, {10., 22.}}]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.714285714285714}, {1., 8.}, {2., 10.285714285714285`}, {
      3., 11.714285714285714`}, {4., 13.214285714285714`}, {5., 
      14.142857142857142`}, {6., 14.500000000000002`}, {7., 
      14.285714285714286`}, {8., 13.5}, {9., 12.142857142857142`}, {10., 
      11.785714285714285`}}]}, 
    {RGBColor[0.560181, 0.691569, 0.194885], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 5.5}, {1., 9.571428571428571}, {2., 13.5}, {3., 
      16.857142857142858`}, {4., 19.642857142857142`}, {5., 
      21.857142857142858`}, {6., 23.5}, {7., 24.571428571428573`}, {8., 
      26.357142857142854`}, {9., 27.857142857142854`}, {10., 
      29.07142857142857}}]}, 
    {RGBColor[0.922526, 0.385626, 0.209179], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.428571428571429}, {1., 7.285714285714286}, {2., 
      9.428571428571429}, {3., 10.857142857142858`}, {4., 
      12.142857142857142`}, {5., 12.857142857142858`}, {6., 13.}, {7., 
      12.571428571428571`}, {8., 12.857142857142858`}, {9., 
      12.857142857142858`}, {10., 12.571428571428571`}}]}, 
    {RGBColor[0.528488, 0.470624, 0.701351], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.214285714285714}, {1., 6.714285714285714}, {2., 9.}, {3.,
       10.857142857142858`}, {4., 12.5}, {5., 14.142857142857142`}, {6., 
      15.5}, {7., 16.571428571428573`}, {8., 17.357142857142858`}, {9., 
      17.857142857142858`}, {10., 18.07142857142857}}]}, 
    {RGBColor[0.772079, 0.431554, 0.102387], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 5.571428571428571}, {1., 10.}, {2., 13.285714285714286`}, {
      3., 15.428571428571429`}, {4., 16.428571428571427`}, {5., 
      16.285714285714285`}, {6., 15.}, {7., 13.142857142857142`}, {8., 
      10.928571428571427`}, {9., 9.285714285714286}, {10., 
      7.071428571428572}}]}, 
    {RGBColor[0.363898, 0.618501, 0.782349], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.5}, {1., 7.571428571428571}, {2., 10.071428571428571`}, {
      3., 12.285714285714286`}, {4., 13.928571428571427`}, {5., 15.}, {6., 
      15.5}, {7., 15.428571428571429`}, {8., 14.785714285714285`}, {9., 
      14.285714285714286`}, {10., 14.142857142857144`}}]}, 
    {RGBColor[1, 0.75, 0], PointSize[0.004583333333333334], AbsoluteThickness[
     1.6], LineBox[{{0., 4.071428571428571}, {1., 6.428571428571429}, {2., 
      7.928571428571429}, {3., 8.857142857142858}, {4., 8.928571428571429}, {
      5., 9.}, {6., 8.5}, {7., 7.428571428571429}, {8., 
      5.7857142857142865`}, {9., 4.285714285714286}, {10., 
      3.142857142857143}}]}, 
    {RGBColor[0.647624, 0.37816, 0.614037], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 4.857142857142857}, {1., 8.}, {2., 10.285714285714285`}, {
      3., 11.714285714285714`}, {4., 12.5}, {5., 12.42857142857143}, {6., 
      11.5}, {7., 9.714285714285714}, {8., 7.071428571428571}, {9., 
      3.5714285714285716`}, {10., 0.7857142857142857}}]}, 
    {RGBColor[0.571589, 0.586483, 0.], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0., 3.9285714285714284`}, {1., 6.142857142857143}, {2., 
      7.285714285714285}, {3., 7.428571428571429}, {4., 6.428571428571429}, {
      5., 6.}, {6., 7.}, {7., 8.}, {8., 9.}, {9., 10.}, {10., 11.}}]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox["\"Score * Gap-Penalty\"", TraditionalForm], None}, {
     FormBox["\"Gap-Penalty\"", TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 10.}, {-12.571428571428571`, 31.60714285714286}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6775717177065687`*^9}]
}, Open  ]],

Cell["\<\
Hier zeigen sich nun erhebliche Unterschiede zwischen den Zufallssequenzen. \
Die Wirkung von Gaps auf den Alignment-Score kann also nicht durch einfache \
\[OpenCurlyQuote]Skalierung\[CloseCurlyQuote] (in diesem Fall durch die \
Multiplikation mit dem Gap-Penalty) beschrieben werden. Nach dieser Operation \
findet man lineare Anstiege dieser Gr\[ODoubleDot]\[SZ]e, ebenso wie nahezu \
konstante Verl\[ADoubleDot]ufe und nicht monotone, bei gro\[SZ]em Gap-Penalty \
abfallende Verl\[ADoubleDot]ufe.
\
\>", "Text",
 CellChangeTimes->{{3.6746363498134174`*^9, 3.674636366138441*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-Exkurs: ",
 "lokales Alignment mit dem Smith-Waterman-Verfahren"
}], "Subtitle",
 CellChangeTimes->{3.670321495640956*^9, 3.670402706588908*^9, 
  3.670402787620543*^9, 3.670403164706111*^9, 3.670404719467038*^9},
 Background->RGBColor[
  0.8705882352941177, 0.00392156862745098, 0.2196078431372549]],

Cell[TextData[{
 "Zuerst wollen wir die Rekursionsgleichung der neuen ",
 StyleBox["F",
  FontSlant->"Italic"],
 "-Matrix implementieren. Die Initialisierung erfolgt, wie wir gesehen haben, \
nun nicht mehr \[UDoubleDot]ber den Gap-Penalty, sondern \[UDoubleDot]ber \
einen Rahmen von Nullen."
}], "Text",
 CellChangeTimes->{{3.674636384006469*^9, 3.6746364166715183`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"gP", "=", "5"}], ";"}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"prot1", "=", 
   RowBox[{"Characters", "[", "\"\<KEFHNGHT\>\"", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"prot2", "=", 
    RowBox[{"Characters", "[", "\"\<KYFHKAQNGHSPT\>\"", "]"}]}], ";"}], 
  " "}]}], "Input",
 CellChangeTimes->{{3.676195684954121*^9, 3.676195686283124*^9}, {
  3.676195995254301*^9, 3.6761959961455026`*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fWaterman", "[", 
    RowBox[{"0", ",", "0"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}], ";"}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fWaterman", "[", 
    RowBox[{"i_", ",", "0"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}], ";"}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fWaterman", "[", 
    RowBox[{"0", ",", "j_"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}], ";"}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[TextData[{
 "F\[UDoubleDot]r unsere erste beispielhafte Darstellung verwenden wir \
denselben Wert des Gap-Penalty (",
 StyleBox["gP",
  FontWeight->"Bold"],
 " = 5) wie im vorangegangenen ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-Exkurs. Ebenso verwenden wir dieselbe Scoring-Matrix (abgelegt in der \
Variablen ",
 StyleBox["blosum",
  FontWeight->"Bold"],
 "), dieselben Beispielsequenzen, sowie die Funktion ",
 StyleBox["coordFun",
  FontWeight->"Bold"],
 ", die Eintr\[ADoubleDot]ge der Scoring-Matrix extrahiert. Die Rekursion \
unterscheidet sich von der Needleman-Wunsch-Vorschrift nur in der Null, die \
noch in die Maximumsabfrage eingeht. Man hat:"
}], "Text",
 CellChangeTimes->{{3.6746365248456836`*^9, 3.674636542980713*^9}, 
   3.67463657535876*^9}],

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"tmp1", "=", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"fWaterman", "[", 
           RowBox[{
            RowBox[{"i", "-", "1"}], ",", 
            RowBox[{"j", "-", "1"}]}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "+", 
         RowBox[{"coordFun", "[", 
          RowBox[{
          "proteinRef", ",", "prot1", ",", "prot2", ",", "i", ",", "j", ",", 
           "blosum"}], "]"}]}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"fWaterman", "[", 
           RowBox[{
            RowBox[{"i", "-", "1"}], ",", "j"}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "gP"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"fWaterman", "[", 
           RowBox[{"i", ",", 
            RowBox[{"j", "-", "1"}]}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "gP"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", " ", 
     RowBox[{
      RowBox[{"fWaterman", "[", 
       RowBox[{"i", ",", "j"}], "]"}], "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Max", "[", "tmp1", "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Position", "[", 
           RowBox[{"tmp1", ",", 
            RowBox[{"Max", "[", "tmp1", "]"}]}], "]"}], "[", 
          RowBox[{"[", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1"}], "]"}], "]"}], "-", "1"}]}], 
       "}"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "1", ",", 
     RowBox[{"Length", "[", "prot1", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "1", ",", 
     RowBox[{"Length", "[", "prot2", "]"}]}], "}"}]}], "]"}]], "Input"],

Cell[TextData[{
 "Dabei ist zu beachten, dass wir nun die Position in der Maximumsabfrage \
minus Eins als Zeigerzustand verwenden. Da als erster Eintrag die Null in der \
Liste zum Maximum steht, stellt diese Verschiebung die Konsistenz zu unseren \
vorangegangenen Zeigerzust\[ADoubleDot]nden her. \[CapitalUDoubleDot]ber \
dieselben Darstellungsmechanismen wie zuvor k\[ODoubleDot]nnen wir nun diese \
Matrix abbilden und die entsprechenden Zeigerzust\[ADoubleDot]nde \
einzeichnen. Das Ergebnis bildet das Ger\[UDoubleDot]st von Abb. 3.12. Um als \
N\[ADoubleDot]chstes das lokale Alignment ausgeben zu k\[ODoubleDot]nnen, m\
\[UDoubleDot]ssen wir den Anfangspunkt und die Abbruchbedingung des \
Traceback-Verfahrens implementieren. Der Anfangspunkt ist durch die Position \
des Maximums in der neuen ",
 StyleBox["F",
  FontSlant->"Italic"],
 "-Matrix gegeben. Wie zuvor legen wir die Ergebnisse in Einzeltabellen ab."
}], "Text",
 CellChangeTimes->{{3.6746366169568214`*^9, 3.6746366233218307`*^9}, {
   3.674636674245906*^9, 3.6746366878799267`*^9}, 3.677494893981167*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fWatermanTab", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"fWaterman", "[", 
      RowBox[{"i", ",", "j"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", 
       RowBox[{"Length", "[", "prot1", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "0", ",", 
       RowBox[{"Length", "[", "prot2", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fWatermanTabA", "=", 
    RowBox[{"fWatermanTab", "/.", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"n1_", ",", "n2_Integer"}], "}"}], "\[Rule]", " ", "n1"}]}]}], 
   " ", ";"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fWatermanTabB", "=", 
    RowBox[{"(", 
     RowBox[{"fWatermanTab", "/.", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"n1_", ",", "n2_Integer"}], "}"}], "\[Rule]", " ", "n2"}]}], 
     " ", ")"}]}], ";"}], " "}]], "Input"],

Cell[TextData[{
 "Die Koordinaten extrahieren wir in bew\[ADoubleDot]hrter Weise mit dem \
Befehl ",
 StyleBox["Position[matrix, Max[matrix]]",
  FontWeight->"Bold"],
 ". Ein um diese Struktur gesetzter ",
 StyleBox["Flatten",
  FontWeight->"Bold"],
 "-Befehl beseitigt \[UDoubleDot]berz\[ADoubleDot]hlige Klammern. Wir setzen \
nun die Variable ",
 StyleBox["dX",
  FontWeight->"Bold"],
 " auf diese Koordinaten und verwenden von da ab eine vollkommen analoge \
Befehlsfolge zur Pfadrekonstruktion wie im Fall des \
Needleman-Wunsch-Algorithmus."
}], "Text",
 CellChangeTimes->{{3.6746367372750025`*^9, 3.674636788934083*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dX", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Position", "[", 
     RowBox[{"fWatermanTabA", ",", 
      RowBox[{"Max", "[", "fWatermanTabA", "]"}]}], "]"}], "]"}]}], 
  ";"}]], "Input"],

Cell[TextData[{
 "Dieser Anfangspunkt (bzw. Endpunkt) des Pfads wird wie zuvor als erster \
Funktionswert von ",
 StyleBox["traX",
  FontWeight->"Bold"],
 " festgelegt:"
}], "Text",
 CellChangeTimes->{{3.6746368366941586`*^9, 3.6746368445991707`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"traX", "[", "1", "]"}], "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"dX", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{"dX", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"9", ",", "12"}], "}"}]], "Output",
 CellChangeTimes->{3.6775717177689686`*^9}]
}, Open  ]],

Cell[TextData[{
 "Zur weiteren Pfadbestimmung k\[ODoubleDot]nnen wir die ",
 StyleBox["While",
  FontWeight->"Bold"],
 "-Schleife des Needleman-Wunsch-Algorithmus exakt wiederverwenden. Dort \
hatten wir das Auffinden einer Null in der Zeigermatrix als Abbruchbedingung \
benutzt (was dort die linke obere Ecke der Matrix kennzeichnete). Durch die \
obige Zeigercodierung wissen wir, dass dies auch das Ende des Pfads im \
Smith-Waterman-Algorithmus darstellt.\n\nDieselbe Befehlsfolge (Traceback \
mithilfe einer ",
 StyleBox["While",
  FontWeight->"Bold"],
 "-Schleife, Auslesen der Zeiger entlang des Pfads, Umsetzung dieser \
Koordinaten-Zeigerzustand-Kombinationen in eine Abfolge von Grafikbefehlen) \
wie f\[UDoubleDot]r das entsprechende Resultat des \
Needleman-Wunsch-Algorithmus f\[UDoubleDot]hrt auf die in Abb. 3.12 \
angegebene Struktur. "
}], "Text",
 CellChangeTimes->{{3.674636905467262*^9, 3.6746369102582693`*^9}, {
   3.6746370187304316`*^9, 3.674637040709467*^9}, {3.674637102607564*^9, 
   3.674637115873584*^9}, {3.6746371607236633`*^9, 3.6746371688986764`*^9}, 
   3.677494930752431*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"j", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"While", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"fWatermanTabB", "[", 
     RowBox[{"[", 
      RowBox[{"Sequence", "@@", 
       RowBox[{"traX", "[", "j", "]"}]}], "]"}], "]"}], "=!=", "0"}], ",", 
   " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"traX", "[", 
       RowBox[{"j", "+", "1"}], "]"}], " ", "=", " ", 
      RowBox[{
       RowBox[{"traX", "[", "j", "]"}], "-", 
       RowBox[{"Switch", "[", 
        RowBox[{
         RowBox[{"fWatermanTabB", "[", 
          RowBox[{"[", 
           RowBox[{"Sequence", "@@", 
            RowBox[{"traX", "[", "j", "]"}]}], "]"}], "]"}], ",", "1", ",", 
         "  ", 
         RowBox[{"{", 
          RowBox[{"1", ",", "1"}], "}"}], ",", "2", ",", " ", 
         RowBox[{"{", 
          RowBox[{"1", ",", "0"}], "}"}], ",", "3", ",", " ", 
         RowBox[{"{", 
          RowBox[{"0", ",", "1"}], "}"}]}], "]"}]}]}], ",", 
     RowBox[{"j", "=", 
      RowBox[{"j", "+", "1"}]}]}], "}"}]}], "]"}]}], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"path1", " ", "=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"traX", "[", "k", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "1", ",", 
      RowBox[{"j", "-", "1"}]}], "}"}]}], "]"}]}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"9", ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", "11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7", ",", "10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", "9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "2"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6775717177845683`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"path2", " ", "=", " ", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"matFTabB", "[", 
       RowBox[{"[", 
        RowBox[{"Sequence", "@@", "#"}], "]"}], "]"}], "&"}], ",", "path1"}], 
    "]"}]}], ";"}], "\n", 
 RowBox[{"path3", " ", "=", " ", 
  RowBox[{"Map", "[", 
   RowBox[{"Flatten", ",", 
    RowBox[{"Thread", "[", 
     RowBox[{"{", 
      RowBox[{"path2", ",", "path1"}], "}"}], "]"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{3.623821093876358*^9},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "9", ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "8", ",", "11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "7", ",", "10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "6", ",", "9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "5", ",", "8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "5", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "5", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "5", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "4", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "2"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6775717178001685`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"gr3", " ", "=", " ", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"arrXXc", "[", 
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "3", "]"}], "]"}], "-", "1"}], ",", 
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "-", "1"}]}], "]"}], "&"}], ",", 
     "path3"}], "]"}]}], ";"}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"pW1", " ", "=", " ", 
   RowBox[{"Show", "[", 
    RowBox[{"Graphics", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"fWatermanTabA", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "j"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", 
           RowBox[{
            RowBox[{
             RowBox[{"Dimensions", "[", "fWatermanTabA", "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}], "-", 
            RowBox[{"(", 
             RowBox[{"i", "-", "1"}], ")"}]}]}], "}"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{
          RowBox[{"Dimensions", "[", "fWatermanTabA", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "1", ",", 
         RowBox[{
          RowBox[{"Dimensions", "[", "fWatermanTabA", "]"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "}"}]}], "]"}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.623822123796694*^9, 3.623822124040147*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pW4", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"p3", ",", "p2", ",", "pW1", ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.623822126827201*^9, 3.623822127017942*^9}, 
   3.670414266207081*^9},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 GraphicsBox[{{
    {GrayLevel[0.9], RectangleBox[{0.5, 9.5}, {14.5, 10.5}]}, {
     InsetBox["\<\" \"\>", {1, 10}], InsetBox["\<\"K\"\>", {2, 10}], 
     InsetBox["\<\"Y\"\>", {3, 10}], InsetBox["\<\"F\"\>", {4, 10}], 
     InsetBox["\<\"H\"\>", {5, 10}], InsetBox["\<\"K\"\>", {6, 10}], 
     InsetBox["\<\"A\"\>", {7, 10}], InsetBox["\<\"G\"\>", {8, 10}], 
     InsetBox["\<\"N\"\>", {9, 10}], InsetBox["\<\"G\"\>", {10, 10}], 
     InsetBox["\<\"H\"\>", {11, 10}], InsetBox["\<\"S\"\>", {12, 10}], 
     InsetBox["\<\"P\"\>", {13, 10}], InsetBox["\<\"T\"\>", {14, 10}]}}, {
    {GrayLevel[0.9], RectangleBox[{-0.5, 0.5}, {0.5, 10.5}]}, {
     InsetBox["\<\" \"\>", {0, 9}], InsetBox["\<\"K\"\>", {0, 8}], 
     InsetBox["\<\"E\"\>", {0, 7}], InsetBox["\<\"F\"\>", {0, 6}], 
     InsetBox["\<\"H\"\>", {0, 5}], InsetBox["\<\"N\"\>", {0, 4}], 
     InsetBox["\<\"G\"\>", {0, 3}], InsetBox["\<\"H\"\>", {0, 2}], 
     InsetBox["\<\"T\"\>", {0, 1}]}}, {{InsetBox["0", {1, 9}], 
     InsetBox["0", {2, 9}], InsetBox["0", {3, 9}], InsetBox["0", {4, 9}], 
     InsetBox["0", {5, 9}], InsetBox["0", {6, 9}], InsetBox["0", {7, 9}], 
     InsetBox["0", {8, 9}], InsetBox["0", {9, 9}], InsetBox["0", {10, 9}], 
     InsetBox["0", {11, 9}], InsetBox["0", {12, 9}], InsetBox["0", {13, 9}], 
     InsetBox["0", {14, 9}]}, {InsetBox["0", {1, 8}], InsetBox["5", {2, 8}], 
     InsetBox["0", {3, 8}], InsetBox["0", {4, 8}], InsetBox["0", {5, 8}], 
     InsetBox["5", {6, 8}], InsetBox["0", {7, 8}], InsetBox["1", {8, 8}], 
     InsetBox["0", {9, 8}], InsetBox["0", {10, 8}], InsetBox["0", {11, 8}], 
     InsetBox["0", {12, 8}], InsetBox["0", {13, 8}], 
     InsetBox["0", {14, 8}]}, {InsetBox["0", {1, 7}], InsetBox["1", {2, 7}], 
     InsetBox["3", {3, 7}], InsetBox["0", {4, 7}], InsetBox["0", {5, 7}], 
     InsetBox["1", {6, 7}], InsetBox["4", {7, 7}], InsetBox["2", {8, 7}], 
     InsetBox["1", {9, 7}], InsetBox["0", {10, 7}], InsetBox["0", {11, 7}], 
     InsetBox["0", {12, 7}], InsetBox["0", {13, 7}], 
     InsetBox["0", {14, 7}]}, {InsetBox["0", {1, 6}], InsetBox["0", {2, 6}], 
     InsetBox["4", {3, 6}], InsetBox["9", {4, 6}], InsetBox["4", {5, 6}], 
     InsetBox["0", {6, 6}], InsetBox["0", {7, 6}], InsetBox["1", {8, 6}], 
     InsetBox["0", {9, 6}], InsetBox["0", {10, 6}], InsetBox["0", {11, 6}], 
     InsetBox["0", {12, 6}], InsetBox["0", {13, 6}], 
     InsetBox["0", {14, 6}]}, {InsetBox["0", {1, 5}], InsetBox["0", {2, 5}], 
     InsetBox["2", {3, 5}], InsetBox["4", {4, 5}], InsetBox["17", {5, 5}], 
     InsetBox["12", {6, 5}], InsetBox["7", {7, 5}], InsetBox["2", {8, 5}], 
     InsetBox["2", {9, 5}], InsetBox["0", {10, 5}], InsetBox["8", {11, 5}], 
     InsetBox["3", {12, 5}], InsetBox["0", {13, 5}], 
     InsetBox["0", {14, 5}]}, {InsetBox["0", {1, 4}], InsetBox["0", {2, 4}], 
     InsetBox["0", {3, 4}], InsetBox["0", {4, 4}], InsetBox["12", {5, 4}], 
     InsetBox["17", {6, 4}], InsetBox["12", {7, 4}], InsetBox["7", {8, 4}], 
     InsetBox["8", {9, 4}], InsetBox["3", {10, 4}], InsetBox["3", {11, 4}], 
     InsetBox["9", {12, 4}], InsetBox["4", {13, 4}], 
     InsetBox["0", {14, 4}]}, {InsetBox["0", {1, 3}], InsetBox["0", {2, 3}], 
     InsetBox["0", {3, 3}], InsetBox["0", {4, 3}], InsetBox["7", {5, 3}], 
     InsetBox["12", {6, 3}], InsetBox["17", {7, 3}], InsetBox["12", {8, 3}], 
     InsetBox["7", {9, 3}], InsetBox["14", {10, 3}], InsetBox["9", {11, 3}], 
     InsetBox["4", {12, 3}], InsetBox["7", {13, 3}], 
     InsetBox["2", {14, 3}]}, {InsetBox["0", {1, 2}], InsetBox["0", {2, 2}], 
     InsetBox["2", {3, 2}], InsetBox["0", {4, 2}], InsetBox["8", {5, 2}], 
     InsetBox["7", {6, 2}], InsetBox["12", {7, 2}], InsetBox["17", {8, 2}], 
     InsetBox["13", {9, 2}], InsetBox["9", {10, 2}], InsetBox["22", {11, 2}], 
     InsetBox["17", {12, 2}], InsetBox["12", {13, 2}], 
     InsetBox["7", {14, 2}]}, {InsetBox["0", {1, 1}], InsetBox["0", {2, 1}], 
     InsetBox["0", {3, 1}], InsetBox["0", {4, 1}], InsetBox["3", {5, 1}], 
     InsetBox["7", {6, 1}], InsetBox["7", {7, 1}], InsetBox["12", {8, 1}], 
     InsetBox["17", {9, 1}], InsetBox["12", {10, 1}], InsetBox["17", {11, 1}],
      InsetBox["23", {12, 1}], InsetBox["18", {13, 1}], 
     InsetBox["17", {14, 1}]}}},
  PlotRange->All]], "Output",
 CellChangeTimes->{3.6775717178469687`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"arrD", "[", 
   RowBox[{"ii_", ",", "jj_"}], "]"}], ":=", " ", 
  RowBox[{"Show", "[", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"GrayLevel", "[", "0.9", "]"}], ",", 
      RowBox[{"Arrow", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0.6"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0.6"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.623822212778883*^9, 3.623822239422749*^9}, {
  3.623822352008049*^9, 3.623822356114167*^9}, {3.623823140823606*^9, 
  3.623823184289259*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"arrXX2", "[", 
   RowBox[{"ll_", ",", "i_", ",", "j_"}], "]"}], " ", ":=", " ", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"ll", "\[Equal]", "1"}], ",", 
    RowBox[{"arrA", "[", 
     RowBox[{"i", ",", "j"}], "]"}], ",", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"ll", "\[Equal]", "2"}], ",", 
      RowBox[{"arrB", "[", 
       RowBox[{"i", ",", "j"}], "]"}], ",", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"ll", "\[Equal]", "3"}], ",", 
        RowBox[{"arrC", "[", 
         RowBox[{"i", ",", "j"}], "]"}], ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"ll", "\[Equal]", "0"}], ",", 
          RowBox[{"arrD", "[", 
           RowBox[{"i", ",", "j"}], "]"}]}], "]"}]}], "]"}]}], "]"}]}], 
   "]"}]}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"arrowfield2", "[", "mat_", "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"dd1", ",", "dd2"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"dd1", " ", "=", " ", 
      RowBox[{
       RowBox[{"Dimensions", "[", "mat", "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"dd2", " ", "=", " ", 
      RowBox[{
       RowBox[{"Dimensions", "[", "mat", "]"}], "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"arrXX2", "[", 
        RowBox[{
         RowBox[{"mat", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "j"}], "]"}], "]"}], ",", 
         RowBox[{"(", 
          RowBox[{"j", "-", "1"}], ")"}], ",", 
         RowBox[{"(", 
          RowBox[{"i", "-", "1"}], ")"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "dd1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "1", ",", "dd2"}], "}"}]}], "]"}]}]}], 
   "]"}]}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"grW1", " ", "=", " ", 
   RowBox[{"arrowfield2", "[", "fWatermanTabB", "]"}]}], ";"}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pW5", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"pW4", ",", "grW1", ",", "gr3", ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.623822285860302*^9, 3.623822287890719*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 GraphicsBox[{{{
     {GrayLevel[0.9], RectangleBox[{0.5, 9.5}, {14.5, 10.5}]}, {
      InsetBox["\<\" \"\>", {1, 10}], InsetBox["\<\"K\"\>", {2, 10}], 
      InsetBox["\<\"Y\"\>", {3, 10}], InsetBox["\<\"F\"\>", {4, 10}], 
      InsetBox["\<\"H\"\>", {5, 10}], InsetBox["\<\"K\"\>", {6, 10}], 
      InsetBox["\<\"A\"\>", {7, 10}], InsetBox["\<\"G\"\>", {8, 10}], 
      InsetBox["\<\"N\"\>", {9, 10}], InsetBox["\<\"G\"\>", {10, 10}], 
      InsetBox["\<\"H\"\>", {11, 10}], InsetBox["\<\"S\"\>", {12, 10}], 
      InsetBox["\<\"P\"\>", {13, 10}], InsetBox["\<\"T\"\>", {14, 10}]}}, {
     {GrayLevel[0.9], RectangleBox[{-0.5, 0.5}, {0.5, 10.5}]}, {
      InsetBox["\<\" \"\>", {0, 9}], InsetBox["\<\"K\"\>", {0, 8}], 
      InsetBox["\<\"E\"\>", {0, 7}], InsetBox["\<\"F\"\>", {0, 6}], 
      InsetBox["\<\"H\"\>", {0, 5}], InsetBox["\<\"N\"\>", {0, 4}], 
      InsetBox["\<\"G\"\>", {0, 3}], InsetBox["\<\"H\"\>", {0, 2}], 
      InsetBox["\<\"T\"\>", {0, 1}]}}, {{InsetBox["0", {1, 9}], 
      InsetBox["0", {2, 9}], InsetBox["0", {3, 9}], InsetBox["0", {4, 9}], 
      InsetBox["0", {5, 9}], InsetBox["0", {6, 9}], InsetBox["0", {7, 9}], 
      InsetBox["0", {8, 9}], InsetBox["0", {9, 9}], InsetBox["0", {10, 9}], 
      InsetBox["0", {11, 9}], InsetBox["0", {12, 9}], InsetBox["0", {13, 9}], 
      InsetBox["0", {14, 9}]}, {InsetBox["0", {1, 8}], InsetBox["5", {2, 8}], 
      InsetBox["0", {3, 8}], InsetBox["0", {4, 8}], InsetBox["0", {5, 8}], 
      InsetBox["5", {6, 8}], InsetBox["0", {7, 8}], InsetBox["1", {8, 8}], 
      InsetBox["0", {9, 8}], InsetBox["0", {10, 8}], InsetBox["0", {11, 8}], 
      InsetBox["0", {12, 8}], InsetBox["0", {13, 8}], 
      InsetBox["0", {14, 8}]}, {InsetBox["0", {1, 7}], InsetBox["1", {2, 7}], 
      InsetBox["3", {3, 7}], InsetBox["0", {4, 7}], InsetBox["0", {5, 7}], 
      InsetBox["1", {6, 7}], InsetBox["4", {7, 7}], InsetBox["2", {8, 7}], 
      InsetBox["1", {9, 7}], InsetBox["0", {10, 7}], InsetBox["0", {11, 7}], 
      InsetBox["0", {12, 7}], InsetBox["0", {13, 7}], 
      InsetBox["0", {14, 7}]}, {InsetBox["0", {1, 6}], InsetBox["0", {2, 6}], 
      InsetBox["4", {3, 6}], InsetBox["9", {4, 6}], InsetBox["4", {5, 6}], 
      InsetBox["0", {6, 6}], InsetBox["0", {7, 6}], InsetBox["1", {8, 6}], 
      InsetBox["0", {9, 6}], InsetBox["0", {10, 6}], InsetBox["0", {11, 6}], 
      InsetBox["0", {12, 6}], InsetBox["0", {13, 6}], 
      InsetBox["0", {14, 6}]}, {InsetBox["0", {1, 5}], InsetBox["0", {2, 5}], 
      InsetBox["2", {3, 5}], InsetBox["4", {4, 5}], InsetBox["17", {5, 5}], 
      InsetBox["12", {6, 5}], InsetBox["7", {7, 5}], InsetBox["2", {8, 5}], 
      InsetBox["2", {9, 5}], InsetBox["0", {10, 5}], InsetBox["8", {11, 5}], 
      InsetBox["3", {12, 5}], InsetBox["0", {13, 5}], 
      InsetBox["0", {14, 5}]}, {InsetBox["0", {1, 4}], InsetBox["0", {2, 4}], 
      InsetBox["0", {3, 4}], InsetBox["0", {4, 4}], InsetBox["12", {5, 4}], 
      InsetBox["17", {6, 4}], InsetBox["12", {7, 4}], InsetBox["7", {8, 4}], 
      InsetBox["8", {9, 4}], InsetBox["3", {10, 4}], InsetBox["3", {11, 4}], 
      InsetBox["9", {12, 4}], InsetBox["4", {13, 4}], 
      InsetBox["0", {14, 4}]}, {InsetBox["0", {1, 3}], InsetBox["0", {2, 3}], 
      InsetBox["0", {3, 3}], InsetBox["0", {4, 3}], InsetBox["7", {5, 3}], 
      InsetBox["12", {6, 3}], InsetBox["17", {7, 3}], InsetBox["12", {8, 3}], 
      InsetBox["7", {9, 3}], InsetBox["14", {10, 3}], InsetBox["9", {11, 3}], 
      InsetBox["4", {12, 3}], InsetBox["7", {13, 3}], 
      InsetBox["2", {14, 3}]}, {InsetBox["0", {1, 2}], InsetBox["0", {2, 2}], 
      InsetBox["2", {3, 2}], InsetBox["0", {4, 2}], InsetBox["8", {5, 2}], 
      InsetBox["7", {6, 2}], InsetBox["12", {7, 2}], InsetBox["17", {8, 2}], 
      InsetBox["13", {9, 2}], InsetBox["9", {10, 2}], InsetBox["22", {11, 2}],
       InsetBox["17", {12, 2}], InsetBox["12", {13, 2}], 
      InsetBox["7", {14, 2}]}, {InsetBox["0", {1, 1}], InsetBox["0", {2, 1}], 
      InsetBox["0", {3, 1}], InsetBox["0", {4, 1}], InsetBox["3", {5, 1}], 
      InsetBox["7", {6, 1}], InsetBox["7", {7, 1}], InsetBox["12", {8, 1}], 
      InsetBox["17", {9, 1}], InsetBox["12", {10, 1}], 
      InsetBox["17", {11, 1}], InsetBox["23", {12, 1}], 
      InsetBox["18", {13, 1}], InsetBox["17", {14, 1}]}}}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {Arrowheads[Small], ArrowBox[{{1.8, 8.2}, {1.2, 8.8}}]}, 
   {Arrowheads[Small], ArrowBox[{{2.7, 8.}, {2.3, 8.}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {Arrowheads[Small], ArrowBox[{{5.8, 8.2}, {5.2, 8.8}}]}, 
   {Arrowheads[Small], ArrowBox[{{6.7, 8.}, {6.3, 8.}}]}, 
   {Arrowheads[Small], ArrowBox[{{7.8, 8.2}, {7.2, 8.8}}]}, 
   {Arrowheads[Small], ArrowBox[{{8.8, 8.2}, {8.2, 8.8}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {Arrowheads[Small], ArrowBox[{{11.8, 8.2}, {11.2, 8.8}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{1.8, 7.199999999999999}, {1.2, 7.800000000000001}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{2.8, 7.199999999999999}, {2.2, 7.800000000000001}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{4.8, 7.199999999999999}, {4.2, 7.800000000000001}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{5.8, 7.199999999999999}, {5.2, 7.800000000000001}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{6.8, 7.199999999999999}, {6.2, 7.800000000000001}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{7.8, 7.199999999999999}, {7.2, 7.800000000000001}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{8.8, 7.199999999999999}, {8.2, 7.800000000000001}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{10.8, 7.199999999999999}, {10.2, 7.800000000000001}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{11.8, 7.199999999999999}, {11.2, 7.800000000000001}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{2.8, 6.199999999999999}, {2.2, 6.800000000000001}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{3.8, 6.199999999999999}, {3.2, 6.800000000000001}}]}, 
   {Arrowheads[Small], ArrowBox[{{4.7, 6.}, {4.3, 6.}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{7.8, 6.199999999999999}, {7.2, 6.800000000000001}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{2.8, 5.199999999999999}, {2.2, 5.800000000000001}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{4, 5.199999999999999}, {4, 5.800000000000001}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{4.8, 5.199999999999999}, {4.2, 5.800000000000001}}]}, 
   {Arrowheads[Small], ArrowBox[{{5.7, 5.}, {5.3, 5.}}]}, 
   {Arrowheads[Small], ArrowBox[{{6.7, 5.}, {6.3, 5.}}]}, 
   {Arrowheads[Small], ArrowBox[{{7.7, 5.}, {7.3, 5.}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{8.8, 5.199999999999999}, {8.2, 5.800000000000001}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{10.8, 5.199999999999999}, {10.2, 5.800000000000001}}]}, 
   {Arrowheads[Small], ArrowBox[{{11.7, 5.}, {11.3, 5.}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{1.8, 4.199999999999999}, {1.2, 4.800000000000001}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{5, 4.199999999999999}, {5, 4.800000000000001}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{5.8, 4.199999999999999}, {5.2, 4.800000000000001}}]}, 
   {Arrowheads[Small], ArrowBox[{{6.7, 4.}, {6.3, 4.}}]}, 
   {Arrowheads[Small], ArrowBox[{{7.7, 4.}, {7.3, 4.}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{8.8, 4.199999999999999}, {8.2, 4.800000000000001}}]}, 
   {Arrowheads[Small], ArrowBox[{{9.7, 4.}, {9.3, 4.}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{11, 4.199999999999999}, {11, 4.800000000000001}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{11.8, 4.199999999999999}, {11.2, 4.800000000000001}}]}, 
   {Arrowheads[Small], ArrowBox[{{12.7, 4.}, {12.3, 4.}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{13.8, 4.199999999999999}, {13.2, 4.800000000000001}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{5, 3.1999999999999993`}, {5, 3.8000000000000007`}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{6, 3.1999999999999993`}, {6, 3.8000000000000007`}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{6.8, 3.1999999999999993`}, {6.2, 3.8000000000000007`}}]}, 
   {Arrowheads[Small], ArrowBox[{{7.7, 3.}, {7.3, 3.}}]}, 
   {Arrowheads[Small], ArrowBox[{{8.7, 3.}, {8.3, 3.}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{9.8, 3.1999999999999993`}, {9.2, 3.8000000000000007`}}]}, 
   {Arrowheads[Small], ArrowBox[{{10.7, 3.}, {10.3, 3.}}]}, 
   {Arrowheads[Small], ArrowBox[{{11.7, 3.}, {11.3, 3.}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{12.8, 3.1999999999999993`}, {12.2, 3.8000000000000007`}}]}, 
   {Arrowheads[Small], ArrowBox[{{13.7, 3.}, {13.3, 3.}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{2.8, 2.1999999999999993`}, {2.2, 2.8000000000000007`}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{4.8, 2.1999999999999993`}, {4.2, 2.8000000000000007`}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{6, 2.1999999999999993`}, {6, 2.8000000000000007`}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{7, 2.1999999999999993`}, {7, 2.8000000000000007`}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{7.8, 2.1999999999999993`}, {7.2, 2.8000000000000007`}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{8.8, 2.1999999999999993`}, {8.2, 2.8000000000000007`}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{10, 2.1999999999999993`}, {10, 2.8000000000000007`}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{10.8, 2.1999999999999993`}, {10.2, 2.8000000000000007`}}]}, 
   {Arrowheads[Small], ArrowBox[{{11.7, 2.}, {11.3, 2.}}]}, 
   {Arrowheads[Small], ArrowBox[{{12.7, 2.}, {12.3, 2.}}]}, 
   {Arrowheads[Small], ArrowBox[{{13.7, 2.}, {13.3, 2.}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {GrayLevel[0.9], ArrowBox[{{0, 0.6}, {0, 0.6}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{3.8, 1.1999999999999993`}, {3.2, 1.8000000000000007`}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{5, 1.1999999999999993`}, {5, 1.8000000000000007`}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{5.8, 1.1999999999999993`}, {5.2, 1.8000000000000007`}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{7, 1.1999999999999993`}, {7, 1.8000000000000007`}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{8, 1.1999999999999993`}, {8, 1.8000000000000007`}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{8.8, 1.1999999999999993`}, {8.2, 1.8000000000000007`}}]}, 
   {Arrowheads[Small], ArrowBox[{{9.7, 1.}, {9.3, 1.}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{11, 1.1999999999999993`}, {11, 1.8000000000000007`}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{11.8, 1.1999999999999993`}, {11.2, 1.8000000000000007`}}]}, 
   {Arrowheads[Small], ArrowBox[{{12.7, 1.}, {12.3, 1.}}]}, 
   {Arrowheads[Small], 
    ArrowBox[{{13.8, 1.1999999999999993`}, {13.2, 1.8000000000000007`}}]}, 
   {RGBColor[1, 0, 0], AbsoluteThickness[2], Arrowheads[Small], 
    ArrowBox[{{11.8, 1.1999999999999993`}, {11.2, 1.8000000000000007`}}]}, 
   {RGBColor[1, 0, 0], AbsoluteThickness[2], Arrowheads[Small], 
    ArrowBox[{{10.8, 2.1999999999999993`}, {10.2, 2.8000000000000007`}}]}, 
   {RGBColor[1, 0, 0], AbsoluteThickness[2], Arrowheads[Small], 
    ArrowBox[{{9.8, 3.1999999999999993`}, {9.2, 3.8000000000000007`}}]}, 
   {RGBColor[1, 0, 0], AbsoluteThickness[2], Arrowheads[Small], 
    ArrowBox[{{8.8, 4.199999999999999}, {8.2, 4.800000000000001}}]}, 
   {RGBColor[1, 0, 0], AbsoluteThickness[2], Arrowheads[Small], 
    ArrowBox[{{7.7, 5.}, {7.3, 5.}}]}, 
   {RGBColor[1, 0, 0], AbsoluteThickness[2], Arrowheads[Small], 
    ArrowBox[{{6.7, 5.}, {6.3, 5.}}]}, 
   {RGBColor[1, 0, 0], AbsoluteThickness[2], Arrowheads[Small], 
    ArrowBox[{{5.7, 5.}, {5.3, 5.}}]}, 
   {RGBColor[1, 0, 0], AbsoluteThickness[2], Arrowheads[Small], 
    ArrowBox[{{4.8, 5.199999999999999}, {4.2, 5.800000000000001}}]}, 
   {RGBColor[1, 0, 0], AbsoluteThickness[2], Arrowheads[Small], 
    ArrowBox[{{3.8, 6.199999999999999}, {3.2, 6.800000000000001}}]}, 
   {RGBColor[1, 0, 0], AbsoluteThickness[2], Arrowheads[Small], 
    ArrowBox[{{2.8, 7.199999999999999}, {2.2, 7.800000000000001}}]}, 
   {RGBColor[1, 0, 0], AbsoluteThickness[2], Arrowheads[Small], 
    ArrowBox[{{1.8, 8.2}, {1.2, 8.8}}]}},
  PlotRange->All]], "Output",
 CellChangeTimes->{3.677571717956169*^9}]
}, Open  ]],

Cell[TextData[{
 "Auch f\[UDoubleDot]r die Ausgabe des lokalen Alignments auf der \
Sequenzebene k\[ODoubleDot]nnten wir im Prinzip die Befehlsstruktur des \
Needleman-Wunsch-Algorithmus nutzen. Wir wollen hier stattdessen die Ausgabe \
\[UDoubleDot]ber eine Do-Schleife realisieren, die bis zur L\[ADoubleDot]nge \
des rekonstruierten Pfads, ",
 StyleBox["Length[path2]",
  FontWeight->"Bold"],
 ", l\[ADoubleDot]uft. Die Variable ",
 StyleBox["path2",
  FontWeight->"Bold"],
 " enth\[ADoubleDot]lt die Abfolge der Zeigerzust\[ADoubleDot]nde entlang des \
Pfads. Sie ergibt sich durch Anwenden (",
 StyleBox["Map",
  FontWeight->"Bold"],
 ") der Matrix ",
 StyleBox["fWatermanTabB",
  FontWeight->"Bold"],
 " auf den Pfad ",
 StyleBox["path1",
  FontWeight->"Bold"],
 ". Die einzige Schwierigkeit bei diesem Schritt stellt die Initialisierung \
der beiden Counter-Variablen dar, mit der wir die aktuelle Position in den \
beiden Sequenzen protokollieren. Wir behalten die Z\[ADoubleDot]hlweise \
\[OpenCurlyQuote]von hinten nach vorne\[CloseCurlyQuote] des \
Needleman-Wunsch-Algorithmus bei (die man daran erkennt, dass wir den Counter \
hochz\[ADoubleDot]hlen, aber die Sequenz stets von hinten her abfragen: ",
 StyleBox["prot1[[-count1]]",
  FontWeight->"Bold"],
 "). Wir initialisieren also z.B. den ersten Counter als \
Sequenzl\[ADoubleDot]nge + 1 - erste Koordinate des Pfadbeginns. Die \
Koordinaten des Pfadbeginns extrahieren wir aus der Variablen ",
 StyleBox["path3",
  FontWeight->"Bold"],
 ", einer Liste, deren Eintr\[ADoubleDot]ge die Form Zeigerzustand, erste \
Koordinate, zweite Koordinate besitzen."
}], "Text",
 CellChangeTimes->{
  3.674637124618599*^9, {3.6746371827866983`*^9, 3.674637193438715*^9}, 
   3.6774949494120646`*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"count1", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Length", "[", "prot1", "]"}], "+", "1"}], ")"}], "-", 
    RowBox[{
     RowBox[{"path3", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "[", 
     RowBox[{"[", "2", "]"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"count2", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Length", "[", "prot2", "]"}], "+", "1"}], ")"}], "-", 
    RowBox[{
     RowBox[{"path3", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "[", 
     RowBox[{"[", "3", "]"}], "]"}]}]}], ";"}]}], "Input"],

Cell[TextData[{
 "Nach diesen Vorbereitungen k\[ODoubleDot]nnen wir die ",
 StyleBox["Do",
  FontWeight->"Bold"],
 "-Schleife nach dem Vorbild der ",
 StyleBox["While",
  FontWeight->"Bold"],
 "-Schleife des vorangegangenen Algorithmus formulieren:"
}], "Text",
 CellChangeTimes->{{3.6746372014797263`*^9, 3.67463722922777*^9}}],

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"path2", "[", 
       RowBox[{"[", "j", "]"}], "]"}], "\[Equal]", "1"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"count1", "=", 
        RowBox[{"count1", "+", "1"}]}], ",", 
       RowBox[{"count2", "=", 
        RowBox[{"count2", "+", "1"}]}], ",", 
       RowBox[{
        RowBox[{"aligW", "[", "j", "]"}], "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"prot1", "[", 
           RowBox[{"[", 
            RowBox[{"-", "count1"}], "]"}], "]"}], ",", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"prot1", "[", 
              RowBox[{"[", 
               RowBox[{"-", "count1"}], "]"}], "]"}], "==", 
             RowBox[{"prot2", "[", 
              RowBox[{"[", 
               RowBox[{"-", "count2"}], "]"}], "]"}]}], ",", "\"\<|\>\"", 
            ",", "\"\< \>\""}], "]"}], ",", 
          RowBox[{"prot2", "[", 
           RowBox[{"[", 
            RowBox[{"-", "count2"}], "]"}], "]"}]}], "}"}]}]}], "}"}], ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"path2", "[", 
         RowBox[{"[", "j", "]"}], "]"}], "\[Equal]", "2"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"count1", "=", 
          RowBox[{"count1", "+", "1"}]}], ",", 
         RowBox[{
          RowBox[{"aligW", "[", "j", "]"}], "=", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"prot1", "[", 
             RowBox[{"[", 
              RowBox[{"-", "count1"}], "]"}], "]"}], ",", "\"\< \>\"", ",", 
            "\"\<-\>\""}], "}"}]}]}], "}"}], ",", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"path2", "[", 
           RowBox[{"[", "j", "]"}], "]"}], "\[Equal]", "3"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"count2", "=", 
            RowBox[{"count2", " ", "+", "1"}]}], ",", 
           RowBox[{
            RowBox[{"aligW", "[", "j", "]"}], "=", 
            RowBox[{"{", 
             RowBox[{"\"\<-\>\"", ",", "\"\< \>\"", ",", 
              RowBox[{"prot2", "[", 
               RowBox[{"[", 
                RowBox[{"-", "count2"}], "]"}], "]"}]}], "}"}]}]}], "}"}]}], 
        "]"}]}], "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "1", ",", 
     RowBox[{"Length", "[", "path2", "]"}]}], "}"}]}], "]"}]], "Input"],

Cell[TextData[{
 "Zur Ausgabe fragen wir die Eintr\[ADoubleDot]ge in ",
 StyleBox["aligW",
  FontWeight->"Bold"],
 " wieder in umgekehrter Reihenfolge ab und geben sie mit dem Formatbefehl ",
 StyleBox["TableForm",
  FontWeight->"Bold"],
 " aus:"
}], "Text",
 CellChangeTimes->{{3.674637250682803*^9, 3.6746372795048475`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"alWFull", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"aligW", "[", "j", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", 
       RowBox[{"Length", "[", "path2", "]"}], ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Transpose", "[", "alWFull", "]"}], "//", "TableForm"}]}], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"K\"\>", "\<\"E\"\>", "\<\"F\"\>", "\<\"H\"\>", "\<\"-\"\>", \
"\<\"-\"\>", "\<\"-\"\>", "\<\"N\"\>", "\<\"G\"\>", "\<\"H\"\>", "\<\"T\"\>"},
    {"\<\"|\"\>", "\<\" \"\>", "\<\"|\"\>", "\<\"|\"\>", "\<\" \"\>", "\<\" \
\"\>", "\<\" \"\>", "\<\"|\"\>", "\<\"|\"\>", "\<\"|\"\>", "\<\" \"\>"},
    {"\<\"K\"\>", "\<\"Y\"\>", "\<\"F\"\>", "\<\"H\"\>", "\<\"K\"\>", \
"\<\"A\"\>", "\<\"Q\"\>", "\<\"N\"\>", "\<\"G\"\>", "\<\"H\"\>", "\<\"S\"\>"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.6775717179873686`*^9}]
}, Open  ]],

Cell[TextData[{
 "Dies ist das Endresultat f\[UDoubleDot]r das lokale Alignment gem\
\[ADoubleDot]\[SZ] dem Smith-Waterman-Algorithmus. Auch hier wollen wir die \
einzelnen Befehle so in einer Module-Umgebung zusammenf\[UDoubleDot]gen, dass \
man ein kompaktes Werkzeug zur Verf\[UDoubleDot]gung hat. Man hat dann einen \
Befehl ",
 StyleBox["alignmentSW",
  FontWeight->"Bold"],
 " mit denselben Argumenten wie beim Needleman-Wunsch-Algorithmus."
}], "Text",
 CellChangeTimes->{{3.6746373488469505`*^9, 3.6746373632669744`*^9}, {
  3.6746374069990435`*^9, 3.674637408732046*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"xxcoordFun", "[", 
    RowBox[{
    "ref_", ",", "seq1_", ",", "seq2_", ",", "posA_", ",", "posB_", ",", 
     "mat_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"tmp1", ",", "tmp2", ",", "tmp3", ",", "tmp4"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"tmp1", "=", 
       RowBox[{"seq1", "[", 
        RowBox[{"[", "posA", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"tmp2", "=", 
       RowBox[{"seq2", "[", 
        RowBox[{"[", "posB", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"tmp3", "=", 
       RowBox[{
        RowBox[{"Position", "[", 
         RowBox[{"ref", ",", "tmp1"}], "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"tmp4", "=", 
       RowBox[{
        RowBox[{"Position", "[", 
         RowBox[{"ref", ",", "tmp2"}], "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"mat", "[", 
       RowBox[{"[", 
        RowBox[{"tmp3", ",", "tmp4"}], "]"}], "]"}]}]}], "]"}]}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"alignmentSW", "[", 
   RowBox[{"seq1_", ",", "seq2_", ",", "mat_", ",", "del_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "xxproteinRef", ",", "xxfWaterman", ",", "xxfWatermanTab", ",", "xxtmp1",
       ",", "j", ",", "xxfWatermanTabA", ",", "xxfWatermanTabB", ",", "xxdX", 
      ",", "xxtraX", ",", "xxpath1", ",", "xxpath2", ",", "xxcount1", ",", 
      "xxcount2", ",", "xxalig", ",", "xxalFull"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"xxproteinRef", "=", 
      RowBox[{"Characters", "[", "\"\<ARNDCQEGHILKMFPSTWYVBZX*\>\"", "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"xxfWaterman", "[", 
       RowBox[{"0", ",", "0"}], "]"}], "=", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"xxfWaterman", "[", 
       RowBox[{"i_", ",", "0"}], "]"}], "=", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"xxfWaterman", "[", 
       RowBox[{"0", ",", "j_"}], "]"}], "=", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"xxtmp1", "=", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{
             RowBox[{
              RowBox[{"xxfWaterman", "[", 
               RowBox[{
                RowBox[{"i", "-", "1"}], ",", 
                RowBox[{"j", "-", "1"}]}], "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}], "+", 
             RowBox[{"xxcoordFun", "[", 
              RowBox[{
              "xxproteinRef", ",", "seq1", ",", "seq2", ",", "i", ",", "j", 
               ",", "mat"}], "]"}]}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"xxfWaterman", "[", 
               RowBox[{
                RowBox[{"i", "-", "1"}], ",", "j"}], "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}], "-", "del"}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"xxfWaterman", "[", 
               RowBox[{"i", ",", 
                RowBox[{"j", "-", "1"}]}], "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}], "-", "del"}]}], "}"}]}], ";", 
         RowBox[{
          RowBox[{"xxfWaterman", "[", 
           RowBox[{"i", ",", "j"}], "]"}], "=", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Max", "[", "xxtmp1", "]"}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Position", "[", 
               RowBox[{"xxtmp1", ",", 
                RowBox[{"Max", "[", "xxtmp1", "]"}]}], "]"}], "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", "1"}]}], "}"}]}]}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", "seq1", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "1", ",", 
         RowBox[{"Length", "[", "seq2", "]"}]}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"xxfWatermanTab", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"xxfWaterman", "[", 
         RowBox[{"i", ",", "j"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", 
          RowBox[{"Length", "[", "seq1", "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "0", ",", 
          RowBox[{"Length", "[", "seq2", "]"}]}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"xxfWatermanTabA", "=", 
      RowBox[{"xxfWatermanTab", "/.", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"n1_", ",", "n2_Integer"}], "}"}], "\[Rule]", "n1"}]}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"xxfWatermanTabB", "=", 
      RowBox[{"xxfWatermanTab", "/.", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"n1_", ",", "n2_Integer"}], "}"}], "\[Rule]", "n2"}]}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"xxdX", "=", 
      RowBox[{"Take", "[", 
       RowBox[{
        RowBox[{"Flatten", "[", 
         RowBox[{"Position", "[", 
          RowBox[{"xxfWatermanTabA", ",", 
           RowBox[{"Max", "[", "xxfWatermanTabA", "]"}]}], "]"}], "]"}], ",", 
        "2"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"xxtraX", "[", "1", "]"}], "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"xxdX", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{"xxdX", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"j", "=", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"xxfWatermanTabB", "[", 
         RowBox[{"[", 
          RowBox[{"Sequence", "@@", 
           RowBox[{"xxtraX", "[", "j", "]"}]}], "]"}], "]"}], "=!=", "0"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"xxtraX", "[", 
           RowBox[{"j", "+", "1"}], "]"}], "=", 
          RowBox[{
           RowBox[{"xxtraX", "[", "j", "]"}], "-", 
           RowBox[{"Switch", "[", 
            RowBox[{
             RowBox[{"xxfWatermanTabB", "[", 
              RowBox[{"[", 
               RowBox[{"Sequence", "@@", 
                RowBox[{"xxtraX", "[", "j", "]"}]}], "]"}], "]"}], ",", "1", 
             ",", 
             RowBox[{"{", 
              RowBox[{"1", ",", "1"}], "}"}], ",", "2", ",", 
             RowBox[{"{", 
              RowBox[{"1", ",", "0"}], "}"}], ",", "3", ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "1"}], "}"}]}], "]"}]}]}], ",", 
         RowBox[{"j", "=", 
          RowBox[{"j", "+", "1"}]}]}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"xxpath1", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"xxtraX", "[", "k", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "1", ",", 
          RowBox[{"j", "-", "1"}]}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"xxpath2", "=", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"xxfWatermanTabB", "[", 
          RowBox[{"[", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}], "&"}], ",", 
        "xxpath1"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"xxcount1", "=", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Length", "[", "seq1", "]"}], "+", "1"}], ")"}], "-", 
       RowBox[{
        RowBox[{"xxpath1", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"xxcount2", "=", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Length", "[", "seq2", "]"}], "+", "1"}], ")"}], "-", 
       RowBox[{
        RowBox[{"xxpath1", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"xxpath2", "[", 
           RowBox[{"[", "j", "]"}], "]"}], "\[Equal]", "1"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"xxcount1", "=", 
            RowBox[{"xxcount1", "+", "1"}]}], ",", 
           RowBox[{"xxcount2", "=", 
            RowBox[{"xxcount2", "+", "1"}]}], ",", 
           RowBox[{
            RowBox[{"xxalig", "[", "j", "]"}], "=", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"seq1", "[", 
               RowBox[{"[", 
                RowBox[{"-", "xxcount1"}], "]"}], "]"}], ",", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"seq1", "[", 
                  RowBox[{"[", 
                   RowBox[{"-", "xxcount1"}], "]"}], "]"}], "\[Equal]", 
                 RowBox[{"seq2", "[", 
                  RowBox[{"[", 
                   RowBox[{"-", "xxcount2"}], "]"}], "]"}]}], ",", 
                "\"\<|\>\"", ",", "\"\< \>\""}], "]"}], ",", 
              RowBox[{"seq2", "[", 
               RowBox[{"[", 
                RowBox[{"-", "xxcount2"}], "]"}], "]"}]}], "}"}]}]}], "}"}], 
         ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"xxpath2", "[", 
             RowBox[{"[", "j", "]"}], "]"}], "\[Equal]", "2"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"xxcount1", "=", 
              RowBox[{"xxcount1", "+", "1"}]}], ",", 
             RowBox[{
              RowBox[{"xxalig", "[", "j", "]"}], "=", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"seq1", "[", 
                 RowBox[{"[", 
                  RowBox[{"-", "xxcount1"}], "]"}], "]"}], ",", "\"\< \>\"", 
                ",", "\"\<-\>\""}], "}"}]}]}], "}"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"xxpath2", "[", 
               RowBox[{"[", "j", "]"}], "]"}], "\[Equal]", "3"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"xxcount2", "=", 
                RowBox[{"xxcount2", "+", "1"}]}], ",", 
               RowBox[{
                RowBox[{"xxalig", "[", "j", "]"}], "=", 
                RowBox[{"{", 
                 RowBox[{"\"\<-\>\"", ",", "\"\< \>\"", ",", 
                  RowBox[{"seq2", "[", 
                   RowBox[{"[", 
                    RowBox[{"-", "xxcount2"}], "]"}], "]"}]}], "}"}]}]}], 
              "}"}]}], "]"}]}], "]"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "1", ",", 
         RowBox[{"Length", "[", "xxpath2", "]"}]}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"xxalFull", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"xxalig", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "xxpath2", "]"}], ",", "1", ",", 
          RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Transpose", "[", "xxalFull", "]"}], "//", "TableForm"}]}]}], 
   "]"}]}]}], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell["\<\
Der folgende Befehl reproduziert also unser zuvor gewonnenes lokales \
Alignment:\
\>", "Text",
 CellChangeTimes->{{3.6746374200940647`*^9, 3.674637441870097*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"alignmentSW", "[", 
  RowBox[{"prot1", ",", "prot2", ",", "blosum", ",", "5"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"K\"\>", "\<\"E\"\>", "\<\"F\"\>", "\<\"H\"\>", "\<\"-\"\>", \
"\<\"-\"\>", "\<\"-\"\>", "\<\"N\"\>", "\<\"G\"\>", "\<\"H\"\>", "\<\"T\"\>"},
    {"\<\"|\"\>", "\<\" \"\>", "\<\"|\"\>", "\<\"|\"\>", "\<\" \"\>", "\<\" \
\"\>", "\<\" \"\>", "\<\"|\"\>", "\<\"|\"\>", "\<\"|\"\>", "\<\" \"\>"},
    {"\<\"K\"\>", "\<\"Y\"\>", "\<\"F\"\>", "\<\"H\"\>", "\<\"K\"\>", \
"\<\"A\"\>", "\<\"Q\"\>", "\<\"N\"\>", "\<\"G\"\>", "\<\"H\"\>", "\<\"S\"\>"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.677571718034169*^9}]
}, Open  ]],

Cell["\<\
In bew\[ADoubleDot]hrter Weise k\[ODoubleDot]nnen wir nun auch betrachten, \
wie sich das Alignment unter Variation des Gap-Parameters \[ADoubleDot]ndert.\
\>", "Text",
 CellChangeTimes->{{3.674637451642112*^9, 3.6746374810741568`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"alignmentSW", "[", 
  RowBox[{"prot1", ",", "prot2", ",", "blosum", ",", "1"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"K\"\>", "\<\"E\"\>", "\<\"F\"\>", "\<\"H\"\>", "\<\"-\"\>", \
"\<\"-\"\>", "\<\"-\"\>", "\<\"N\"\>", "\<\"G\"\>", "\<\"H\"\>", "\<\"-\"\>", \
"\<\"-\"\>", "\<\"T\"\>"},
    {"\<\"|\"\>", "\<\" \"\>", "\<\"|\"\>", "\<\"|\"\>", "\<\" \"\>", "\<\" \
\"\>", "\<\" \"\>", "\<\"|\"\>", "\<\"|\"\>", "\<\"|\"\>", "\<\" \"\>", "\<\" \
\"\>", "\<\"|\"\>"},
    {"\<\"K\"\>", "\<\"Y\"\>", "\<\"F\"\>", "\<\"H\"\>", "\<\"K\"\>", \
"\<\"A\"\>", "\<\"Q\"\>", "\<\"N\"\>", "\<\"G\"\>", "\<\"H\"\>", "\<\"S\"\>", \
"\<\"P\"\>", "\<\"T\"\>"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.677571718049769*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"alignmentSW", "[", 
  RowBox[{"prot1", ",", "prot2", ",", "blosum", ",", "15"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"N\"\>", "\<\"G\"\>", "\<\"H\"\>", "\<\"T\"\>"},
    {"\<\"|\"\>", "\<\"|\"\>", "\<\"|\"\>", "\<\" \"\>"},
    {"\<\"N\"\>", "\<\"G\"\>", "\<\"H\"\>", "\<\"S\"\>"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.677571718080969*^9}]
}, Open  ]],

Cell["\<\
In einer Hinsicht ist die bisher erzeugte Ausgabe des lokalen Alignments \
unbefriedigend. In vielen F\[ADoubleDot]llen (vor allem f\[UDoubleDot]r kurze \
Sequenzsegmente, bei denen dadurch die \[CapitalUDoubleDot]bersichtlichkeit \
der Darstellung nicht leidet) m\[ODoubleDot]chte man die nicht in Alignment \
gebrachten Sequenzbereiche an den Enden der Sequenzen ebenfalls sichtbar \
machen.\
\>", "Text",
 CellChangeTimes->{{3.674637660801426*^9, 3.6746377162865124`*^9}, {
  3.677565588332404*^9, 3.677565591234009*^9}}],

Cell[TextData[{
 StyleBox["Diesen Teil der Ergebnisausgabe wollen wir nun in Angriff nehmen. \
Zur Bestimmung der Restsequenzen verwenden wir die Initialisierungen der \
Counter-Variablen und die Counter-Werte nach Durchlauf der ",
  FontColor->GrayLevel[0]],
 StyleBox["Do",
  FontWeight->"Bold",
  FontColor->GrayLevel[0]],
 StyleBox["-Schleife. Einsetzen dieser Grenzen (unter \
Ber\[UDoubleDot]cksichtigung der umgekehrten Leserichtung!) in entsprechende ",
  FontColor->GrayLevel[0]],
 StyleBox["Take",
  FontWeight->"Bold",
  FontColor->GrayLevel[0]],
 StyleBox["-Befehle f\[UDoubleDot]hrt unmittelbar auf die gesuchten Segmente: \
",
  FontColor->GrayLevel[0]]
}], "Text",
 CellChangeTimes->{{3.677565594463215*^9, 3.6775656107808433`*^9}},
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"initCount1", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Length", "[", "prot1", "]"}], "+", "1"}], ")"}], "-", 
    RowBox[{
     RowBox[{"path3", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "[", 
     RowBox[{"[", "2", "]"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"initCount2", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Length", "[", "prot2", "]"}], "+", "1"}], ")"}], "-", 
    RowBox[{
     RowBox[{"path3", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "[", 
     RowBox[{"[", "3", "]"}], "]"}]}]}], ";"}]}], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"initCount1", ",", "initCount2", ",", "count1", ",", "count2"}], 
  "}"}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "2", ",", "8", ",", "13"}], "}"}]], "Output",
 CellChangeTimes->{3.677571718096569*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"end1", "=", 
  RowBox[{"Take", "[", 
   RowBox[{"prot1", ",", 
    RowBox[{"-", "initCount1"}]}], "]"}]}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output",
 CellChangeTimes->{3.6775717181121693`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"end2", "=", 
  RowBox[{"Take", "[", 
   RowBox[{"prot2", ",", 
    RowBox[{"-", "initCount2"}]}], "]"}]}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"P\"\>", ",", "\<\"T\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.6775717181121693`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"start1", "=", 
  RowBox[{"Take", "[", 
   RowBox[{"prot1", ",", 
    RowBox[{
     RowBox[{"Length", "[", "prot1", "]"}], "-", "count1"}]}], 
   "]"}]}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output",
 CellChangeTimes->{3.6775717181277695`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"start2", "=", 
  RowBox[{"Take", "[", 
   RowBox[{"prot2", ",", 
    RowBox[{
     RowBox[{"Length", "[", "prot2", "]"}], "-", "count2"}]}], 
   "]"}]}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output",
 CellChangeTimes->{3.677571718143369*^9}]
}, Open  ]],

Cell[TextData[{
 "Da es vergleichsweise schwierig ist, an eine gegebene Tabelle (unser \
lokales Alignment) unter Beibehaltung der Struktur Elementgruppen an den R\
\[ADoubleDot]ndern anzuf\[UDoubleDot]gen, gehen wir erneut den Umweg, die \
Tabelle in eine Grafik umzuwandeln, indem wir die \
Tabelleneintr\[ADoubleDot]ge mit Hilfe des ",
 StyleBox["Text",
  FontWeight->"Bold"],
 "-Befehls als Zeichen an den entsprechenden Koordinaten eintragen. Dies \
geschieht in Grafik ",
 StyleBox["pX1",
  FontWeight->"Bold"],
 ". Die Grafik ",
 StyleBox["pX2",
  FontWeight->"Bold"],
 " unterlegt ",
 StyleBox["pX1",
  FontWeight->"Bold"],
 " mit einem hellgrauen Kasten; dadurch wird unter anderem eine implizite \
Skalierung der Tabelle erreicht. "
}], "Text",
 CellChangeTimes->{{3.674637739718547*^9, 3.6746377493155613`*^9}, 
   3.674637779988608*^9},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"dim1", ",", "dim2"}], "}"}], "=", 
  RowBox[{"Dimensions", "[", "alWFull", "]"}]}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"11", ",", "3"}], "}"}]], "Output",
 CellChangeTimes->{3.677571718143369*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pX1", "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"Graphics", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"StyleForm", "[", 
           RowBox[{
            RowBox[{"alWFull", "[", 
             RowBox[{"[", 
              RowBox[{"i", ",", "j"}], "]"}], "]"}], ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
            RowBox[{"FontWeight", "\[Rule]", "Bold"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"dim2", "-", "j"}]}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "dim1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "1", ",", "dim2"}], "}"}]}], "]"}], "]"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pX2", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"Graphics", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"GrayLevel", "[", "0.9", "]"}], ",", 
       RowBox[{"Rectangle", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "4"}], ",", 
           RowBox[{"-", "2"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"dim1", "+", "9"}], ",", 
           RowBox[{"dim2", "+", "1"}]}], "}"}]}], "]"}]}], "}"}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"pX2", ",", "pX1"}], "]"}]}], "Input",
 CellChangeTimes->{{3.623822470963595*^9, 3.6238224784095583`*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0.9], RectangleBox[{-4, -2}, {20, 4}]}, {{InsetBox[
      TagBox[
       StyleBox["\<\"K\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {1, 2}], InsetBox[
      TagBox[
       StyleBox["\<\"|\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {1, 1}], InsetBox[
      TagBox[
       StyleBox["\<\"K\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {1, 0}]}, {InsetBox[
      TagBox[
       StyleBox["\<\"E\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {2, 2}], InsetBox[
      TagBox[
       StyleBox["\<\" \"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {2, 1}], InsetBox[
      TagBox[
       StyleBox["\<\"Y\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {2, 0}]}, {InsetBox[
      TagBox[
       StyleBox["\<\"F\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {3, 2}], InsetBox[
      TagBox[
       StyleBox["\<\"|\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {3, 1}], InsetBox[
      TagBox[
       StyleBox["\<\"F\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {3, 0}]}, {InsetBox[
      TagBox[
       StyleBox["\<\"H\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {4, 2}], InsetBox[
      TagBox[
       StyleBox["\<\"|\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {4, 1}], InsetBox[
      TagBox[
       StyleBox["\<\"H\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {4, 0}]}, {InsetBox[
      TagBox[
       StyleBox["\<\"-\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {5, 2}], InsetBox[
      TagBox[
       StyleBox["\<\" \"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {5, 1}], InsetBox[
      TagBox[
       StyleBox["\<\"K\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {5, 0}]}, {InsetBox[
      TagBox[
       StyleBox["\<\"-\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {6, 2}], InsetBox[
      TagBox[
       StyleBox["\<\" \"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {6, 1}], InsetBox[
      TagBox[
       StyleBox["\<\"A\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {6, 0}]}, {InsetBox[
      TagBox[
       StyleBox["\<\"-\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {7, 2}], InsetBox[
      TagBox[
       StyleBox["\<\" \"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {7, 1}], InsetBox[
      TagBox[
       StyleBox["\<\"Q\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {7, 0}]}, {InsetBox[
      TagBox[
       StyleBox["\<\"N\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {8, 2}], InsetBox[
      TagBox[
       StyleBox["\<\"|\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {8, 1}], InsetBox[
      TagBox[
       StyleBox["\<\"N\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {8, 0}]}, {InsetBox[
      TagBox[
       StyleBox["\<\"G\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {9, 2}], InsetBox[
      TagBox[
       StyleBox["\<\"|\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {9, 1}], InsetBox[
      TagBox[
       StyleBox["\<\"G\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {9, 0}]}, {InsetBox[
      TagBox[
       StyleBox["\<\"H\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {10, 2}], InsetBox[
      TagBox[
       StyleBox["\<\"|\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {10, 1}], InsetBox[
      TagBox[
       StyleBox["\<\"H\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {10, 0}]}, {InsetBox[
      TagBox[
       StyleBox["\<\"T\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {11, 2}], InsetBox[
      TagBox[
       StyleBox["\<\" \"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {11, 1}], InsetBox[
      TagBox[
       StyleBox["\<\"S\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {11, 0}]}}}]], "Output",
 CellChangeTimes->{3.677571718174569*^9}]
}, Open  ]],

Cell[TextData[{
 "Mit Hilfe des Befehls ",
 StyleBox["StyleForm",
  FontWeight->"Bold"],
 " haben wir dabei den Ausgabefont gewechselt und einen Fettdruck der Zeichen \
erreicht. Letzteres wollen wir verwenden, um den Bereich des lokalen \
Alignments von den Randbereichen (Normaldruck) abzuheben.  Mit derselben \
Befehlsstruktur wie f\[UDoubleDot]r ",
 StyleBox["pX1",
  FontWeight->"Bold"],
 " k\[ODoubleDot]nnen wir nun die verschiedenen Sequenzsegmente an den Enden \
des Alignments anf\[UDoubleDot]gen. "
}], "Text",
 CellChangeTimes->{{3.6746378018436394`*^9, 3.674637838142695*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"pX3", "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"Graphics", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"StyleForm", "[", 
           RowBox[{
            RowBox[{"end1", "[", 
             RowBox[{"[", "i", "]"}], "]"}], ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", 
          RowBox[{"{", " ", 
           RowBox[{
            RowBox[{"dim1", "+", "i"}], ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"Length", "[", "end1", "]"}]}], "}"}]}], "]"}], "]"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.623822495849495*^9, 3.623822496094647*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"pX4", " ", "=", " ", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"Graphics", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"StyleForm", "[", 
           RowBox[{
            RowBox[{"end2", "[", 
             RowBox[{"[", "i", "]"}], "]"}], ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", 
          RowBox[{"{", " ", 
           RowBox[{
            RowBox[{"dim1", "+", "i"}], ",", "2"}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"Length", "[", "end2", "]"}]}], "}"}]}], "]"}], "]"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.623822501073515*^9, 3.623822501278517*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"pX5", "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"Graphics", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"StyleForm", "[", 
           RowBox[{
            RowBox[{"start1", "[", 
             RowBox[{"[", "i", "]"}], "]"}], ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              RowBox[{"Length", "[", "start1", "]"}]}], "+", "i"}], ",", 
            "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"Length", "[", "start1", "]"}]}], "}"}]}], "]"}], "]"}], 
     ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.623822504040873*^9, 3.623822504223349*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"pX6", "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"Graphics", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"StyleForm", "[", 
           RowBox[{
            RowBox[{"start2", "[", 
             RowBox[{"[", "i", "]"}], "]"}], ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              RowBox[{"Length", "[", "start2", "]"}]}], "+", "i"}], ",", 
            "2"}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"Length", "[", "start2", "]"}]}], "}"}]}], "]"}], "]"}], 
     ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.623822506208692*^9, 3.6238225063836327`*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"pX2", ",", "pX1", ",", "pX3", ",", "pX4", ",", "pX5", ",", "pX6"}],
   "]"}]], "Input",
 CellChangeTimes->{{3.623822509176222*^9, 3.623822510462736*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0.9], RectangleBox[{-4, -2}, {20, 4}]}, {{InsetBox[
      TagBox[
       StyleBox["\<\"K\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {1, 2}], InsetBox[
      TagBox[
       StyleBox["\<\"|\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {1, 1}], InsetBox[
      TagBox[
       StyleBox["\<\"K\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {1, 0}]}, {InsetBox[
      TagBox[
       StyleBox["\<\"E\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {2, 2}], InsetBox[
      TagBox[
       StyleBox["\<\" \"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {2, 1}], InsetBox[
      TagBox[
       StyleBox["\<\"Y\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {2, 0}]}, {InsetBox[
      TagBox[
       StyleBox["\<\"F\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {3, 2}], InsetBox[
      TagBox[
       StyleBox["\<\"|\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {3, 1}], InsetBox[
      TagBox[
       StyleBox["\<\"F\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {3, 0}]}, {InsetBox[
      TagBox[
       StyleBox["\<\"H\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {4, 2}], InsetBox[
      TagBox[
       StyleBox["\<\"|\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {4, 1}], InsetBox[
      TagBox[
       StyleBox["\<\"H\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {4, 0}]}, {InsetBox[
      TagBox[
       StyleBox["\<\"-\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {5, 2}], InsetBox[
      TagBox[
       StyleBox["\<\" \"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {5, 1}], InsetBox[
      TagBox[
       StyleBox["\<\"K\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {5, 0}]}, {InsetBox[
      TagBox[
       StyleBox["\<\"-\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {6, 2}], InsetBox[
      TagBox[
       StyleBox["\<\" \"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {6, 1}], InsetBox[
      TagBox[
       StyleBox["\<\"A\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {6, 0}]}, {InsetBox[
      TagBox[
       StyleBox["\<\"-\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {7, 2}], InsetBox[
      TagBox[
       StyleBox["\<\" \"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {7, 1}], InsetBox[
      TagBox[
       StyleBox["\<\"Q\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {7, 0}]}, {InsetBox[
      TagBox[
       StyleBox["\<\"N\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {8, 2}], InsetBox[
      TagBox[
       StyleBox["\<\"|\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {8, 1}], InsetBox[
      TagBox[
       StyleBox["\<\"N\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {8, 0}]}, {InsetBox[
      TagBox[
       StyleBox["\<\"G\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {9, 2}], InsetBox[
      TagBox[
       StyleBox["\<\"|\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {9, 1}], InsetBox[
      TagBox[
       StyleBox["\<\"G\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {9, 0}]}, {InsetBox[
      TagBox[
       StyleBox["\<\"H\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {10, 2}], InsetBox[
      TagBox[
       StyleBox["\<\"|\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {10, 1}], InsetBox[
      TagBox[
       StyleBox["\<\"H\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {10, 0}]}, {InsetBox[
      TagBox[
       StyleBox["\<\"T\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {11, 2}], InsetBox[
      TagBox[
       StyleBox["\<\" \"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {11, 1}], InsetBox[
      TagBox[
       StyleBox["\<\"S\"\>",
        FontFamily->"Helvetica",
        FontWeight->Bold],
       StyleForm[#, FontFamily -> "Helvetica", FontWeight -> 
        Bold]& ], {11, 0}]}}, {}, {InsetBox[
     TagBox[
      StyleBox["\<\"P\"\>",
       FontFamily->"Helvetica"],
      StyleForm[#, FontFamily -> "Helvetica"]& ], {12, 2}], InsetBox[
     TagBox[
      StyleBox["\<\"T\"\>",
       FontFamily->"Helvetica"],
      StyleForm[#, FontFamily -> 
       "Helvetica"]& ], {13, 2}]}, {}, {}}]], "Output",
 CellChangeTimes->{3.677571718236969*^9}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{507, 900},
WindowMargins->{{453, Automatic}, {Automatic, 138}},
FrontEndVersion->"10.4 for Microsoft Windows (64-bit) (April 11, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 870, 36, 182, "Subsubtitle"],
Cell[CellGroupData[{
Cell[1453, 60, 287, 8, 94, "Subtitle"],
Cell[1743, 70, 507, 9, 125, "Text"],
Cell[2253, 81, 187, 5, 47, "Input"],
Cell[2443, 88, 634, 15, 112, "Input"],
Cell[3080, 105, 290, 7, 49, "Text"],
Cell[CellGroupData[{
Cell[3395, 116, 68, 1, 31, "Input"],
Cell[3466, 119, 119, 3, 31, "Output"]
}, Open  ]],
Cell[3600, 125, 483, 10, 125, "Text"],
Cell[CellGroupData[{
Cell[4108, 139, 129, 3, 52, "Input"],
Cell[4240, 144, 550, 9, 52, "Output"]
}, Open  ]],
Cell[4805, 156, 261, 7, 49, "Text"],
Cell[CellGroupData[{
Cell[5091, 167, 454, 9, 72, "Input"],
Cell[5548, 178, 15740, 573, 330, "Output"]
}, Open  ]],
Cell[21303, 754, 381, 8, 106, "Text"],
Cell[21687, 764, 324, 10, 52, "Input"],
Cell[22014, 776, 3080, 71, 733, "Text"],
Cell[25097, 849, 1163, 32, 152, "Input"],
Cell[26263, 883, 329, 6, 87, "Text"],
Cell[CellGroupData[{
Cell[26617, 893, 153, 4, 52, "Input"],
Cell[26773, 899, 86, 2, 31, "Output"]
}, Open  ]],
Cell[26874, 904, 711, 17, 163, "Text"],
Cell[27588, 923, 497, 15, 92, "Input"],
Cell[28088, 940, 612, 16, 125, "Text"],
Cell[CellGroupData[{
Cell[28725, 960, 307, 7, 72, "Input"],
Cell[29035, 969, 4037, 143, 162, "Output"]
}, Open  ]],
Cell[33087, 1115, 257, 6, 87, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33381, 1126, 300, 9, 94, "Subtitle"],
Cell[33684, 1137, 403, 9, 87, "Text"],
Cell[34090, 1148, 87, 3, 31, "Input"],
Cell[34180, 1153, 1224, 21, 277, "Text"],
Cell[35407, 1176, 217, 7, 31, "Input"],
Cell[35627, 1185, 267, 9, 31, "Input"],
Cell[35897, 1196, 267, 9, 31, "Input"],
Cell[36167, 1207, 1060, 22, 258, "Text"],
Cell[37230, 1231, 1819, 51, 212, "Input"],
Cell[39052, 1284, 1715, 34, 410, "Text"],
Cell[40770, 1320, 529, 16, 52, "Input"],
Cell[41302, 1338, 415, 8, 106, "Text"],
Cell[41720, 1348, 586, 17, 52, "Input"],
Cell[42309, 1367, 5306, 134, 1189, "Text"],
Cell[47618, 1503, 3789, 108, 512, "Input"],
Cell[51410, 1613, 233, 7, 49, "Text"],
Cell[CellGroupData[{
Cell[51668, 1624, 235, 5, 31, "Input"],
Cell[51906, 1631, 5952, 115, 250, "Output"]
}, Open  ]],
Cell[57873, 1749, 323, 7, 87, "Text"],
Cell[58199, 1758, 698, 12, 198, "Text"],
Cell[58900, 1772, 1194, 31, 128, "Input"],
Cell[60097, 1805, 721, 16, 160, "Text"],
Cell[60821, 1823, 2034, 55, 228, "Input"],
Cell[62858, 1880, 618, 17, 141, "Text"],
Cell[63479, 1899, 1316, 34, 148, "Input"],
Cell[64798, 1935, 434, 8, 122, "Text"],
Cell[65235, 1945, 1221, 34, 128, "Input"],
Cell[66459, 1981, 866, 23, 179, "Text"],
Cell[67328, 2006, 292, 7, 47, "Input"],
Cell[67623, 2015, 339, 9, 84, "Text"],
Cell[67965, 2026, 253, 7, 47, "Input"],
Cell[CellGroupData[{
Cell[68243, 2037, 237, 6, 47, "Input"],
Cell[68483, 2045, 15483, 296, 250, "Output"]
}, Open  ]],
Cell[83981, 2344, 982, 19, 220, "Text"],
Cell[84966, 2365, 155, 4, 31, "Input"],
Cell[CellGroupData[{
Cell[85146, 2373, 241, 8, 31, "Input"],
Cell[85390, 2383, 116, 3, 31, "Output"]
}, Open  ]],
Cell[85521, 2389, 687, 15, 144, "Text"],
Cell[86211, 2406, 1087, 31, 132, "Input"],
Cell[87301, 2439, 2370, 62, 467, "Text"],
Cell[CellGroupData[{
Cell[89696, 2505, 230, 7, 31, "Input"],
Cell[89929, 2514, 869, 29, 72, "Output"]
}, Open  ]],
Cell[90813, 2546, 453, 11, 87, "Text"],
Cell[CellGroupData[{
Cell[91291, 2561, 278, 9, 31, "Input"],
Cell[91572, 2572, 234, 5, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[91843, 2582, 209, 6, 31, "Input"],
Cell[92055, 2590, 997, 29, 92, "Output"]
}, Open  ]],
Cell[93067, 2622, 269, 5, 49, "Text"],
Cell[93339, 2629, 704, 15, 179, "Text"],
Cell[94046, 2646, 3851, 106, 488, "Input"],
Cell[97900, 2754, 454, 16, 65, "Text"],
Cell[98357, 2772, 549, 18, 88, "Input"],
Cell[CellGroupData[{
Cell[98931, 2794, 238, 6, 47, "Input"],
Cell[99172, 2802, 17377, 322, 250, "Output"]
}, Open  ]],
Cell[116564, 3127, 129, 4, 49, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[116730, 3136, 336, 9, 94, "Subtitle"],
Cell[117069, 3147, 1322, 29, 296, "Text"],
Cell[118394, 3178, 2845, 80, 332, "Input"],
Cell[121242, 3260, 448, 12, 87, "Text"],
Cell[CellGroupData[{
Cell[121715, 3276, 236, 7, 31, "Input"],
Cell[121954, 3285, 1309, 30, 92, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[123300, 3320, 99, 2, 31, "Input"],
Cell[123402, 3324, 1083, 24, 71, "Output"]
}, Open  ]],
Cell[124500, 3351, 339, 9, 65, "Text"],
Cell[124842, 3362, 22127, 571, 2648, "Input"],
Cell[146972, 3935, 461, 9, 125, "Text"],
Cell[CellGroupData[{
Cell[147458, 3948, 118, 2, 31, "Input"],
Cell[147579, 3952, 1081, 24, 71, "Output"]
}, Open  ]],
Cell[148675, 3979, 240, 5, 68, "Text"],
Cell[CellGroupData[{
Cell[148940, 3988, 118, 2, 31, "Input"],
Cell[149061, 3992, 1120, 24, 71, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[150218, 4021, 118, 2, 31, "Input"],
Cell[150339, 4025, 1083, 24, 71, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[151459, 4054, 119, 2, 31, "Input"],
Cell[151581, 4058, 1081, 24, 71, "Output"]
}, Open  ]],
Cell[152677, 4085, 1806, 31, 505, "Text"],
Cell[CellGroupData[{
Cell[154508, 4120, 688, 12, 72, "Input"],
Cell[155199, 4134, 73, 1, 31, "Output"]
}, Open  ]],
Cell[155287, 4138, 779, 16, 239, "Text"],
Cell[CellGroupData[{
Cell[156091, 4158, 727, 13, 72, "Input"],
Cell[156821, 4173, 401, 10, 31, "Output"]
}, Open  ]],
Cell[157237, 4186, 782, 13, 220, "Text"],
Cell[158022, 4201, 4325, 101, 392, "Input"],
Cell[162350, 4304, 358, 7, 87, "Text"],
Cell[CellGroupData[{
Cell[162733, 4315, 112, 3, 31, "Input"],
Cell[162848, 4320, 1083, 24, 71, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[163968, 4349, 232, 4, 31, "Input"],
Cell[164203, 4355, 1083, 24, 71, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[165335, 4385, 304, 9, 94, "Subtitle"],
Cell[165642, 4396, 426, 7, 125, "Text"],
Cell[CellGroupData[{
Cell[166093, 4407, 266, 5, 31, "Input"],
Cell[166362, 4414, 191, 4, 31, "Output"]
}, Open  ]],
Cell[166568, 4421, 224, 4, 49, "Text"],
Cell[166795, 4427, 669, 18, 92, "Input"],
Cell[CellGroupData[{
Cell[167489, 4449, 430, 9, 52, "Input"],
Cell[167922, 4460, 1965, 67, 117, "Output"]
}, Open  ]],
Cell[169902, 4530, 309, 8, 68, "Text"],
Cell[170214, 4540, 92, 2, 31, "Input"],
Cell[CellGroupData[{
Cell[170331, 4546, 359, 10, 52, "Input"],
Cell[170693, 4558, 324, 6, 31, "Output"],
Cell[171020, 4566, 324, 6, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[171381, 4577, 237, 4, 31, "Input"],
Cell[171621, 4583, 1122, 24, 71, "Output"]
}, Open  ]],
Cell[172758, 4610, 101, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[172884, 4615, 288, 5, 31, "Input"],
Cell[173175, 4622, 71, 1, 31, "Output"]
}, Open  ]],
Cell[173261, 4626, 186, 4, 49, "Text"],
Cell[CellGroupData[{
Cell[173472, 4634, 509, 13, 92, "Input"],
Cell[173984, 4649, 775, 26, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[174796, 4680, 430, 10, 52, "Input"],
Cell[175229, 4692, 1538, 37, 244, "Output"]
}, Open  ]],
Cell[176782, 4732, 700, 11, 182, "Text"],
Cell[177485, 4745, 419, 8, 52, "Input"],
Cell[177907, 4755, 640, 18, 132, "Input"],
Cell[178550, 4775, 1192, 29, 172, "Input"],
Cell[CellGroupData[{
Cell[179767, 4808, 508, 11, 52, "Input"],
Cell[180278, 4821, 43669, 725, 243, "Output"]
}, Open  ]],
Cell[223962, 5549, 225, 4, 68, "Text"],
Cell[224190, 5555, 1245, 31, 172, "Input"],
Cell[CellGroupData[{
Cell[225460, 5590, 525, 11, 72, "Input"],
Cell[225988, 5603, 41704, 683, 239, "Output"]
}, Open  ]],
Cell[267707, 6289, 593, 10, 182, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[268337, 6304, 368, 9, 122, "Subtitle"],
Cell[268708, 6315, 373, 8, 87, "Text"],
Cell[269084, 6325, 132, 4, 47, "Input"],
Cell[269219, 6331, 463, 13, 68, "Input"],
Cell[269685, 6346, 242, 8, 47, "Input"],
Cell[269930, 6356, 243, 8, 47, "Input"],
Cell[270176, 6366, 243, 8, 47, "Input"],
Cell[270422, 6376, 783, 20, 182, "Text"],
Cell[271208, 6398, 1796, 52, 212, "Input"],
Cell[273007, 6452, 1079, 17, 277, "Text"],
Cell[274089, 6471, 425, 13, 52, "Input"],
Cell[274517, 6486, 248, 8, 52, "Input"],
Cell[274768, 6496, 279, 9, 52, "Input"],
Cell[275050, 6507, 627, 16, 144, "Text"],
Cell[275680, 6525, 227, 7, 52, "Input"],
Cell[275910, 6534, 251, 7, 49, "Text"],
Cell[CellGroupData[{
Cell[276186, 6545, 241, 8, 31, "Input"],
Cell[276430, 6555, 118, 3, 31, "Output"]
}, Open  ]],
Cell[276563, 6561, 1111, 21, 277, "Text"],
Cell[277677, 6584, 1138, 34, 188, "Input"],
Cell[CellGroupData[{
Cell[278840, 6622, 304, 9, 47, "Input"],
Cell[279147, 6633, 749, 25, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[279933, 6663, 582, 18, 88, "Input"],
Cell[280518, 6683, 859, 25, 72, "Output"]
}, Open  ]],
Cell[281392, 6711, 559, 18, 88, "Input"],
Cell[281954, 6731, 1200, 33, 188, "Input"],
Cell[CellGroupData[{
Cell[283179, 6768, 327, 8, 47, "Input"],
Cell[283509, 6778, 4295, 62, 250, "Output"]
}, Open  ]],
Cell[287819, 6843, 725, 21, 108, "Input"],
Cell[288547, 6866, 869, 26, 128, "Input"],
Cell[289419, 6894, 1173, 33, 128, "Input"],
Cell[290595, 6929, 195, 5, 47, "Input"],
Cell[CellGroupData[{
Cell[290815, 6938, 304, 7, 47, "Input"],
Cell[291122, 6947, 14605, 256, 250, "Output"]
}, Open  ]],
Cell[305742, 7206, 1754, 39, 391, "Text"],
Cell[307499, 7247, 615, 20, 52, "Input"],
Cell[308117, 7269, 328, 9, 68, "Text"],
Cell[308448, 7280, 2473, 71, 252, "Input"],
Cell[310924, 7353, 326, 9, 68, "Text"],
Cell[CellGroupData[{
Cell[311275, 7366, 407, 11, 72, "Input"],
Cell[311685, 7379, 999, 21, 71, "Output"]
}, Open  ]],
Cell[312699, 7403, 580, 11, 144, "Text"],
Cell[313282, 7416, 11738, 313, 1608, "Input"],
Cell[325023, 7731, 173, 4, 49, "Text"],
Cell[CellGroupData[{
Cell[325221, 7739, 120, 2, 31, "Input"],
Cell[325344, 7743, 997, 21, 71, "Output"]
}, Open  ]],
Cell[326356, 7767, 246, 4, 49, "Text"],
Cell[CellGroupData[{
Cell[326627, 7775, 120, 2, 31, "Input"],
Cell[326750, 7779, 1081, 24, 71, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[327868, 7808, 121, 2, 31, "Input"],
Cell[327992, 7812, 718, 18, 71, "Output"]
}, Open  ]],
Cell[328725, 7833, 534, 9, 125, "Text"],
Cell[329262, 7844, 785, 19, 160, "Text"],
Cell[330050, 7865, 687, 22, 108, "Input"],
Cell[CellGroupData[{
Cell[330762, 7891, 187, 5, 47, "Input"],
Cell[330952, 7898, 136, 3, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[331125, 7906, 204, 6, 47, "Input"],
Cell[331332, 7914, 89, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[331458, 7921, 204, 6, 47, "Input"],
Cell[331665, 7929, 133, 3, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[331835, 7937, 251, 8, 47, "Input"],
Cell[332089, 7947, 89, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[332215, 7954, 251, 8, 47, "Input"],
Cell[332469, 7964, 87, 2, 31, "Output"]
}, Open  ]],
Cell[332571, 7969, 912, 24, 217, "Text"],
Cell[CellGroupData[{
Cell[333508, 7997, 209, 6, 47, "Input"],
Cell[333720, 8005, 116, 3, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[333873, 8013, 1682, 48, 308, "Input"],
Cell[335558, 8063, 6833, 201, 112, "Output"]
}, Open  ]],
Cell[342406, 8267, 654, 15, 160, "Text"],
Cell[343063, 8284, 910, 25, 168, "Input"],
Cell[343976, 8311, 920, 25, 168, "Input"],
Cell[344899, 8338, 1004, 29, 168, "Input"],
Cell[345906, 8369, 1006, 29, 168, "Input"],
Cell[CellGroupData[{
Cell[346937, 8402, 265, 6, 47, "Input"],
Cell[347205, 8410, 7143, 210, 112, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

